@@ -21,11 +21,11 @@ rm mlterm/[tv]font
 
 cd $HOME/mlterm.app/Contents/MacOS
 
-libs="lib/libkik.[0-9]*.dylib lib/libmkf.[0-9]*.dylib lib/libmlterm_core.dylib lib/mlterm/libctl_bidi.so lib/mlterm/libctl_iscii.so lib/mlterm/libind_bengali.so lib/mlterm/libind_hindi.so lib/mlterm/libotl.so lib/mlterm/libim-skk.so lib/mlterm/libim-kbd.so"
+libs="lib/libpobl.[0-9]*.dylib lib/libmef.[0-9]*.dylib lib/libmlterm_core.dylib lib/libmlterm_coreotl.dylib lib/mlterm/libctl_bidi.so lib/mlterm/libctl_iscii.so lib/mlterm/libind_bengali.so lib/mlterm/libind_hindi.so lib/mlterm/libotl.so lib/mlterm/libim-skk.so lib/mlterm/libim-kbd.so"
 
-mkdir -p lib/mkf
+mkdir -p lib/mef
 mkdir -p lib/mlterm
-for file in $libs lib/mkf/lib*.so ; do
+for file in $libs lib/mef/lib*.so ; do
 	cp -f $prefix/$file `dirname $file`/
 done
 
@@ -54,4 +54,4 @@ if [ -f lib/mlterm/libotl.so ]; then
 		install_name_tool -change $libotf \
 			@executable_path/lib/gtk/libotf.0.dylib lib/mlterm/libotl.so
 	fi
-fi
\ No newline at end of file
+fi
