@@ -7,14 +7,24 @@
 
 #ifdef SIXEL_1BPP
 
-#define realloc_pixels realloc_pixels_1bpp
 #define correct_height correct_height_1bpp
-#define load_sixel_from_file load_sixel_from_file_1bpp
+#define load_sixel_from_data load_sixel_from_data_1bpp
 #define SIXEL_RGB(r, g, b) ((9 * (r) + 30 * (g) + (b)) * 51 >= 5120 * 20 ? 1 : 0)
 #define CARD_HEAD_SIZE 0
 #define pixel_t u_int8_t
 
-#else /* SIXEL_1BPP */
+#elif defined(SIXEL_SHAREPALETTE) /* Both sixel and system uses same palette (works on fb alone) */
+
+#define correct_height correct_height_sharepalette
+#define load_sixel_from_data load_sixel_from_data_sharepalette
+#define CARD_HEAD_SIZE 0
+#ifdef USE_GRF
+#define pixel_t u_int16_t
+#else
+#define pixel_t u_int8_t
+#endif
+
+#else
 
 #define SIXEL_RGB(r, g, b) ((((r)*255 / 100) << 16) | (((g)*255 / 100) << 8) | ((b)*255 / 100))
 #ifndef CARD_HEAD_SIZE
@@ -32,7 +42,7 @@
 
 /* --- static variables --- */
 
-#ifndef SIXEL_1BPP
+#if !defined(SIXEL_1BPP) && !defined(SIXEL_SHAREPALETTE)
 static pixel_t *custom_palette;
 #endif
 
@@ -73,70 +83,97 @@ static size_t get_params(int *params, size_t max_params, char **p) {
 }
 #endif /* __GET_PARAMS__ */
 
-static int realloc_pixels(u_char **pixels, int new_width, int new_height, int cur_width,
-                          int cur_height) {
+#ifndef __READ_SIXEL_FILE__
+#define __READ_SIXEL_FILE__
+static char *read_sixel_file(const char *path) {
+  FILE* fp;
+  struct stat st;
+  char * data;
+  size_t len;
+
+  if (!(fp = fopen(path, "r"))) {
+#ifdef DEBUG
+    bl_debug_printf(BL_DEBUG_TAG " failed to open %s\n.", path);
+#endif
+
+    return NULL;
+  }
+
+  fstat(fileno(fp), &st);
+
+  /*
+   * - malloc() should be used here because alloca() could return insufficient
+   * memory.
+   * - Cast to char* is necessary because this function can be compiled by g++.
+   */
+  if (!(data = (char*)malloc(st.st_size + 1))) {
+    fclose(fp);
+
+    return NULL;
+  }
+
+  len = fread(data, 1, st.st_size, fp);
+  fclose(fp);
+  data[len] = '\0';
+
+  return data;
+}
+#endif
+
+#ifndef __REALLOC_PIXELS_INTERN__
+#define __REALLOC_PIXELS_INTERN__
+static int realloc_pixels_intern(u_char **pixels, size_t new_stride, int new_height,
+                                 size_t cur_stride, int cur_height) {
   u_char *p;
   int y;
   int n_copy_rows;
-  size_t new_line_len;
-  size_t cur_line_len;
-
-  if (new_width == cur_width && new_height == cur_height) {
-    return 1;
-  }
 
   n_copy_rows = K_MIN(new_height, cur_height);
-  new_line_len = new_width * PIXEL_SIZE;
-  cur_line_len = cur_width * PIXEL_SIZE;
 
-  if (new_width < cur_width) {
+  if (new_stride < cur_stride) {
     if (new_height > cur_height) {
 /* Not supported */
 
 #ifdef DEBUG
       bl_error_printf(BL_DEBUG_TAG
-                      " Sixel width is shrunk (%d->%d) but"
-                      " height is lengthen (%d->%d)\n",
-                      cur_width, cur_height, new_width, new_height);
+                      " Sixel width bytes is shrunk (%d->%d) but height is lengthen (%d->%d)\n",
+                      cur_stride, cur_height, new_stride, new_height);
 #endif
 
       return 0;
     } else /* if( new_height < cur_height) */
     {
 #ifdef DEBUG
-      bl_debug_printf(BL_DEBUG_TAG " Sixel data: %d %d -> shrink %d %d\n", cur_width, cur_height,
-                      new_width, new_height);
+      bl_debug_printf(BL_DEBUG_TAG " Sixel data: %d bytes %d rows -> shrink %d bytes %d rows\n",
+                      cur_stride, cur_height, new_stride, new_height);
 #endif
 
       for (y = 1; y < n_copy_rows; y++) {
-        memmove(*pixels + (y * new_line_len), *pixels + (y * cur_line_len), new_line_len);
+        memmove(*pixels + (y * new_stride), *pixels + (y * cur_stride), new_stride);
       }
 
       return 1;
     }
-  } else if (new_width == cur_width && new_height < cur_height) {
+  } else if (new_stride == cur_stride && new_height < cur_height) {
     /* do nothing */
 
     return 1;
   }
 
-  if (new_width > (SSIZE_MAX - CARD_HEAD_SIZE) / PIXEL_SIZE / new_height) {
+  if (new_stride > (SSIZE_MAX - CARD_HEAD_SIZE) / new_height) {
     /* integer overflow */
     return 0;
   }
 
-  if (new_width == cur_width /* && new_height > cur_height */) {
+  if (new_stride == cur_stride /* && new_height > cur_height */) {
 #ifdef DEBUG
-    bl_debug_printf(BL_DEBUG_TAG " Sixel data: %d %d -> realloc %d %d\n", cur_width, cur_height,
-                    new_width, new_height);
+    bl_debug_printf(BL_DEBUG_TAG " Sixel data: %d bytes %d rows -> realloc %d bytes %d rows\n",
+                    cur_stride, cur_height, new_stride, new_height);
 #endif
 
-    /*
-     * Cast to u_char* is necessary because this function can be
-     * compiled by g++.
-     */
+    /* Cast to u_char* is necessary because this function can be compiled by g++. */
     if ((p = (u_char*)realloc(*pixels - CARD_HEAD_SIZE,
-                              CARD_HEAD_SIZE + new_line_len * new_height))) {
+                              CARD_HEAD_SIZE + new_stride * new_height))) {
       p += CARD_HEAD_SIZE;
     } else {
 #ifdef DEBUG
@@ -145,16 +182,15 @@ static int realloc_pixels(u_char **pixels, int new_width, int new_height, int cu
       return 0;
     }
 
-    memset(p + cur_line_len * cur_height, 0, new_width * (new_height - cur_height));
+    memset(p + cur_stride * cur_height, 0, new_stride * (new_height - cur_height));
   } else {
 #ifdef DEBUG
-    bl_debug_printf(BL_DEBUG_TAG " Sixel data: %d %d -> calloc %d %d\n", cur_width, cur_height,
-                    new_width, new_height);
+    bl_debug_printf(BL_DEBUG_TAG " Sixel data: %d bytes %d rows -> calloc %d bytes %d rows\n",
+                    cur_stride, cur_height, new_stride, new_height);
 #endif
 
-    /* Cast to u_char* is necessary because this function can be compiled by
-     * g++. */
-    if ((p = (u_char*)calloc(CARD_HEAD_SIZE + new_line_len * new_height, 1))) {
+    /* Cast to u_char* is necessary because this function can be compiled by g++. */
+    if ((p = (u_char*)calloc(CARD_HEAD_SIZE + new_stride * new_height, 1))) {
       p += CARD_HEAD_SIZE;
     } else {
 #ifdef DEBUG
@@ -164,7 +200,7 @@ static int realloc_pixels(u_char **pixels, int new_width, int new_height, int cu
     }
 
     for (y = 0; y < n_copy_rows; y++) {
-      memcpy(p + (y * new_line_len), (*pixels) + (y * cur_line_len), cur_line_len);
+      memcpy(p + (y * new_stride), (*pixels) + (y * cur_stride), cur_stride);
     }
 
     if (*pixels) {
@@ -176,13 +212,20 @@ static int realloc_pixels(u_char **pixels, int new_width, int new_height, int cu
 
   return 1;
 }
+#endif
+
+/* realloc_pixels() might not be inlined because it is called twice. */
+#define realloc_pixels(pixels, new_width, new_height, cur_width, cur_height) \
+  ((new_width) == (cur_width) && (new_height) == (cur_height) ? \
+    1 : realloc_pixels_intern(pixels, new_width * PIXEL_SIZE, new_height, \
+                              cur_width * PIXEL_SIZE, cur_height))
+
 
 /*
  * Correct the height which is always multiple of 6, but this doesn't
  * necessarily work.
  */
-static void correct_height(pixel_t *pixels, int width, int *height /* multiple of 6 */
-                           ) {
+static void correct_height(pixel_t *pixels, int width, int *height /* multiple of 6 */) {
   int x;
   int y;
 
@@ -205,18 +248,15 @@ static void correct_height(pixel_t *pixels, int width, int *height /* multiple o
  * the actual image size is less than it.
  * It is the caller that should shrink (realloc) it.
  */
-static u_char *load_sixel_from_file(const char *path, u_int *width_ret, u_int *height_ret) {
-  FILE* fp;
-  struct stat st;
-  char *file_data;
-  char *p;
-  size_t len;
+static u_char *load_sixel_from_data(char *file_data, u_int *width_ret, u_int *height_ret) {
+  char *p = file_data;
   u_char *pixels;
   int params[5];
   size_t n; /* number of params */
   int init_width;
   int pix_x;
   int pix_y;
+  int stride;
   int cur_width;
   int cur_height;
   int width;
@@ -224,6 +264,25 @@ static u_char *load_sixel_from_file(const char *path, u_int *width_ret, u_int *h
   int rep;
   int color;
   int asp_x;
+#ifdef SIXEL_SHAREPALETTE
+  u_int8_t color_indexes[] =
+    { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15,
+      16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31,
+      32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47,
+      48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63,
+      64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79,
+      80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95,
+      96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111,
+      112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127,
+      128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143,
+      144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159,
+      160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175,
+      176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191,
+      192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 207,
+      208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223,
+      224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239,
+      240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255 };
+#else
   /* VT340 Default Color Map */
   static pixel_t default_palette[] = {
       SIXEL_RGB(0, 0, 0),    /* BLACK */
@@ -244,46 +303,19 @@ static u_char *load_sixel_from_file(const char *path, u_int *width_ret, u_int *h
       SIXEL_RGB(80, 80, 80)  /* GRAY 75% */
   };
   pixel_t *palette;
-
-  if (!(fp = fopen(path, "r"))) {
-#ifdef DEBUG
-    bl_debug_printf(BL_DEBUG_TAG " failed to open %s\n.", path);
 #endif
 
-    return NULL;
-  }
-
-  fstat(fileno(fp), &st);
-
-  /*
-   * - malloc() should be used here because alloca() could return insufficient
-   * memory.
-   * - Cast to char* is necessary because this function can be compiled by g++.
-   */
-  if (!(p = file_data = (char*)malloc(st.st_size + 1))) {
-    fclose(fp);
-
-    return NULL;
-  }
-
-  len = fread(p, 1, st.st_size, fp);
-  fclose(fp);
-  p[len] = '\0';
-
   pixels = NULL;
   init_width = 0;
   cur_width = cur_height = 0;
   width = 1024;
   height = 1024;
 
-  /*  Cast to u_char* is necessary because this function can be compiled by g++.
-   */
   if (!realloc_pixels(&pixels, width, height, 0, 0)) {
-    free(file_data);
-
     return NULL;
   }
 
+#ifndef SIXEL_SHAREPALETTE
 #ifndef SIXEL_1BPP
   if (custom_palette) {
     palette = custom_palette;
@@ -299,6 +331,7 @@ static u_char *load_sixel_from_file(const char *path, u_int *width_ret, u_int *h
     memcpy(palette, default_palette, sizeof(default_palette));
     memset(palette + 16, 0, sizeof(pixel_t) * 256 - sizeof(default_palette));
   }
+#endif
 
 restart:
   while (1) {
@@ -426,51 +459,105 @@ restart:
   }
 
 body:
+#ifdef SIXEL_SHAREPALETTE
+  {
+    char *p2;
+
+    /* 'p + 2' is to skip '#' of "#0;9;%d;%d;%d" appended just after "DCS ... q" in vt_parser.c */
+    if (!(p2 = memchr(p + 2, '#', 50)) || (p2[2] != ';' && p2[3] != ';' && p2[4] != ';')) {
+      /* If color definition is not found, load_sixel_from_data_sharepalette() exits. */
+      goto error;
+    }
+  }
+#endif
+
   rep = asp_x;
   pix_x = pix_y = 0;
+  stride = width * PIXEL_SIZE;
   color = 0;
 
   while (*(++p) != '\0') {
-    if (*p == '"') /* " Pan ; Pad ; Ph ; Pv */
-    {
-      if (*(++p) == '\0') {
-#ifdef DEBUG
-        bl_debug_printf(BL_DEBUG_TAG " Illegal format.\n.");
-#endif
+    if (*p >= '?' && *p <= '\x7E') {
+      u_int new_width;
+      u_int new_height;
+      int a;
+      int b;
+      int y;
+      u_char *line;
+
+      if (width < pix_x + rep) {
+        new_width = width + 512;
+        stride += (512 * PIXEL_SIZE);
+      } else {
+        new_width = width;
+      }
+
+      if (!realloc_pixels(&pixels, new_width,
+                          (new_height = height < pix_y + 6 ? height + 512 : height),
+                          width, height)) {
         break;
       }
 
-      if ((n = get_params(params, 4, &p)) == 1) {
-        params[1] = 1;
-        n = 2;
-      }
+      width = new_width;
+      height = new_height;
 
-/* XXX ignored */
-#if 0
-      switch (n) {
-        case 4:
-          height = params[3];
-        case 3:
-          width = params[2];
-        /* XXX realloc_pixels() is necessary here. */
-        case 2:
-/* V:H=params[0]:params[1] */
-#if 0
-          asp_x = params[1];
-          asp_y = params[0];
-#else
-          rep /= asp_x;
-          if ((asp_x = params[1] / params[0]) == 0) {
-            asp_x = 1; /* XXX */
+      b = *p - '?';
+      a = 0x01;
+      line = pixels + pix_y * stride + pix_x * PIXEL_SIZE;
+
+#ifdef SIXEL_SHAREPALETTE
+      for (y = 0; y < 6; y++) {
+        if ((b & a) != 0) {
+#ifdef USE_GRF
+          int x;
+          for (x = 0; x < rep; x++) {
+            ((u_int16_t*)line)[x] = color_indexes[color];
           }
-          rep *= asp_x;
+#else
+          memset(line, color_indexes[color], rep);
 #endif
+        }
+        a <<= 1;
+        line += stride;
+      }
+#else
+      for (y = 0; y < 6; y++) {
+        if ((b & a) != 0) {
+          int x;
+
+          for (x = 0; x < rep; x++) {
+#if defined(GDK_PIXBUF_VERSION) || defined(USE_QUARTZ)
+            /* RGBA */
+            line[x * PIXEL_SIZE] = (palette[color] >> 16) & 0xff;
+            line[x * PIXEL_SIZE + 1] = (palette[color] >> 8) & 0xff;
+            line[x * PIXEL_SIZE + 2] = (palette[color]) & 0xff;
+            line[x * PIXEL_SIZE + 3] = 0xff;
+#elif defined(SIXEL_1BPP)
+            /* 0x80 is opaque mark */
+            ((pixel_t*)line)[x] = 0x80 | palette[color];
+#else
+            /* ARGB (cardinal) */
+            ((pixel_t*)line)[x] = 0xff000000 | palette[color];
+#endif
+          }
+        }
+
+        a <<= 1;
+        line += stride;
+      }
+#endif /* SIXEL_SHAREPALETTE */
+
+      pix_x += rep;
+
+      if (cur_width < pix_x) {
+        cur_width = pix_x;
       }
 
-      if (asp_x <= 0) {
-        asp_x = 1;
+      if (cur_height < pix_y + 6) {
+        cur_height = pix_y + 6;
       }
-#endif
+
+      rep = asp_x;
     } else if (*p == '!') {
       /* ! Pn Ch */
       if (*(++p) == '\0') {
@@ -488,8 +575,33 @@ body:
 
         rep *= asp_x;
       }
-    } else if (*p == '#') /* # Pc ; Pu; Px; Py; Pz */
-    {
+    } else if (*p == '$' || *p == '-') {
+      pix_x = 0;
+      rep = asp_x;
+
+      if (*p == '-') {
+        if (!init_width && width > cur_width && cur_width > 0) {
+          int y;
+
+#ifdef DEBUG
+          bl_debug_printf("Sixel width is shrunk (%d -> %d)\n", width, cur_width);
+#endif
+
+          for (y = 1; y < cur_height; y++) {
+            memmove(pixels + y * cur_width * PIXEL_SIZE, pixels + y * width * PIXEL_SIZE,
+                    cur_width * PIXEL_SIZE);
+          }
+          memset(pixels + y * cur_width * PIXEL_SIZE, 0,
+                 (cur_height * (width - cur_width) * PIXEL_SIZE));
+
+          width = cur_width;
+          stride = width * PIXEL_SIZE;
+          init_width = 1;
+        }
+
+        pix_y += 6;
+      }
+    } else if (*p == '#') /* # Pc ; Pu; Px; Py; Pz */ {
       if (*(++p) == '\0') {
 #ifdef DEBUG
         bl_debug_printf(BL_DEBUG_TAG " Illegal format.\n.");
@@ -508,12 +620,13 @@ body:
       }
 
       if (n > 4) {
+        u_int8_t rgb[3];
+
         if (params[1] == 1) {
           /* HLS */
           int h;
           u_int32_t l;
           u_int32_t s;
-          u_int8_t rgb[3];
 
           h = K_MIN(params[2], 360);
           l = K_MIN(params[3], 100);
@@ -552,17 +665,44 @@ body:
               }
             }
           }
-
-          palette[color] = (rgb[0] << 16) | (rgb[1] << 8) | rgb[2];
-        } else if (params[1] == 2) {
+        } else if (params[1] == 2
+#ifndef SIXEL_SHAREPALETTE
+                   || params[1] == 9 /* see vt_parser.c */
+#endif
+                   ) {
           /* RGB */
-          palette[color] =
-              SIXEL_RGB(K_MIN(params[2], 100), K_MIN(params[3], 100), K_MIN(params[4], 100));
+          rgb[0] = params[2] >= 100 ? 255 : params[2] * 255 / 100;
+          rgb[1] = params[3] >= 100 ? 255 : params[3] * 255 / 100;
+          rgb[2] = params[4] >= 100 ? 255 : params[4] * 255 / 100;
         } else {
           continue;
         }
 
-#ifndef SIXEL_1BPP
+#ifdef SIXEL_SHAREPALETTE
+        {
+          u_int8_t r, g, b;
+
+          /* fb/ui_display.h which defines ui_cmap_get_pixel_rgb() is included from ui_imagelib.c */
+          if (!ui_cmap_get_pixel_rgb(&r, &g, &b, color) ||
+              abs(r - rgb[0]) >= 0x10 || abs(g - rgb[1]) >= 0x10 || abs(b - rgb[2]) >= 0x10) {
+            u_long closest;
+
+            /*
+             * fb/ui_display.h which defines ui_cmap_get_closest_color() is included
+             * from ui_imagelib.c
+             */
+            if (ui_cmap_get_closest_color(&closest, rgb[0], rgb[1], rgb[2])) {
+              color_indexes[color] = closest;
+            } else {
+              goto error;
+            }
+          }
+        }
+#else
+        palette[color] = (rgb[0] << 16) | (rgb[1] << 8) | rgb[2];
+#endif
+
+#if !defined(SIXEL_1BPP) && !defined(SIXEL_SHAREPALETTE)
         if (palette == custom_palette && palette[256] <= color) {
           /*
            * Set max active palette number for NetBSD/OpenBSD.
@@ -576,86 +716,46 @@ body:
         bl_debug_printf(BL_DEBUG_TAG " Set rgb %x for color %d.\n", palette[color], color);
 #endif
       }
-    } else if (*p == '$' || *p == '-') {
-      pix_x = 0;
-      rep = asp_x;
-
-      if (!init_width && width > cur_width && cur_width > 0) {
-        int y;
-
+    } else if (*p == '"') /* " Pan ; Pad ; Ph ; Pv */ {
+      if (*(++p) == '\0') {
 #ifdef DEBUG
-        bl_debug_printf("Sixel width is shrunk (%d -> %d)\n", width, cur_width);
+        bl_debug_printf(BL_DEBUG_TAG " Illegal format.\n.");
 #endif
-
-        for (y = 1; y < cur_height; y++) {
-          memmove(pixels + y * cur_width * PIXEL_SIZE, pixels + y * width * PIXEL_SIZE,
-                  cur_width * PIXEL_SIZE);
-        }
-        memset(pixels + y * cur_width * PIXEL_SIZE, 0,
-               (cur_height * (width - cur_width) * PIXEL_SIZE));
-
-        width = cur_width;
-        init_width = 1;
-      }
-
-      if (*p == '-') {
-        pix_y += 6;
-      }
-    } else if (*p >= '?' && *p <= '\x7E') {
-      u_int new_width;
-      u_int new_height;
-      int a;
-      int b;
-      int y;
-
-      if (!realloc_pixels(&pixels, (new_width = width < pix_x + rep ? width + 512 : width),
-                          (new_height = height < pix_y + 6 ? height + 512 : height), width,
-                          height)) {
         break;
       }
 
-      width = new_width;
-      height = new_height;
+      if ((n = get_params(params, 4, &p)) == 1) {
+        params[1] = 1;
+        n = 2;
+      }
 
-      b = *p - '?';
-      a = 0x01;
-
-      for (y = 0; y < 6; y++) {
-        if ((b & a) != 0) {
-          int x;
-
-          for (x = 0; x < rep; x++) {
-#if defined(GDK_PIXBUF_VERSION) || defined(USE_QUARTZ)
-            /* RGBA */
-            pixels[((pix_y + y) * width + pix_x + x) * PIXEL_SIZE] = (palette[color] >> 16) & 0xff;
-            pixels[((pix_y + y) * width + pix_x + x) * PIXEL_SIZE + 1] =
-                (palette[color] >> 8) & 0xff;
-            pixels[((pix_y + y) * width + pix_x + x) * PIXEL_SIZE + 2] = (palette[color]) & 0xff;
-            pixels[((pix_y + y) * width + pix_x + x) * PIXEL_SIZE + 3] = 0xff;
-#elif defined(SIXEL_1BPP)
-            /* 0x80 is opaque mark */
-            ((pixel_t*)pixels)[(pix_y + y) * width + pix_x + x] = 0x80 | palette[color];
+/* XXX ignored */
+#if 0
+      switch (n) {
+      case 4:
+        height = params[3];
+      case 3:
+        width = params[2];
+        /* XXX realloc_pixels() is necessary here. */
+        stride = width * PIXEL_SIZE;
+      case 2:
+/* V:H=params[0]:params[1] */
+#if 0
+        asp_x = params[1];
+        asp_y = params[0];
 #else
-            /* ARGB (cardinal) */
-            ((pixel_t*)pixels)[(pix_y + y) * width + pix_x + x] = 0xff000000 | palette[color];
-#endif
-          }
+        rep /= asp_x;
+        if ((asp_x = params[1] / params[0]) == 0) {
+          asp_x = 1; /* XXX */
         }
-
-        a <<= 1;
+        rep *= asp_x;
+#endif
       }
 
-      pix_x += rep;
-
-      if (cur_width < pix_x) {
-        cur_width = pix_x;
+      if (asp_x <= 0) {
+        asp_x = 1;
       }
-
-      if (cur_height < pix_y + 6) {
-        cur_height = pix_y + 6;
-      }
-
-      rep = asp_x;
+#endif
     } else if (*p == '\x1b') {
       if (*(++p) == '\\') {
 #ifdef DEBUG
@@ -684,31 +784,46 @@ body:
   }
 
 end:
-  free(file_data);
-
-#ifndef SIXEL_1BPP
+#if !defined(SIXEL_1BPP) && !defined(SIXEL_SHAREPALETTE)
   custom_palette = NULL;
 #endif
 
-  if (cur_width == 0 || !realloc_pixels(&pixels, cur_width, cur_height, width, height)) {
-#ifdef DEBUG
-    bl_debug_printf(BL_DEBUG_TAG " Nothing is drawn.\n");
-#endif
+  if (cur_width > 0 && realloc_pixels(&pixels, cur_width, cur_height, width, height)) {
+    correct_height((pixel_t*)pixels, cur_width, &cur_height);
 
-    free(pixels - CARD_HEAD_SIZE);
+    *width_ret = cur_width;
+    *height_ret = cur_height;
 
-    return NULL;
+    return pixels;
   }
 
-  correct_height((pixel_t*)pixels, cur_width, &cur_height);
+#ifdef DEBUG
+  bl_debug_printf(BL_DEBUG_TAG " Nothing is drawn.\n");
+#endif
 
-  *width_ret = cur_width;
-  *height_ret = cur_height;
+#ifdef SIXEL_SHAREPALETTE
+error:
+#endif
+  free(pixels - CARD_HEAD_SIZE);
 
-  return pixels;
+  return NULL;
 }
 
-#ifndef SIXEL_1BPP
+#if !defined(SIXEL_1BPP) && !defined(SIXEL_SHAREPALETTE)
+
+static u_char *load_sixel_from_file(const char *path, u_int *width_ret, u_int *height_ret) {
+  char *file_data;
+  u_char *pixels;
+
+  if ((file_data = read_sixel_file(path))) {
+    pixels = load_sixel_from_data(file_data, width_ret, height_ret);
+    free(file_data);
+
+    return pixels;
+  } else {
+    return NULL;
+  }
+}
 
 pixel_t *ui_set_custom_sixel_palette(pixel_t *palette /* NULL -> Create new palette */
                                      ) {
@@ -723,7 +838,7 @@ pixel_t *ui_set_custom_sixel_palette(pixel_t *palette /* NULL -> Create new pale
 
 #undef realloc_pixels
 #undef correct_height
-#undef load_sixel_from_file
+#undef load_sixel_from_data
 #undef SIXEL_RGB
 #undef CARD_HEAD_SIZE
 #undef pixel_t
