@@ -299,7 +299,7 @@ static kbd_type_t find_kbd_type(char *locale) {
  * methods of ui_im_t
  */
 
-static int delete (ui_im_t *im) {
+static void delete(ui_im_t *im) {
   im_kbd_t *kbd;
 
   kbd = (im_kbd_t*)im;
@@ -330,8 +330,6 @@ static int delete (ui_im_t *im) {
 
     initialized = 0;
   }
-
-  return ref_count;
 }
 
 static int key_event_arabic_hebrew(ui_im_t *im, u_char key_char, KeySym ksym, XKeyEvent *event) {
@@ -678,14 +676,14 @@ im_info_t *im_kbd_get_info(char *locale, char *encoding) {
     return NULL;
   }
 
-  result->num_of_args = 13;
+  result->num_args = 13;
 
-  if (!(result->args = malloc(sizeof(char*) * result->num_of_args))) {
+  if (!(result->args = malloc(sizeof(char*) * result->num_args))) {
     free(result);
     return NULL;
   }
 
-  if (!(result->readable_args = malloc(sizeof(char*) * result->num_of_args))) {
+  if (!(result->readable_args = malloc(sizeof(char*) * result->num_args))) {
     free(result->args);
     free(result);
     return NULL;
