@@ -474,7 +474,7 @@ static char *serv_search(int sock, ef_conv_t *dic_conv, ef_parser_t *dic_parser,
   return strdup(buf + 1);
 }
 
-static void set_blocking(int fd, int nonblock) {
+static void set_nonblocking(int fd, int nonblock) {
 /* Non blocking */
 #ifdef USE_WIN32API
   u_long val = nonblock;
@@ -494,13 +494,13 @@ static int check_protocol_4(int sock) {
   char p;
   int count;
 
-  set_blocking(sock, 0);
+  set_nonblocking(sock, 0);
   send(sock, msg, sizeof(msg) - 1, 0);
 #ifndef USE_WIN32API
   fsync(sock);
 #endif
 
-  set_blocking(sock, 1);
+  set_nonblocking(sock, 1);
   count = 0;
   while (1) {
     if (recv(sock, &p, 1, 0) == 1) {
@@ -513,10 +513,14 @@ static int check_protocol_4(int sock) {
       }
 
       bl_usleep(1000);
+    } else {
+      /* recv() of winsock sets errno=ENOENT if skk server doesn't respond to msg. */
+      count = 10;
+      break;
     }
   }
 
-  set_blocking(sock, 0);
+  set_nonblocking(sock, 0);
 
   return (count != 10);
 }
@@ -568,6 +572,7 @@ static int connect_to_server(void) {
   return sock;
 
 error:
+  bl_msg_printf("Failed to connect to skk server (%s)\n", serv);
   closesocket(sock);
 
   return -1;
@@ -623,10 +628,10 @@ static void unconcat(char *str) {
   }
 }
 
-static int candidate_exists(const char **cands, u_int num_of_cands, const char *cand) {
+static int candidate_exists(const char **cands, u_int num_cands, const char *cand) {
   u_int count;
 
-  for (count = 0; count < num_of_cands; count++) {
+  for (count = 0; count < num_cands; count++) {
     if (strcmp(cands[count], cand) == 0) {
       return 1;
     }
@@ -690,6 +695,7 @@ static table_t global_tables[MAX_TABLES];
 static char *global_data;
 static size_t global_data_size;
 static int global_sock = -1;
+static int global_is_loaded = 0;
 static int server_supports_protocol_4 = 0;
 static ef_conv_t *global_conv;
 static ef_parser_t *global_parser;
@@ -703,17 +709,15 @@ static ef_parser_t *local_parser;
 /* --- static variables --- */
 
 static int global_dict_load(void) {
-  static int is_loaded;
-
   if (!global_conv) {
     global_conv = (*syms->vt_char_encoding_conv_new)(VT_EUCJP);
     global_parser = (*syms->vt_char_encoding_parser_new)(VT_EUCJP);
   }
 
-  if (!is_loaded && !global_data && global_sock == -1) {
+  if (!global_is_loaded && !global_data && global_sock == -1) {
     char *path;
 
-    is_loaded = 1;
+    global_is_loaded = 1;
 
     if (global_dict && (path = strdup(global_dict))) {
       global_data = file_load(&global_data_size, global_tables, path);
@@ -1283,14 +1287,23 @@ int dict_candidate_add_to_local(void *aux) {
 void dict_set_global(char *dict) {
   size_t len;
 
-  free(global_dict);
+  if (global_dict) {
+    if (strcmp(dict, global_dict) == 0) {
+      return;
+    }
+
+    free(global_dict);
+  }
+
   global_dict = strdup(dict);
 
   if (global_data) {
     file_unload(global_tables, global_data, global_data_size, NULL);
     free(global_data);
     global_data = NULL;
-  } else {
+  }
+
+  if (global_sock != -1) {
     closesocket(global_sock);
     global_sock = -1;
   }
