@@ -61,7 +61,10 @@ typedef struct im_skk {
 
   input_mode_t mode;
 
-  int is_editing_new_word;
+  int8_t sticky_shift;
+  int8_t start_candidate;
+
+  int8_t is_editing_new_word;
   ef_char_t new_word[MAX_CAPTION_LEN];
   u_int new_word_len;
 
@@ -80,6 +83,8 @@ typedef struct im_skk {
 
 ui_im_export_syms_t *syms = NULL; /* mlterm internal symbols */
 static int ref_count = 0;
+static KeySym sticky_shift_ksym;
+static int sticky_shift_ch;
 
 /* --- static functions --- */
 
@@ -201,7 +206,7 @@ static void preedit(im_skk_t *skk, ef_char_t *preedit, u_int preedit_len, int re
     }
 
     (*syms->vt_str_init)(skk->im.preedit.chars = p,
-                         skk->im.preedit.num_of_chars = (preedit_len + pos_len));
+                         skk->im.preedit.num_chars = (preedit_len + pos_len));
 
     skk->im.preedit.filled_len = 0;
     for (count = 0; count < preedit_len; count++) {
@@ -227,7 +232,7 @@ static void preedit(im_skk_t *skk, ef_char_t *preedit, u_int preedit_len, int re
         is_comb = 1;
 
         if ((*syms->vt_char_combine)(p - 1, ef_char_to_int(&ch), ch.cs, is_fullwidth, is_comb,
-                                     VT_FG_COLOR, VT_BG_COLOR, 0, 0, 1, 0, 0, 0)) {
+                                     VT_FG_COLOR, VT_BG_COLOR, 0, 0, LS_UNDERLINE_SINGLE, 0, 0)) {
           continue;
         }
 
@@ -240,10 +245,10 @@ static void preedit(im_skk_t *skk, ef_char_t *preedit, u_int preedit_len, int re
 
       if (rev_pos <= skk->im.preedit.filled_len && skk->im.preedit.filled_len < rev_pos + rev_len) {
         (*syms->vt_char_set)(p, ef_char_to_int(&ch), ch.cs, is_fullwidth, is_comb, VT_BG_COLOR,
-                             VT_FG_COLOR, 0, 0, 1, 0, 0, 0);
+                             VT_FG_COLOR, 0, 0, LS_UNDERLINE_SINGLE, 0, 0);
       } else {
         (*syms->vt_char_set)(p, ef_char_to_int(&ch), ch.cs, is_fullwidth, is_comb, VT_FG_COLOR,
-                             VT_BG_COLOR, 0, 0, 1, 0, 0, 0);
+                             VT_BG_COLOR, 0, 0, LS_UNDERLINE_SINGLE, 0, 0);
       }
 
       p++;
@@ -251,8 +256,8 @@ static void preedit(im_skk_t *skk, ef_char_t *preedit, u_int preedit_len, int re
     }
 
     for (; pos_len > 0; pos_len--) {
-      (*syms->vt_char_set)(p++, *(pos++), US_ASCII, 0, 0, VT_FG_COLOR, VT_BG_COLOR, 0, 0, 1,
-                           0, 0, 0);
+      (*syms->vt_char_set)(p++, *(pos++), US_ASCII, 0, 0, VT_FG_COLOR, VT_BG_COLOR, 0, 0,
+                           LS_UNDERLINE_SINGLE, 0, 0);
       skk->im.preedit.filled_len++;
     }
   }
@@ -573,7 +578,7 @@ static void insert_alphabet_full(im_skk_t *skk, u_char key_char) {
  * methods of ui_im_t
  */
 
-static int delete (ui_im_t *im) {
+static void delete(ui_im_t *im) {
   im_skk_t *skk;
 
   skk = (im_skk_t*)im;
@@ -607,8 +612,6 @@ static int delete (ui_im_t *im) {
 #ifdef IM_SKK_DEBUG
   bl_debug_printf(BL_DEBUG_TAG " An object was deleted. ref_count: %d\n", ref_count);
 #endif
-
-  return ref_count;
 }
 
 static int switch_mode(ui_im_t *im) {
@@ -815,10 +818,35 @@ static int key_event(ui_im_t *im, u_char key_char, KeySym ksym, XKeyEvent *event
     if (!skk->is_enabled) {
       return 0;
     }
+
+    goto end;
   } else if (!skk->is_enabled) {
     return 1;
-  } else if ((skk->mode != ALPHABET && key_char == 'l') ||
-             (skk->mode != ALPHABET_FULL && key_char == 'L')) {
+  }
+
+  /* skk is enabled */
+
+  if (skk->mode != ALPHABET && skk->mode != ALPHABET_FULL) {
+    if (sticky_shift_ch ? (key_char == sticky_shift_ch) :
+                          (sticky_shift_ksym ? (ksym == sticky_shift_ksym) : 0)) {
+      if (skk->sticky_shift) {
+        skk->sticky_shift = 0;
+      } else {
+        skk->sticky_shift = 1;
+
+        return 0;
+      }
+    } else if (skk->sticky_shift) {
+      if ('a' <= key_char && key_char <= 'z') {
+        key_char -= 0x20;
+      }
+      event->state |= ShiftMask;
+      skk->sticky_shift = 0;
+    }
+  }
+
+  if ((skk->mode != ALPHABET && key_char == 'l') ||
+      (skk->mode != ALPHABET_FULL && key_char == 'L')) {
     if (!skk->is_editing_new_word) {
       fix(skk);
     }
@@ -968,11 +996,8 @@ static int key_event(ui_im_t *im, u_char key_char, KeySym ksym, XKeyEvent *event
       }
 
       step = 0;
+      skk->start_candidate = 1;
     } else {
-      if (!skk->im.cand_screen) {
-        update = 1;
-      }
-
       dict_candidate_get_state(skk->candidate, &cur_index, &num);
 
       if (ksym == XK_Left) {
@@ -1002,12 +1027,12 @@ static int key_event(ui_im_t *im, u_char key_char, KeySym ksym, XKeyEvent *event
           } else {
             update = 1;
           }
-        } else {
-          if (cur_index % CAND_UNIT == CAND_UNIT - 1) {
-            update = 1;
-          }
+        } else if ((cur_index % CAND_UNIT == CAND_UNIT - 1) || skk->start_candidate) {
+          update = 1;
         }
       }
+
+      skk->start_candidate = 0;
     }
 
     preedited_alphabet = (skk->mode == ALPHABET && skk->is_preediting);
@@ -1056,8 +1081,8 @@ static void focused(ui_im_t *im) {
 
   skk = (im_skk_t*)im;
 
-  if (skk->im.cand_screen) {
-    (*skk->im.cand_screen->show)(skk->im.cand_screen);
+  if (skk->im.stat_screen) {
+    (*skk->im.stat_screen->show)(skk->im.stat_screen);
   }
 }
 
@@ -1066,17 +1091,34 @@ static void unfocused(ui_im_t *im) {
 
   skk = (im_skk_t*)im;
 
-  if (skk->im.cand_screen) {
-    (*skk->im.cand_screen->hide)(skk->im.cand_screen);
+  if (skk->im.stat_screen) {
+    (*skk->im.stat_screen->hide)(skk->im.stat_screen);
   }
 }
 
+static void set_sticky_shift_key(char *key) {
+  int digit;
+  if (strlen(key) == 1) {
+    sticky_shift_ch = *key;
+  } else if (sscanf(key, "\\x%x", &digit) == 1) {
+    sticky_shift_ch = digit;
+  } else {
+    sticky_shift_ksym = (*syms->XStringToKeysym)(key);
+    sticky_shift_ch = 0;
+
+    return;
+  }
+
+  sticky_shift_ksym = 0;
+}
+
 /* --- global functions --- */
 
 ui_im_t *im_skk_new(u_int64_t magic, vt_char_encoding_t term_encoding,
-                    ui_im_export_syms_t *export_syms, char *engine, u_int mod_ignore_mask) {
+                    ui_im_export_syms_t *export_syms, char *options, u_int mod_ignore_mask) {
   im_skk_t *skk;
   ef_parser_t *parser;
+  char *env;
 
   if (magic != (u_int64_t)IM_API_COMPAT_CHECK_MAGIC) {
     bl_error_printf("Incompatible input method API.\n");
@@ -1096,8 +1138,37 @@ ui_im_t *im_skk_new(u_int64_t magic, vt_char_encoding_t term_encoding,
     goto error;
   }
 
-  if (engine) {
-    dict_set_global(engine);
+  if ((env = getenv("SKK_DICTIONARY"))) {
+    dict_set_global(env);
+  }
+
+  if ((env = getenv("SKK_STICKY_SHIFT_KEY"))) {
+    set_sticky_shift_key(env);
+  }
+
+  /* Same processing as skk_widget_new() in mc_im.c */
+  if (options) {
+#if 1
+    /* XXX Compat with 3.8.3 or before. */
+    if (!strchr(options, '=')) {
+      dict_set_global(options);
+    } else
+#endif
+    {
+      char *next;
+
+      do {
+        if ((next = strchr(options, ','))) {
+          *(next++) = '\0';
+        }
+
+        if (strncmp(options, "sskey=", 6) == 0) {
+          set_sticky_shift_key(options + 6);
+        } else if (strncmp(options, "dict=", 5) == 0) {
+          dict_set_global(options + 5);
+        }
+      } while ((options = next));
+    }
   }
 
   skk->term_encoding = term_encoding;
@@ -1179,7 +1250,7 @@ im_info_t *im_skk_get_info(char *locale, char *encoding) {
   if ((result = malloc(sizeof(im_info_t)))) {
     result->id = strdup("skk");
     result->name = strdup("Skk");
-    result->num_of_args = 0;
+    result->num_args = 0;
     result->args = NULL;
     result->readable_args = NULL;
   }
