@@ -222,7 +222,7 @@ static int window_scroll_upward_region(void *p, int beg_row, int end_row, u_int
                           "linesScrolledOut", "(I)V");
   }
 
-  if (nativeObj->listener && beg_row == 0 &&
+  if (nativeObj->listener && beg_row == 0 && !vt_term_has_status_line(nativeObj->term) &&
       end_row + 1 == vt_term_get_logical_rows(nativeObj->term) &&
       !vt_screen_is_alternative_edit(nativeObj->term->screen)) {
     (*nativeObj->env)->CallVoidMethod(nativeObj->env, nativeObj->listener, mid, size);
@@ -286,8 +286,7 @@ static int need_style(vt_char_t *ch, vt_char_t *prev_ch) {
   int need_style;
 
   if (vt_char_fg_color(ch) != VT_FG_COLOR || vt_char_bg_color(ch) != VT_BG_COLOR ||
-      vt_char_underline_style(ch) || vt_char_is_crossed_out(ch) ||
-      (vt_char_font(ch) & (FONT_BOLD | FONT_ITALIC))) {
+      vt_char_line_style(ch) || (vt_char_font(ch) & (FONT_BOLD | FONT_ITALIC))) {
     need_style = 2;
   } else {
     need_style = 0;
@@ -295,8 +294,7 @@ static int need_style(vt_char_t *ch, vt_char_t *prev_ch) {
 
   if (prev_ch && vt_char_fg_color(ch) == vt_char_fg_color(prev_ch) &&
       vt_char_bg_color(ch) == vt_char_bg_color(prev_ch) &&
-      vt_char_underline_style(ch) == vt_char_underline_style(prev_ch) &&
-      vt_char_is_crossed_out(ch) == vt_char_is_crossed_out(prev_ch) &&
+      vt_char_line_style(ch) == vt_char_line_style(prev_ch) &&
       (vt_char_font(ch) & (FONT_BOLD | FONT_ITALIC)) ==
           (vt_char_font(prev_ch) & (FONT_BOLD | FONT_ITALIC))) {
     if (need_style) {
@@ -308,7 +306,7 @@ static int need_style(vt_char_t *ch, vt_char_t *prev_ch) {
   return need_style;
 }
 
-static u_int get_num_of_filled_chars_except_spaces(vt_line_t *line) {
+static u_int get_num_filled_chars_except_sp(vt_line_t *line) {
   if (vt_line_is_empty(line)) {
     return 0;
   } else {
@@ -428,6 +426,7 @@ Java_mlterm_MLTermPty_nativeOpen(JNIEnv *env, jobject obj, jstring jstr_host,
   static int logging_vt_seq;
   static int use_local_echo;
   static int use_auto_detect;
+  static int use_ansi_colors;
   static char *public_key;
   static char *private_key;
   static char **default_argv;
@@ -461,7 +460,7 @@ Java_mlterm_MLTermPty_nativeOpen(JNIEnv *env, jobject obj, jstring jstr_host,
   if (!str_parser) {
     bl_conf_t *conf;
 
-    bl_init_prog("mlterm", "3.8.3");
+    bl_init_prog("mlterm", "3.8.4");
     bl_set_sys_conf_dir(CONFIG_PATH);
     bl_locale_init("");
     bl_sig_child_init();
@@ -492,9 +491,8 @@ Java_mlterm_MLTermPty_nativeOpen(JNIEnv *env, jobject obj, jstring jstr_host,
     use_multi_col_char = 1;
 #ifdef USE_LOCAL_ECHO_BY_DEFAULT
     use_local_echo = 1;
-#else
-    use_local_echo = 0;
 #endif
+    use_ansi_colors = 1;
 
     if ((conf = bl_conf_new())) {
       char *rcpath;
@@ -595,7 +593,7 @@ Java_mlterm_MLTermPty_nativeOpen(JNIEnv *env, jobject obj, jstring jstr_host,
 
       if ((value = bl_conf_get_value(conf, "use_ansi_colors"))) {
         if (strcmp(value, "false") == 0) {
-          vt_set_use_ansi_colors(0);
+          use_ansi_colors = 0;
         }
       }
 
@@ -697,7 +695,7 @@ Java_mlterm_MLTermPty_nativeOpen(JNIEnv *env, jobject obj, jstring jstr_host,
             logging_vt_seq, unicode_policy, col_size_a, use_char_combining, use_multi_col_char,
             0 /* use_ctl */, 0 /* bidi_mode */, NULL /* bidi_separators */,
             0 /* use_dynamic_comb */, BSM_STATIC, 0 /* vertical_mode */, use_local_echo, NULL, NULL,
-            0 /* alt_color_mode */, 0 /* use_ot_layout */, 0 /* cursor_style */,
+            use_ansi_colors, 0 /* alt_color_mode */, 0 /* use_ot_layout */, 0 /* cursor_style */,
             0 /* ignore_broadcasted_chars */))) {
     goto error;
   }
@@ -867,25 +865,25 @@ JNIEXPORT jboolean JNICALL Java_mlterm_MLTermPty_waitForReading(JNIEnv *env, jcl
 #else
   u_int count;
   vt_term_t **terms;
-  u_int num_of_terms;
+  u_int num_terms;
   int maxfd;
   int ptyfd;
   fd_set read_fds;
 #ifdef USE_LIBSSH2
   struct timeval tval;
   int *xssh_fds;
-  u_int num_of_xssh_fds;
+  u_int num_xssh_fds;
 #endif
 
   vt_close_dead_terms();
-  num_of_terms = vt_get_all_terms(&terms);
+  num_terms = vt_get_all_terms(&terms);
 
-  if (num_of_terms == 0) {
+  if (num_terms == 0) {
     return JNI_FALSE;
   }
 
 #ifdef USE_LIBSSH2
-  num_of_xssh_fds = vt_pty_ssh_get_x11_fds(&xssh_fds);
+  num_xssh_fds = vt_pty_ssh_get_x11_fds(&xssh_fds);
 #endif
 
   while (1) {
@@ -898,7 +896,7 @@ JNIEXPORT jboolean JNICALL Java_mlterm_MLTermPty_waitForReading(JNIEnv *env, jcl
     maxfd = 0;
     FD_ZERO(&read_fds);
 
-    for (count = 0; count < num_of_terms; count++) {
+    for (count = 0; count < num_terms; count++) {
       ptyfd = vt_term_get_master_fd(terms[count]);
       FD_SET(ptyfd, &read_fds);
 
@@ -908,7 +906,7 @@ JNIEXPORT jboolean JNICALL Java_mlterm_MLTermPty_waitForReading(JNIEnv *env, jcl
     }
 
 #ifdef USE_LIBSSH2
-    for (count = 0; count < num_of_xssh_fds; count++) {
+    for (count = 0; count < num_xssh_fds; count++) {
       FD_SET(xssh_fds[count], &read_fds);
 
       if (xssh_fds[count] > maxfd) {
@@ -973,24 +971,24 @@ JNIEXPORT jboolean JNICALL Java_mlterm_MLTermPty_nativeRead(JNIEnv *env, jobject
     if (ret) {
 #if 0 /* #ifdef  TUNEUP_HACK */
       u_int row;
-      u_int num_of_skip;
-      u_int num_of_rows;
-      u_int num_of_mod;
+      u_int num_skip;
+      u_int num_rows;
+      u_int num_mod;
       int prev_is_modified;
       vt_line_t *line;
 
       prev_is_modified = 0;
-      num_of_skip = 0;
-      num_of_mod = 0;
-      num_of_rows = vt_term_get_rows(nativeObj->term);
-      for (row = 0; row < num_of_rows; row++) {
+      num_skip = 0;
+      num_mod = 0;
+      num_rows = vt_term_get_rows(nativeObj->term);
+      for (row = 0; row < num_rows; row++) {
         if ((line = vt_term_get_line(nativeObj->term, row)) && vt_line_is_modified(line)) {
           if (!prev_is_modified) {
-            num_of_skip++;
+            num_skip++;
           }
           prev_is_modified = 1;
 
-          num_of_mod++;
+          num_mod++;
         } else if (prev_is_modified) {
           prev_is_modified = 0;
         }
@@ -1000,8 +998,8 @@ JNIEXPORT jboolean JNICALL Java_mlterm_MLTermPty_nativeRead(JNIEnv *env, jobject
        * If 80% of lines are modified, set modified flag to all lines
        * to decrease the number of calling replaceTextRange().
        */
-      if (num_of_skip > 2 && num_of_mod * 5 / 4 > num_of_rows) {
-        for (row = 0; row < num_of_rows; row++) {
+      if (num_skip > 2 && num_mod * 5 / 4 > num_rows) {
+        for (row = 0; row < num_rows; row++) {
           if ((line = vt_term_get_line(nativeObj->term, row))) {
             vt_line_set_modified_all(line);
           }
@@ -1184,15 +1182,15 @@ JNIEXPORT jboolean JNICALL Java_mlterm_MLTermPty_nativeGetRedrawString(JNIEnv *e
                                                                        jlong nativeObj, jint row,
                                                                        jobject region) {
   vt_line_t *line;
-  char *buf;
+  u_char *buf;
   size_t buf_len;
   int mod_beg;
-  u_int num_of_chars;
+  u_int num_chars;
   u_int count;
   u_int start;
   size_t redraw_len;
   jobject *styles;
-  u_int num_of_styles;
+  u_int num_styles;
   static jfieldID region_str;
   static jfieldID region_start;
   static jfieldID region_styles;
@@ -1226,20 +1224,20 @@ JNIEXPORT jboolean JNICALL Java_mlterm_MLTermPty_nativeGetRedrawString(JNIEnv *e
 
   mod_beg = vt_line_get_beg_of_modified(line);
 #if 0
-  num_of_chars = vt_line_get_num_of_redrawn_chars(line, 1 /* to end */);
+  num_chars = vt_line_get_num_redrawn_chars(line, 1 /* to end */);
 #else
-  if ((num_of_chars = get_num_of_filled_chars_except_spaces(line)) >= mod_beg) {
-    num_of_chars -= mod_beg;
+  if ((num_chars = get_num_filled_chars_except_sp(line)) >= mod_beg) {
+    num_chars -= mod_beg;
   } else {
-    num_of_chars = 0;
+    num_chars = 0;
   }
 #endif
 
-  buf_len = (mod_beg + num_of_chars) * sizeof(u_int16_t) * 2 /* SURROGATE_PAIR */
+  buf_len = (mod_beg + num_chars) * sizeof(u_int16_t) * 2 /* SURROGATE_PAIR */
             + 2 /* NULL */;
   buf = alloca(buf_len);
 
-  num_of_styles = 0;
+  num_styles = 0;
 
   if (mod_beg > 0) {
     (*str_parser->init)(str_parser);
@@ -1249,13 +1247,13 @@ JNIEXPORT jboolean JNICALL Java_mlterm_MLTermPty_nativeGetRedrawString(JNIEnv *e
     start = 0;
   }
 
-  if (num_of_chars > 0) {
+  if (num_chars > 0) {
     int prev_ch_was_added = 0;
 
-    styles = alloca(sizeof(jobject) * num_of_chars);
+    styles = alloca(sizeof(jobject) * num_chars);
     redraw_len = 0;
     (*str_parser->init)(str_parser);
-    for (count = 0; count < num_of_chars; count++) {
+    for (count = 0; count < num_chars; count++) {
       size_t len;
       int ret;
 
@@ -1280,13 +1278,14 @@ JNIEXPORT jboolean JNICALL Java_mlterm_MLTermPty_nativeGetRedrawString(JNIEnv *e
 
       if (ret == 1) {
         (*env)->SetIntField(
-            env, styles[num_of_styles - 1], style_length,
-            (*env)->GetIntField(env, styles[num_of_styles - 1], style_length) + len / 2);
+            env, styles[num_styles - 1], style_length,
+            (*env)->GetIntField(env, styles[num_styles - 1], style_length) + len / 2);
       } else if (ret == 2) {
         vt_color_t color;
         u_int8_t red;
         u_int8_t green;
         u_int8_t blue;
+        int line_style;
 
         if (!style_class) {
           style_class = (*env)->NewGlobalRef(env, (*env)->FindClass(env, "mlterm/Style"));
@@ -1302,42 +1301,42 @@ JNIEXPORT jboolean JNICALL Java_mlterm_MLTermPty_nativeGetRedrawString(JNIEnv *e
           style_italic = (*env)->GetFieldID(env, style_class, "italic", "Z");
         }
 
-        styles[num_of_styles++] = (*env)->AllocObject(env, style_class);
+        styles[num_styles++] = (*env)->AllocObject(env, style_class);
 
-        (*env)->SetIntField(env, styles[num_of_styles - 1], style_length, len / 2);
+        (*env)->SetIntField(env, styles[num_styles - 1], style_length, len / 2);
 
-        (*env)->SetIntField(env, styles[num_of_styles - 1], style_start, redraw_len / 2);
+        (*env)->SetIntField(env, styles[num_styles - 1], style_start, redraw_len / 2);
 
         color = vt_char_fg_color(line->chars + mod_beg + count);
-        (*env)->SetIntField(env, styles[num_of_styles - 1], style_fg_color, color);
-        (*env)->SetIntField(env, styles[num_of_styles - 1], style_fg_pixel,
+        (*env)->SetIntField(env, styles[num_styles - 1], style_fg_color, color);
+        (*env)->SetIntField(env, styles[num_styles - 1], style_fg_pixel,
                             /* return -1(white) for invalid color. */
                             vt_get_color_rgba(color, &red, &green, &blue, NULL)
                                 ? ((red << 16) | (green << 8) | blue)
                                 : -1);
 
         color = vt_char_bg_color(line->chars + mod_beg + count);
-        (*env)->SetIntField(env, styles[num_of_styles - 1], style_bg_color, color);
-        (*env)->SetIntField(env, styles[num_of_styles - 1], style_bg_pixel,
+        (*env)->SetIntField(env, styles[num_styles - 1], style_bg_color, color);
+        (*env)->SetIntField(env, styles[num_styles - 1], style_bg_pixel,
                             /* return -1(white) for invalid color. */
                             vt_get_color_rgba(color, &red, &green, &blue, NULL)
                                 ? ((red << 16) | (green << 8) | blue)
                                 : -1);
 
-        (*env)->SetBooleanField(
-            env, styles[num_of_styles - 1], style_underline,
-            vt_char_underline_style(line->chars + mod_beg + count) ? JNI_TRUE : JNI_FALSE);
+        line_style = vt_char_line_style(line->chars + mod_beg + count);
+
+        (*env)->SetBooleanField(env, styles[num_styles - 1], style_underline,
+                                (line_style & LS_UNDERLINE_SINGLE) ? JNI_TRUE : JNI_FALSE);
+
+        (*env)->SetBooleanField(env, styles[num_styles - 1], style_strikeout,
+                                (line_style & LS_CROSSED_OUT) ? JNI_TRUE : JNI_FALSE);
 
         (*env)->SetBooleanField(
-            env, styles[num_of_styles - 1], style_strikeout,
-            vt_char_is_crossed_out(line->chars + mod_beg + count) ? JNI_TRUE : JNI_FALSE);
-
-        (*env)->SetBooleanField(
-            env, styles[num_of_styles - 1], style_bold,
+            env, styles[num_styles - 1], style_bold,
             vt_char_font(line->chars + mod_beg + count) & FONT_BOLD ? JNI_TRUE : JNI_FALSE);
 
         (*env)->SetBooleanField(
-            env, styles[num_of_styles - 1], style_italic,
+            env, styles[num_styles - 1], style_italic,
             vt_char_font(line->chars + mod_beg + count) & FONT_ITALIC ? JNI_TRUE : JNI_FALSE);
       }
 
@@ -1358,11 +1357,11 @@ JNIEXPORT jboolean JNICALL Java_mlterm_MLTermPty_nativeGetRedrawString(JNIEnv *e
   (*env)->SetObjectField(env, region, region_str, ((*env)->NewString)(env, buf, redraw_len / 2));
   (*env)->SetIntField(env, region, region_start, start);
 
-  if (num_of_styles > 0) {
+  if (num_styles > 0) {
     u_int count;
 
-    array = (*env)->NewObjectArray(env, num_of_styles, style_class, styles[0]);
-    for (count = 1; count < num_of_styles; count++) {
+    array = (*env)->NewObjectArray(env, num_styles, style_class, styles[0]);
+    for (count = 1; count < num_styles; count++) {
       (*env)->SetObjectArrayElement(env, array, count, styles[count]);
     }
   } else {
