@@ -3,6 +3,7 @@
 #include <stdio.h> /* sprintf */
 #include <gtk/gtk.h>
 #include <glib.h>
+#include <pobl/bl_mem.h>
 #include <pobl/bl_debug.h>
 #include <pobl/bl_str.h>
 
@@ -28,6 +29,8 @@
 #include "mc_radio.h"
 #include "mc_char_width.h"
 #include "mc_geometry.h"
+#include "mc_click.h"
+#include "mc_opentype.h"
 
 #if 0
 #define __DEBUG
@@ -35,6 +38,12 @@
 
 /* --- static functions --- */
 
+#ifdef DEBUG
+static void check_mem_leak(void) {
+  bl_mem_free_all();
+}
+#endif
+
 static void end_application(GtkWidget *widget, gpointer data) { gtk_main_quit(); }
 
 /*
@@ -42,6 +51,8 @@ static void end_application(GtkWidget *widget, gpointer data) { gtk_main_quit();
  */
 
 static int update(mc_io_t io) {
+  char *gui = mc_get_gui();
+
   mc_update_char_encoding();
   mc_update_auto_detect();
   mc_update_color(MC_COLOR_FG);
@@ -63,6 +74,8 @@ static int update(mc_io_t io) {
   mc_update_font_misc();
   mc_update_space(MC_SPACE_LINE);
   mc_update_space(MC_SPACE_LETTER);
+  mc_update_space(MC_SPACE_UNDERLINE);
+  mc_update_space(MC_SPACE_BASELINE);
   mc_update_ratio(MC_RATIO_SCREEN_WIDTH);
   mc_update_radio(MC_RADIO_MOD_META_MODE);
   mc_update_radio(MC_RADIO_BELL_MODE);
@@ -76,11 +89,15 @@ static int update(mc_io_t io) {
   mc_update_substitute_color();
   mc_update_ctl();
   mc_update_char_width();
+  mc_update_click_interval();
+  mc_update_opentype();
 
   mc_update_flag_mode(MC_FLAG_COMB);
   mc_update_flag_mode(MC_FLAG_DYNCOMB);
   mc_update_flag_mode(MC_FLAG_RECVUCS);
-  mc_update_flag_mode(MC_FLAG_CLIPBOARD);
+  if (strcmp(gui, "xlib") == 0) {
+    mc_update_flag_mode(MC_FLAG_CLIPBOARD);
+  }
   mc_update_flag_mode(MC_FLAG_LOCALECHO);
   mc_update_flag_mode(MC_FLAG_BLINKCURSOR);
   mc_update_flag_mode(MC_FLAG_STATICBACKSCROLL);
@@ -89,11 +106,12 @@ static int update(mc_io_t io) {
   mc_update_flag_mode(MC_FLAG_OTLAYOUT);
 
   mc_update_radio(MC_RADIO_SB_MODE);
-#ifndef USE_QUARTZ
-  mc_update_color(MC_COLOR_SBFG);
-  mc_update_color(MC_COLOR_SBBG);
-  mc_update_sb_view_name();
-#endif
+
+  if (strcmp(gui, "quartz") != 0) {
+    mc_update_color(MC_COLOR_SBFG);
+    mc_update_color(MC_COLOR_SBBG);
+    mc_update_sb_view_name();
+  }
 
   mc_flush(io);
 
@@ -322,7 +340,6 @@ static gint pty_button_clicked(GtkWidget *widget, gpointer data) {
   return 1;
 }
 
-#if defined(UES_WIN32GUI) || defined(USE_QUARTZ)
 static gboolean event(GtkWidget *widget, GdkEvent *event, gpointer data) {
   if (event->type == GDK_FOCUS_CHANGE && !((GdkEventFocus*)event)->in) {
     gtk_window_set_keep_above(GTK_WINDOW(widget), FALSE);
@@ -331,7 +348,6 @@ static gboolean event(GtkWidget *widget, GdkEvent *event, gpointer data) {
 
   return FALSE;
 }
-#endif
 
 /*
  *  ********  Building GUI (lower part, independent buttons)  ********
@@ -444,6 +460,7 @@ static int show(void) {
   GtkWidget *label;
   GtkWidget *config_widget;
   GtkWidget *separator;
+  char *gui = mc_get_gui();
 
   window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
   g_signal_connect(window, "destroy", G_CALLBACK(end_application), NULL);
@@ -521,7 +538,11 @@ static int show(void) {
   gtk_widget_show(config_widget);
   gtk_box_pack_start(GTK_BOX(vbox), config_widget, FALSE, FALSE, 0);
 
-  config_widget = mc_flag_config_widget_new(MC_FLAG_OTLAYOUT);
+  config_widget = mc_opentype_config_widget_new();
+  gtk_widget_show(config_widget);
+  gtk_box_pack_start(GTK_BOX(vbox), config_widget, FALSE, FALSE, 0);
+
+  config_widget = mc_char_width_config_widget_new();
   gtk_widget_show(config_widget);
   gtk_box_pack_start(GTK_BOX(vbox), config_widget, FALSE, FALSE, 0);
 
@@ -550,6 +571,14 @@ static int show(void) {
   gtk_widget_show(config_widget);
   gtk_box_pack_start(GTK_BOX(hbox), config_widget, FALSE, FALSE, 0);
 
+  config_widget = mc_space_config_widget_new(MC_SPACE_UNDERLINE);
+  gtk_widget_show(config_widget);
+  gtk_box_pack_start(GTK_BOX(vbox), config_widget, FALSE, FALSE, 0);
+
+  config_widget = mc_space_config_widget_new(MC_SPACE_BASELINE);
+  gtk_widget_show(config_widget);
+  gtk_box_pack_start(GTK_BOX(vbox), config_widget, FALSE, FALSE, 0);
+
   config_widget = mc_ratio_config_widget_new(MC_RATIO_SCREEN_WIDTH);
   gtk_widget_show(config_widget);
   gtk_box_pack_start(GTK_BOX(vbox), config_widget, FALSE, FALSE, 0);
@@ -637,23 +666,23 @@ static int show(void) {
   gtk_widget_show(config_widget);
   gtk_box_pack_start(GTK_BOX(vbox), config_widget, FALSE, FALSE, 0);
 
-#ifndef USE_QUARTZ
-  config_widget = mc_sb_view_config_widget_new();
-  gtk_widget_show(config_widget);
-  gtk_box_pack_start(GTK_BOX(vbox), config_widget, FALSE, FALSE, 0);
+  if (strcmp(gui, "quartz") != 0) {
+    config_widget = mc_sb_view_config_widget_new();
+    gtk_widget_show(config_widget);
+    gtk_box_pack_start(GTK_BOX(vbox), config_widget, FALSE, FALSE, 0);
 
-  hbox = gtk_hbox_new(FALSE, 0);
-  gtk_widget_show(hbox);
-  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
+    hbox = gtk_hbox_new(FALSE, 0);
+    gtk_widget_show(hbox);
+    gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
-  config_widget = mc_color_config_widget_new(MC_COLOR_SBFG);
-  gtk_widget_show(config_widget);
-  gtk_box_pack_start(GTK_BOX(hbox), config_widget, FALSE, FALSE, 5);
+    config_widget = mc_color_config_widget_new(MC_COLOR_SBFG);
+    gtk_widget_show(config_widget);
+    gtk_box_pack_start(GTK_BOX(hbox), config_widget, FALSE, FALSE, 5);
 
-  config_widget = mc_color_config_widget_new(MC_COLOR_SBBG);
-  gtk_widget_show(config_widget);
-  gtk_box_pack_start(GTK_BOX(hbox), config_widget, FALSE, FALSE, 0);
-#endif
+    config_widget = mc_color_config_widget_new(MC_COLOR_SBBG);
+    gtk_widget_show(config_widget);
+    gtk_box_pack_start(GTK_BOX(hbox), config_widget, FALSE, FALSE, 0);
+  }
 
   /* contents of the "Others" tab */
 
@@ -688,6 +717,10 @@ static int show(void) {
   gtk_widget_show(config_widget);
   gtk_box_pack_start(GTK_BOX(hbox), config_widget, FALSE, FALSE, 0);
 
+  config_widget = mc_click_interval_config_widget_new();
+  gtk_widget_show(config_widget);
+  gtk_box_pack_start(GTK_BOX(vbox), config_widget, FALSE, FALSE, 0);
+
   config_widget = mc_radio_config_widget_new(MC_RADIO_MOD_META_MODE);
   gtk_widget_show(config_widget);
   gtk_box_pack_start(GTK_BOX(vbox), config_widget, FALSE, FALSE, 0);
@@ -700,19 +733,15 @@ static int show(void) {
   gtk_widget_show(config_widget);
   gtk_box_pack_start(GTK_BOX(vbox), config_widget, FALSE, FALSE, 0);
 
-  config_widget = mc_char_width_config_widget_new();
-  gtk_widget_show(config_widget);
-  gtk_box_pack_start(GTK_BOX(vbox), config_widget, FALSE, FALSE, 0);
-
   hbox = gtk_hbox_new(FALSE, 0);
   gtk_widget_show(hbox);
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
-#ifndef USE_WIN32GUI
-  config_widget = mc_flag_config_widget_new(MC_FLAG_CLIPBOARD);
-  gtk_widget_show(config_widget);
-  gtk_box_pack_start(GTK_BOX(hbox), config_widget, FALSE, FALSE, 0);
-#endif
+  if (strcmp(gui, "xlib") == 0) {
+    config_widget = mc_flag_config_widget_new(MC_FLAG_CLIPBOARD);
+    gtk_widget_show(config_widget);
+    gtk_box_pack_start(GTK_BOX(hbox), config_widget, FALSE, FALSE, 0);
+  }
 
   config_widget = mc_flag_config_widget_new(MC_FLAG_LOCALECHO);
   gtk_widget_show(config_widget);
@@ -730,8 +759,20 @@ static int show(void) {
   gtk_widget_show(config_widget);
   gtk_box_pack_start(GTK_BOX(vbox), config_widget, FALSE, FALSE, 0);
 
+  hbox = gtk_hbox_new(FALSE, 0);
+  gtk_widget_show(hbox);
+  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
+
   config_widget = mc_flag_config_widget_new(MC_FLAG_REGARDURIASWORD);
   gtk_widget_show(config_widget);
+  gtk_box_pack_start(GTK_BOX(hbox), config_widget, FALSE, FALSE, 0);
+
+  config_widget = mc_flag_config_widget_new(MC_FLAG_BROADCAST);
+  gtk_widget_show(config_widget);
+  gtk_box_pack_start(GTK_BOX(hbox), config_widget, FALSE, FALSE, 0);
+
+  config_widget = mc_flag_config_widget_new(MC_FLAG_TRIMNEWLINE);
+  gtk_widget_show(config_widget);
   gtk_box_pack_start(GTK_BOX(vbox), config_widget, FALSE, FALSE, 0);
 
   gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_MOUSE);
@@ -741,10 +782,10 @@ static int show(void) {
 
   gtk_widget_show(window);
 
-#if defined(UES_WIN32GUI) || defined(USE_QUARTZ)
-  gtk_window_set_keep_above(GTK_WINDOW(window), TRUE);
-  g_signal_connect(window, "event", G_CALLBACK(event), NULL);
-#endif
+  if (strcmp(gui, "win32") == 0 || strcmp(gui, "quartz") == 0) {
+    gtk_window_set_keep_above(GTK_WINDOW(window), TRUE);
+    g_signal_connect(window, "event", G_CALLBACK(event), NULL);
+  }
 
   gtk_main();
 
@@ -754,6 +795,10 @@ static int show(void) {
 /* --- global functions --- */
 
 int main(int argc, char **argv) {
+#ifdef DEBUG
+  atexit(check_mem_leak);
+#endif
+
 #if !GTK_CHECK_VERSION(2, 90, 0)
   gtk_set_locale();
 #endif
