@@ -10,10 +10,12 @@
 #include <stdlib.h>    /* getenv */
 #include <termios.h>
 #include <signal.h>
-#include <time.h>
+#include <time.h>      /* time */
+#include <sys/time.h>  /* gettimeofday */
 #include <errno.h>
 #include <sys/select.h> /* select */
 
+#include <pobl/bl_def.h> /* HAVE_GETTIMEOFDAY */
 #include <pobl/bl_debug.h>
 #include <pobl/bl_privilege.h> /* bl_priv_change_e(u|g)id */
 #include <pobl/bl_unistd.h>    /* bl_getuid */
@@ -39,7 +41,7 @@
 /* --- static variables --- */
 
 static ui_display_t **displays;
-static u_int num_of_displays;
+static u_int num_displays;
 
 static struct termios orig_tm;
 
@@ -125,7 +127,7 @@ static void sig_winch(int sig) {
   /* XXX */
   ui_font_cache_unload_all();
 
-  for (count = 0; count < displays[0]->num_of_roots; count++) {
+  for (count = 0; count < displays[0]->num_roots; count++) {
     ui_window_resize_with_margin(displays[0]->roots[count], displays[0]->width, displays[0]->height,
                                  NOTIFY_TO_MYSELF);
   }
@@ -136,22 +138,22 @@ static void sig_winch(int sig) {
 static ui_display_t *open_display_socket(int fd) {
   void *p;
 
-  if (!(p = realloc(displays, sizeof(ui_display_t *) * (num_of_displays + 1)))) {
+  if (!(p = realloc(displays, sizeof(ui_display_t *) * (num_displays + 1)))) {
     return NULL;
   }
 
   displays = p;
 
-  if (!(displays[num_of_displays] = calloc(1, sizeof(ui_display_t))) ||
-      !(displays[num_of_displays]->display = calloc(1, sizeof(Display)))) {
-    free(displays[num_of_displays]);
+  if (!(displays[num_displays] = calloc(1, sizeof(ui_display_t))) ||
+      !(displays[num_displays]->display = calloc(1, sizeof(Display)))) {
+    free(displays[num_displays]);
 
     return NULL;
   }
 
-  if (!(displays[num_of_displays]->display->fp = fdopen(fd, "w"))) {
-    free(displays[num_of_displays]->display);
-    free(displays[num_of_displays]);
+  if (!(displays[num_displays]->display->fp = fdopen(fd, "w"))) {
+    free(displays[num_displays]->display);
+    free(displays[num_displays]);
 
     return NULL;
   }
@@ -169,12 +171,12 @@ static ui_display_t *open_display_socket(int fd) {
   write(fd, "\x1b[?1002h\x1b[?1006h", 16);
   write(fd, "\x1b[>c", 4);
 
-  displays[num_of_displays]->display->conv = vt_char_encoding_conv_new(encoding);
-  vt_char_encoding_conv_set_use_loose_rule(displays[num_of_displays]->display->conv, encoding, 1);
+  displays[num_displays]->display->conv = vt_char_encoding_conv_new(encoding);
+  vt_char_encoding_conv_set_use_loose_rule(displays[num_displays]->display->conv, encoding, 1);
 
-  set_winsize(displays[num_of_displays], "8;24;80;4;384;640t");
+  set_winsize(displays[num_displays], "8;24;80;4;384;640t");
 
-  return displays[num_of_displays++];
+  return displays[num_displays++];
 }
 
 static ui_display_t *open_display_console(void) {
@@ -182,7 +184,7 @@ static ui_display_t *open_display_console(void) {
   struct termios tio;
   int fd;
 
-  if (num_of_displays > 0 || !isatty(STDIN_FILENO) ||
+  if (num_displays > 0 || !isatty(STDIN_FILENO) ||
       !(p = realloc(displays, sizeof(ui_display_t *)))) {
     return NULL;
   }
@@ -240,7 +242,7 @@ static ui_display_t *open_display_console(void) {
 
   signal(SIGWINCH, sig_winch);
 
-  return displays[num_of_displays++];
+  return displays[num_displays++];
 }
 
 #ifdef __linux__
@@ -267,7 +269,7 @@ static int get_key_state(void) {
 static inline ui_window_t *get_window_intern(ui_window_t *win, int x, int y) {
   u_int count;
 
-  for (count = 0; count < win->num_of_children; count++) {
+  for (count = 0; count < win->num_children; count++) {
     ui_window_t *child;
 
     if ((child = win->children[count])->is_mapped) {
@@ -291,7 +293,7 @@ static inline ui_window_t *get_window(ui_display_t *disp, int x, /* X in display
 }
 
 /* XXX defined in console/ui_window.c */
-int ui_window_clear_margin_area(ui_window_t *win);
+void ui_window_clear_margin_area(ui_window_t *win);
 
 static void expose_window(ui_window_t *win, int x, int y, u_int width, u_int height) {
   if (x + width <= win->x || win->x + ACTUAL_WIDTH(win) < x || y + height <= win->y ||
@@ -344,7 +346,7 @@ static void expose_display(ui_display_t *disp, int x, int y, u_int width, u_int
 
   expose_window(disp->roots[0], x, y, width, height);
 
-  for (count = 0; count < disp->roots[0]->num_of_children; count++) {
+  for (count = 0; count < disp->roots[0]->num_children; count++) {
     expose_window(disp->roots[0]->children[count], x, y, width, height);
   }
 }
@@ -361,9 +363,9 @@ static int check_visibility_of_im_window(ui_display_t *disp) {
   int redraw_im_win = 0;
 
 #ifdef DEBUG
-  if (disp->num_of_roots > 2) {
+  if (disp->num_roots > 2) {
     bl_debug_printf(BL_DEBUG_TAG" Multiple IM Windows (%d) are activated.\n",
-                    disp->num_of_roots - 1);
+                    disp->num_roots - 1);
   }
 #endif
 
@@ -408,7 +410,7 @@ static void receive_event_for_multi_roots(ui_display_t *disp, XEvent *xev) {
 
   ui_window_receive_event(disp->roots[0], xev);
 
-  if (redraw_im_win && disp->num_of_roots == 2) {
+  if (redraw_im_win && disp->num_roots == 2) {
     /* Restart drawing input method window */
     disp->roots[1]->is_mapped = 1;
   } else if (!check_visibility_of_im_window(disp)) {
@@ -499,7 +501,7 @@ static int receive_stdin_event(ui_display_t *disp) {
   if (!receive_stdin(disp->display)) {
     u_int count;
 
-    for (count = disp->num_of_roots; count > 0; count--) {
+    for (count = disp->num_roots; count > 0; count--) {
       if (disp->roots[count - 1]->window_deleted) {
         (*disp->roots[count - 1]->window_deleted)(disp->roots[count - 1]);
       }
@@ -601,7 +603,9 @@ static int receive_stdin_event(ui_display_t *disp) {
         } else if (*ft == 'M' || *ft == 'm') {
           XButtonEvent bev;
           int state;
+#ifdef HAVE_GETTIMEOFDAY
           struct timeval tv;
+#endif
           ui_window_t *win;
 
           if (*ft == 'M') {
@@ -646,8 +650,12 @@ static int receive_stdin_event(ui_display_t *disp) {
           bev.x -= win->x;
           bev.y -= win->y;
 
+#ifdef HAVE_GETTIMEOFDAY
           gettimeofday(&tv, NULL);
           bev.time = tv.tv_sec * 1000 + tv.tv_usec / 1000;
+#else
+          bev.time = time(NULL) * 1000;
+#endif
 
           set_blocking(fileno(disp->display->fp), 1);
           ui_window_receive_event(win, &bev);
@@ -660,7 +668,7 @@ static int receive_stdin_event(ui_display_t *disp) {
           /* XXX */
           ui_font_cache_unload_all();
 
-          for (count = 0; count < disp->num_of_roots; count++) {
+          for (count = 0; count < disp->num_roots; count++) {
             ui_window_resize_with_margin(disp->roots[count], disp->width, disp->height,
                                          NOTIFY_TO_MYSELF);
           }
@@ -857,7 +865,7 @@ ui_display_t *ui_display_open(char *disp_name, u_int depth) {
   return disp;
 }
 
-int ui_display_close(ui_display_t *disp) {
+void ui_display_close(ui_display_t *disp) {
   u_int count;
 
 /* inline pictures are alive until vt_term_t is deleted. */
@@ -876,34 +884,30 @@ int ui_display_close(ui_display_t *disp) {
   fclose(disp->display->fp);
   (*disp->display->conv->delete)(disp->display->conv);
 
-  for (count = 0; count < num_of_displays; count++) {
+  for (count = 0; count < num_displays; count++) {
     if (displays[count] == disp) {
       memcpy(displays + count, displays + count + 1,
-             sizeof(ui_display_t *) * (num_of_displays - count - 1));
-      num_of_displays--;
+             sizeof(ui_display_t *) * (num_displays - count - 1));
+      num_displays--;
 
       break;
     }
   }
-
-  return 1;
 }
 
-int ui_display_close_all(void) {
+void ui_display_close_all(void) {
   u_int count;
 
-  for (count = num_of_displays; count > 0; count--) {
+  for (count = num_displays; count > 0; count--) {
     ui_display_close(displays[count - 1]);
   }
 
   free(displays);
   displays = NULL;
-
-  return 1;
 }
 
 ui_display_t **ui_get_opened_displays(u_int *num) {
-  *num = num_of_displays;
+  *num = num_displays;
 
   return displays;
 }
@@ -915,7 +919,7 @@ int ui_display_show_root(ui_display_t *disp, ui_window_t *root, int x, int y, in
                          ) {
   void *p;
 
-  if ((p = realloc(disp->roots, sizeof(ui_window_t *) * (disp->num_of_roots + 1))) == NULL) {
+  if ((p = realloc(disp->roots, sizeof(ui_window_t *) * (disp->num_roots + 1))) == NULL) {
 #ifdef DEBUG
     bl_warn_printf(BL_DEBUG_TAG " realloc failed.\n");
 #endif
@@ -936,7 +940,7 @@ int ui_display_show_root(ui_display_t *disp, ui_window_t *root, int x, int y, in
     root->app_name = app_name;
   }
 
-  disp->roots[disp->num_of_roots++] = root;
+  disp->roots[disp->num_roots++] = root;
 
   /* Cursor is drawn internally by calling ui_display_put_image(). */
   if (!ui_window_show(root, hint)) {
@@ -949,7 +953,7 @@ int ui_display_show_root(ui_display_t *disp, ui_window_t *root, int x, int y, in
 int ui_display_remove_root(ui_display_t *disp, ui_window_t *root) {
   u_int count;
 
-  for (count = 0; count < disp->num_of_roots; count++) {
+  for (count = 0; count < disp->num_roots; count++) {
     if (disp->roots[count] == root) {
 /* XXX ui_window_unmap resizes all windows internally. */
 #if 0
@@ -957,12 +961,12 @@ int ui_display_remove_root(ui_display_t *disp, ui_window_t *root) {
 #endif
       ui_window_final(root);
 
-      disp->num_of_roots--;
+      disp->num_roots--;
 
-      if (count == disp->num_of_roots) {
+      if (count == disp->num_roots) {
         disp->roots[count] = NULL;
       } else {
-        disp->roots[count] = disp->roots[disp->num_of_roots];
+        disp->roots[count] = disp->roots[disp->num_roots];
       }
 
       return 1;
@@ -975,7 +979,7 @@ int ui_display_remove_root(ui_display_t *disp, ui_window_t *root) {
 void ui_display_idling(ui_display_t *disp) {
   u_int count;
 
-  for (count = 0; count < disp->num_of_roots; count++) {
+  for (count = 0; count < disp->num_roots; count++) {
     ui_window_idling(disp->roots[count]);
   }
 }
@@ -1001,7 +1005,7 @@ int ui_display_clear_selection(ui_display_t *disp, /* NULL means all selection o
   if (disp == NULL) {
     u_int count;
 
-    for (count = 0; count < num_of_displays; count++) {
+    for (count = 0; count < num_displays; count++) {
       ui_display_clear_selection(displays[count], displays[count]->selection_owner);
     }
 
