@@ -36,6 +36,9 @@ typedef struct fb_cmap fb_cmap_t;
 
 #endif
 
+/* SIXEL_SHAREPALETTE in c_sixel.c reduces the role of COLOR_CACHE_MINIMUM. */
+#define COLOR_CACHE_MINIMUM
+
 typedef struct {
   int fd;
 
@@ -184,15 +187,15 @@ typedef union {
 typedef struct _XFontStruct {
   char *file;
 
-  int32_t format; /* XXX (fontsize|FONT_BOLD|FONT_ITALIC) on freetype. */
+  int32_t format; /* XXX (fontsize|FONT_BOLD|FONT_ITALIC|FONT_ROTATED) on freetype. */
 
-  int32_t num_of_glyphs;
+  int32_t num_glyphs;
   unsigned char *glyphs;
 
   int32_t glyph_width_bytes;
 
   unsigned char width;
-  unsigned char width_full;
+  unsigned char width_full; /* If it doesn't contain full width glyphs, width_full == width */
   unsigned char height;
   unsigned char ascent;
 
@@ -208,7 +211,7 @@ typedef struct _XFontStruct {
 #ifdef USE_FREETYPE
   /* for freetype */
   void *face;
-  u_int32_t num_of_indeces;
+  u_int32_t num_indeces;
   u_int32_t glyph_size;
   int is_aa;
 
@@ -658,5 +661,10 @@ KeySym XStringToKeysym(char *str);
  */
 #undef HAVE_PTHREAD
 #define COMPOSE_DECSP_FONT
+#ifdef USE_FREETYPE
+#define USE_REAL_VERTICAL_FONT
+#else
+#undef USE_REAL_VERTICAL_FONT
+#endif
 
 #endif
