@@ -27,7 +27,7 @@ static ui_color_t black = {TP_COLOR, 0, 0, 0, 0};
 #define DummyPixmap (2L)
 
 /* XXX Check if win is input method window or not. */
-#define IS_IM_WINDOW(win) ((win)->disp->num_of_roots >= 2 && (win) == (win)->disp->roots[1])
+#define IS_IM_WINDOW(win) ((win)->disp->num_roots >= 2 && (win) == (win)->disp->roots[1])
 
 /* --- static variables --- */
 
@@ -137,19 +137,28 @@ static int copy_blended_pixel(Display *display, u_char *dst, u_char **bitmap, u_
 }
 #endif
 
-static int draw_string_intern(ui_window_t *win, XFontStruct *xfont, u_int font_height,
-                              u_int font_ascent, u_int font_width, int font_x_off,
-                              int double_draw_gap, int is_proportional,
-                              u_int32_t fg_pixel, u_int32_t bg_pixel,
-                              int x, /* win->x and win->hmargin are added. */
-                              int y, int y_off, u_char **bitmaps, u_int len, u_char *picture,
-                              size_t picture_line_len, int src_bg_is_set, int bpp) {
+static void draw_string_intern(ui_window_t *win, XFontStruct *xfont, u_int font_height,
+                               u_int font_ascent, u_int font_width, int font_x_off,
+                               int double_draw_gap, int is_proportional,
+                               u_int32_t fg_pixel, u_int32_t bg_pixel,
+                               int x, /* win->x and win->hmargin are added. */
+                               int y, int y_off, u_char **bitmaps, u_int len, u_char *picture,
+                               size_t picture_line_len, int src_bg_is_set, int bpp) {
   size_t size;
   u_char *src;
   u_char *p;
   u_int count;
   int orig_x;
   int orig_y_off;
+  /*
+   * If font_width is larger than xfont->width_full, memory access must be limited
+   * to the latter one. (Don't excess xfont->glyph_width_bytes)
+   */
+  u_int max_glyph_width = xfont->width_full;
+
+  if (max_glyph_width + font_x_off > font_width) {
+    max_glyph_width = font_width - font_x_off;
+  }
 
 #ifdef USE_FREETYPE
   if (xfont->is_aa && is_proportional) {
@@ -168,7 +177,7 @@ static int draw_string_intern(ui_window_t *win, XFontStruct *xfont, u_int font_h
   }
 
   if (!(src = alloca(size))) {
-    return 0;
+    return;
   }
 
 #if 1
@@ -180,9 +189,7 @@ static int draw_string_intern(ui_window_t *win, XFontStruct *xfont, u_int font_h
       ) {
     u_char *bitmap_line;
     int x_off;
-    u_int glyph_width;
-
-    glyph_width = font_width - font_x_off;
+    u_int end_gap = font_width - font_x_off - max_glyph_width;
 
     switch (bpp) {
       case 1:
@@ -196,20 +203,20 @@ static int draw_string_intern(ui_window_t *win, XFontStruct *xfont, u_int font_h
             } else {
               p += font_x_off;
 
-              for (x_off = 0; x_off < glyph_width; x_off++) {
+              for (x_off = 0; x_off < max_glyph_width; x_off++, p++) {
                 if (ui_get_bitmap_cell(bitmap_line, x_off)) {
                   *p = fg_pixel;
                 }
-
-                p++;
               }
+
+              p += end_gap;
             }
           }
 
           ui_display_put_image(win->disp, x, y + y_off, src, p - src, 0);
         }
 
-        return 1;
+        return;
 
       case 2:
         for (; y_off < font_height; y_off++) {
@@ -222,20 +229,20 @@ static int draw_string_intern(ui_window_t *win, XFontStruct *xfont, u_int font_h
             } else {
               p += (font_x_off * 2);
 
-              for (x_off = 0; x_off < glyph_width; x_off++) {
+              for (x_off = 0; x_off < max_glyph_width; x_off++, p += 2) {
                 if (ui_get_bitmap_cell(bitmap_line, x_off)) {
                   *((u_int16_t *)p) = fg_pixel;
                 }
-
-                p += 2;
               }
+
+              p += (end_gap * 2);
             }
           }
 
           ui_display_put_image(win->disp, x, y + y_off, src, p - src, 0);
         }
 
-        return 1;
+        return;
 
       /* case  4: */
       default:
@@ -249,20 +256,20 @@ static int draw_string_intern(ui_window_t *win, XFontStruct *xfont, u_int font_h
             } else {
               p += (font_x_off * 4);
 
-              for (x_off = 0; x_off < glyph_width; x_off++) {
+              for (x_off = 0; x_off < max_glyph_width; x_off++, p += 4) {
                 if (ui_get_bitmap_cell(bitmap_line, x_off)) {
                   *((u_int32_t *)p) = fg_pixel;
                 }
-
-                p += 4;
               }
+
+              p += (end_gap * 4);
             }
           }
 
           ui_display_put_image(win->disp, x, y + y_off, src, p - src, 0);
         }
 
-        return 1;
+        return;
     }
   }
 #endif
@@ -390,11 +397,10 @@ static int draw_string_intern(ui_window_t *win, XFontStruct *xfont, u_int font_h
             x = x + advance - font_width;
           }
         } else {
-          for (x_off = 0; x_off < font_width; x_off++, p += bpp) {
-            u_long pixel;
+          u_int glyph_end = font_x_off + max_glyph_width;
 
-            if (font_x_off <= x_off &&
-                x_off < font_x_off + ui_get_bitmap_width(xfont)) {
+          for (x_off = 0; ; x_off++, p += bpp) {
+            if (font_x_off <= x_off && x_off < glyph_end) {
               u_long bg;
 
               if (src_bg_is_set) {
@@ -407,13 +413,16 @@ static int draw_string_intern(ui_window_t *win, XFontStruct *xfont, u_int font_h
                 bg = ui_display_get_pixel(win->disp, x + x_off, y + y_off);
               }
 
-              if (copy_blended_pixel(win->disp->display, p, &bitmap_line, fg_pixel, bg,
-                                     bpp)) {
+              if (copy_blended_pixel(win->disp->display, p, &bitmap_line, fg_pixel, bg, bpp)) {
                 continue;
               }
+            } else if (font_width <= x_off) {
+              break;
             }
 
             if (!src_bg_is_set) {
+              u_long pixel;
+
               pixel = ui_display_get_pixel(win->disp, x + x_off, y + y_off);
               copy_pixel(p, pixel, bpp);
             }
@@ -422,17 +431,18 @@ static int draw_string_intern(ui_window_t *win, XFontStruct *xfont, u_int font_h
       }
 #endif
       else {
-        int force_fg;
+        int force_fg = 0;
+        u_int glyph_end = font_x_off + max_glyph_width;
 
-        force_fg = 0;
-
-        for (x_off = 0; x_off < font_width; x_off++, p += bpp) {
+        for (x_off = 0; ; x_off++, p += bpp) {
           u_long pixel;
 
-          if (font_x_off <= x_off && ui_get_bitmap_cell(bitmap_line, x_off - font_x_off)) {
+          if (font_x_off <= x_off && x_off < glyph_end &&
+              ui_get_bitmap_cell(bitmap_line, x_off - font_x_off)) {
             pixel = fg_pixel;
-
             force_fg = double_draw_gap;
+          } else if (font_width <= x_off) {
+            break;
           } else {
             if (force_fg) {
               pixel = fg_pixel;
@@ -452,13 +462,13 @@ static int draw_string_intern(ui_window_t *win, XFontStruct *xfont, u_int font_h
     ui_display_put_image(win->disp, (x = orig_x), y + y_off, src, p - src, !src_bg_is_set);
   }
 
-  return 1;
+  return;
 }
 
-static int draw_string(ui_window_t *win, ui_font_t *font, ui_color_t *fg_color,
-                       ui_color_t *bg_color,      /* must be NULL if wall_picture_bg is 1 */
-                       int x, int y, u_char *str, /* 'len * ch_len' bytes */
-                       u_int len, u_int ch_len, int wall_picture_bg) {
+static void draw_string(ui_window_t *win, ui_font_t *font, ui_color_t *fg_color,
+                        ui_color_t *bg_color,      /* must be NULL if wall_picture_bg is 1 */
+                        int x, int y, u_char *str, /* 'len * ch_len' bytes */
+                        u_int len, u_int ch_len, int wall_picture_bg) {
   u_int bpp;
   XFontStruct *xfont;
   u_char **bitmaps;
@@ -474,11 +484,11 @@ static int draw_string(ui_window_t *win, ui_font_t *font, ui_color_t *fg_color,
   int x_off;
 
   if (!win->is_mapped) {
-    return 0;
+    return;
   }
 
   if (!(bitmaps = alloca((len * sizeof(*bitmaps))))) {
-    return 0;
+    return;
   }
 
   bpp = win->disp->display->bytes_per_pixel;
@@ -510,7 +520,7 @@ static int draw_string(ui_window_t *win, ui_font_t *font, ui_color_t *fg_color,
   }
 
   if (y >= clip_bottom + font_ascent) {
-    return 0;
+    return;
   } else if (y + font_height - font_ascent > clip_bottom) {
     font_height -= (y + font_height - font_ascent - clip_bottom + 1);
 
@@ -522,7 +532,7 @@ static int draw_string(ui_window_t *win, ui_font_t *font, ui_color_t *fg_color,
   }
 
   if (y + font_height - font_ascent < win->clip_y) {
-    return 0;
+    return;
   } else if (y < win->clip_y + font_ascent) {
     y_off = win->clip_y + font_ascent - y;
   } else {
@@ -654,7 +664,7 @@ static int draw_string(ui_window_t *win, ui_font_t *font, ui_color_t *fg_color,
         xfont = compl_xfont;
 
         /* see ui_font.c */
-        if ((font->id & FONT_FULLWIDTH) && xfont->width_full > 0) {
+        if (font->id & FONT_FULLWIDTH) {
           w = xfont->width_full;
         } else {
           w = xfont->width;
@@ -674,10 +684,10 @@ static int draw_string(ui_window_t *win, ui_font_t *font, ui_color_t *fg_color,
     }
   }
 
-  return draw_string_intern(win, xfont, font_height, font_ascent, font->width, x_off,
-                            font->double_draw_gap, font->is_proportional,
-                            fg_color->pixel, bg_color ? bg_color->pixel : 0, x, y, y_off,
-                            bitmaps, len, picture, picture_line_len, src_bg_is_set, bpp);
+  draw_string_intern(win, xfont, font_height, font_ascent, font->width, x_off,
+                     font->double_draw_gap, font->is_proportional,
+                     fg_color->pixel, bg_color ? bg_color->pixel : 0, x, y, y_off,
+                     bitmaps, len, picture, picture_line_len, src_bg_is_set, bpp);
 }
 
 static int copy_area(ui_window_t *win, Pixmap src, PixmapMask mask, int src_x, /* can be minus */
@@ -772,7 +782,7 @@ static int copy_area(ui_window_t *win, Pixmap src, PixmapMask mask, int src_x, /
   return 1;
 }
 
-static int clear_margin_area(ui_window_t *win) {
+static void clear_margin_area(ui_window_t *win) {
   u_int right_margin;
   u_int bottom_margin;
 
@@ -788,7 +798,7 @@ static int clear_margin_area(ui_window_t *win) {
   }
 
   /* XXX */
-  if (win->num_of_children == 2 &&
+  if (win->num_children == 2 &&
       ACTUAL_HEIGHT(win->children[0]) == ACTUAL_HEIGHT(win->children[1])) {
     if (win->children[0]->x + ACTUAL_WIDTH(win->children[0]) <= win->children[1]->x) {
       ui_window_clear(win, win->children[0]->x + ACTUAL_WIDTH(win->children[0]), 0,
@@ -800,8 +810,6 @@ static int clear_margin_area(ui_window_t *win) {
                       win->height);
     }
   }
-
-  return 1;
 }
 
 static int fix_rl_boundary(ui_window_t *win, int boundary_start, int *boundary_end) {
@@ -852,7 +860,7 @@ static void reset_input_focus(ui_window_t *win) {
     }
   }
 
-  for (count = 0; count < win->num_of_children; count++) {
+  for (count = 0; count < win->num_children; count++) {
     reset_input_focus(win->children[count]);
   }
 }
@@ -864,7 +872,7 @@ static void check_update_window(ui_window_t *win, int x /* parent */, int y /* p
   x += win->x;
   y += win->y;
 
-  if ((win->parent || win->num_of_children == 0) && /* XXX ui_layout_t is not updated. */
+  if ((win->parent || win->num_children == 0) && /* XXX ui_layout_t is not updated. */
       (ui_display_get_pixel(win->disp, x + ACTUAL_WIDTH(win) / 2,
                             y + ACTUAL_HEIGHT(win) / 2) == 0 ||
        ui_display_get_pixel(win->disp, x + ACTUAL_WIDTH(win) - 1,
@@ -873,7 +881,7 @@ static void check_update_window(ui_window_t *win, int x /* parent */, int y /* p
     ui_window_update_all(win);
   }
 
-  for (count = 0; count < win->num_of_children; count++) {
+  for (count = 0; count < win->num_children; count++) {
     check_update_window(win->children[count], x, y);
   }
 }
@@ -881,11 +889,11 @@ static void check_update_window(ui_window_t *win, int x /* parent */, int y /* p
 
 #if 0
 static int check_child_window_area(ui_window_t *win) {
-  if (win->num_of_children > 0) {
+  if (win->num_children > 0) {
     u_int count;
     u_int sum;
 
-    for (sum = 0, count = 1; count < win->num_of_children; count++) {
+    for (sum = 0, count = 1; count < win->num_children; count++) {
       sum += (ACTUAL_WIDTH(win->children[count]) * ACTUAL_HEIGHT(win->children[count]));
     }
 
@@ -945,10 +953,10 @@ int ui_window_init(ui_window_t *win, u_int width, u_int height, u_int min_width,
   return 1;
 }
 
-int ui_window_final(ui_window_t *win) {
+void ui_window_final(ui_window_t *win) {
   u_int count;
 
-  for (count = 0; count < win->num_of_children; count++) {
+  for (count = 0; count < win->num_children; count++) {
     ui_window_final(win->children[count]);
   }
 
@@ -959,25 +967,19 @@ int ui_window_final(ui_window_t *win) {
   if (win->window_finalized) {
     (*win->window_finalized)(win);
   }
-
-  return 1;
 }
 
-int ui_window_set_type_engine(ui_window_t *win, ui_type_engine_t type_engine) { return 1; }
+void ui_window_set_type_engine(ui_window_t *win, ui_type_engine_t type_engine) {}
 
-int ui_window_add_event_mask(ui_window_t *win, long event_mask) {
+void ui_window_add_event_mask(ui_window_t *win, long event_mask) {
   win->event_mask |= event_mask;
-
-  return 1;
 }
 
-int ui_window_remove_event_mask(ui_window_t *win, long event_mask) {
+void ui_window_remove_event_mask(ui_window_t *win, long event_mask) {
   win->event_mask &= ~event_mask;
-
-  return 1;
 }
 
-int ui_window_ungrab_pointer(ui_window_t *win) { return 0; }
+void ui_window_ungrab_pointer(ui_window_t *win) {}
 
 int ui_window_set_wall_picture(ui_window_t *win, Pixmap pic, int do_expose) {
   u_int count;
@@ -1018,7 +1020,7 @@ int ui_window_set_wall_picture(ui_window_t *win, Pixmap pic, int do_expose) {
 #endif
   }
 
-  for (count = 0; count < win->num_of_children; count++) {
+  for (count = 0; count < win->num_children; count++) {
     ui_window_set_wall_picture(win->children[count], ParentRelative, do_expose);
   }
 
@@ -1048,7 +1050,7 @@ int ui_window_unset_wall_picture(ui_window_t *win, int do_expose) {
 #endif
   }
 
-  for (count = 0; count < win->num_of_children; count++) {
+  for (count = 0; count < win->num_children; count++) {
     ui_window_unset_wall_picture(win->children[count], do_expose);
   }
 
@@ -1063,19 +1065,25 @@ int ui_window_set_transparent(
 
 int ui_window_unset_transparent(ui_window_t *win) { return 0; }
 
-int ui_window_set_cursor(ui_window_t *win, u_int cursor_shape) {
+void ui_window_set_cursor(ui_window_t *win, u_int cursor_shape) {
   win->cursor_shape = cursor_shape;
-
-  return 1;
 }
 
 int ui_window_set_fg_color(ui_window_t *win, ui_color_t *fg_color) {
+  if (win->fg_color.pixel == fg_color->pixel) {
+    return 0;
+  }
+
   win->fg_color = *fg_color;
 
   return 1;
 }
 
 int ui_window_set_bg_color(ui_window_t *win, ui_color_t *bg_color) {
+  if (win->bg_color.pixel == bg_color->pixel) {
+    return 0;
+  }
+
   win->bg_color = *bg_color;
 
   clear_margin_area(win);
@@ -1091,7 +1099,7 @@ int ui_window_add_child(ui_window_t *win, ui_window_t *child, int x, int y, int
     return 0;
   }
 
-  if ((p = realloc(win->children, sizeof(*win->children) * (win->num_of_children + 1))) == NULL) {
+  if ((p = realloc(win->children, sizeof(*win->children) * (win->num_children + 1))) == NULL) {
 #ifdef DEBUG
     bl_warn_printf(BL_DEBUG_TAG " realloc failed.\n");
 #endif
@@ -1124,7 +1132,7 @@ int ui_window_add_child(ui_window_t *win, ui_window_t *child, int x, int y, int
   }
 #endif
 
-  win->children[win->num_of_children++] = child;
+  win->children[win->num_children++] = child;
 
   return 1;
 }
@@ -1132,11 +1140,11 @@ int ui_window_add_child(ui_window_t *win, ui_window_t *child, int x, int y, int
 int ui_window_remove_child(ui_window_t *win, ui_window_t *child) {
   u_int count;
 
-  for (count = 0; count < win->num_of_children; count++) {
+  for (count = 0; count < win->num_children; count++) {
     if (win->children[count] == child) {
       child->parent = NULL;
 
-      win->children[count] = win->children[--win->num_of_children];
+      win->children[count] = win->children[--win->num_children];
 
       return 1;
     }
@@ -1202,7 +1210,7 @@ int ui_window_show(ui_window_t *win,
    * showing child windows.
    */
 
-  for (count = 0; count < win->num_of_children; count++) {
+  for (count = 0; count < win->num_children; count++) {
     ui_window_show(win->children[count], 0);
   }
 
@@ -1218,21 +1226,17 @@ int ui_window_show(ui_window_t *win,
   return 1;
 }
 
-int ui_window_map(ui_window_t *win) {
+void ui_window_map(ui_window_t *win) {
   if (!win->is_mapped) {
     win->is_mapped = 1;
 
     clear_margin_area(win);
     (*win->window_exposed)(win, 0, 0, ACTUAL_WIDTH(win), ACTUAL_HEIGHT(win));
   }
-
-  return 1;
 }
 
-int ui_window_unmap(ui_window_t *win) {
+void ui_window_unmap(ui_window_t *win) {
   win->is_mapped = 0;
-
-  return 1;
 }
 
 int ui_window_resize(ui_window_t *win, u_int width, /* excluding margin */
@@ -1324,17 +1328,23 @@ int ui_window_resize_with_margin(ui_window_t *win, u_int width, u_int height,
   return ui_window_resize(win, width - win->hmargin * 2, height - win->vmargin * 2, flag);
 }
 
-int ui_window_set_normal_hints(ui_window_t *win, u_int min_width, u_int min_height, u_int width_inc,
-                               u_int height_inc) {
+void ui_window_set_maximize_flag(ui_window_t *win, ui_maximize_flag_t flag) {
+#ifdef USE_WAYLAND
+  if (flag == MAXIMIZE_FULL) {
+    ui_display_set_maximized(win->disp);
+  }
+#endif
+}
+
+void ui_window_set_normal_hints(ui_window_t *win, u_int min_width, u_int min_height,
+                                u_int width_inc, u_int height_inc) {
   win->min_width = min_width;
   win->min_height = min_height;
   win->width_inc = width_inc;
   win->height_inc = height_inc;
-
-  return 1;
 }
 
-int ui_window_set_override_redirect(ui_window_t *win, int flag) { return 0; }
+void ui_window_set_override_redirect(ui_window_t *win, int flag) {}
 
 int ui_window_set_borderless_flag(ui_window_t *win, int flag) { return 0; }
 
@@ -1412,14 +1422,14 @@ int ui_window_move(ui_window_t *win, int x, int y) {
   return 1;
 }
 
-int ui_window_clear(ui_window_t *win, int x, int y, u_int width, u_int height) {
+void ui_window_clear(ui_window_t *win, int x, int y, u_int width, u_int height) {
 #ifdef USE_GRF
   if (x68k_tvram_is_enabled()) {
-    return ui_window_fill_with(win, &black, x, y, width, height);
+    ui_window_fill_with(win, &black, x, y, width, height);
   } else
 #endif
-      if (!win->wall_picture) {
-    return ui_window_fill_with(win, &win->bg_color, x, y, width, height);
+  if (!win->wall_picture) {
+    ui_window_fill_with(win, &win->bg_color, x, y, width, height);
   } else {
     Pixmap pic;
     int src_x;
@@ -1435,29 +1445,27 @@ int ui_window_clear(ui_window_t *win, int x, int y, u_int width, u_int height) {
       src_y = y;
     }
 
-    return copy_area(win, pic, None, src_x, src_y, width, height, x, y, 1);
+    copy_area(win, pic, None, src_x, src_y, width, height, x, y, 1);
   }
-
-  return 1;
 }
 
-int ui_window_clear_all(ui_window_t *win) {
-  return ui_window_clear(win, 0, 0, win->width, win->height);
+void ui_window_clear_all(ui_window_t *win) {
+  ui_window_clear(win, 0, 0, win->width, win->height);
 }
 
-int ui_window_fill(ui_window_t *win, int x, int y, u_int width, u_int height) {
-  return ui_window_fill_with(win, &win->fg_color, x, y, width, height);
+void ui_window_fill(ui_window_t *win, int x, int y, u_int width, u_int height) {
+  ui_window_fill_with(win, &win->fg_color, x, y, width, height);
 }
 
-int ui_window_fill_with(ui_window_t *win, ui_color_t *color, int x, int y, u_int width,
-                        u_int height) {
+void ui_window_fill_with(ui_window_t *win, ui_color_t *color, int x, int y, u_int width,
+                         u_int height) {
   u_char *src;
   size_t size;
   int y_off;
   u_int bpp;
 
   if (!win->is_mapped) {
-    return 0;
+    return;
   }
 
   x += (win->x + win->hmargin);
@@ -1467,7 +1475,7 @@ int ui_window_fill_with(ui_window_t *win, ui_color_t *color, int x, int y, u_int
     ui_display_fill_with(x, y, width, height, (u_int8_t)color->pixel);
   } else {
     if (!(src = alloca((size = width * bpp)))) {
-      return 0;
+      return;
     }
 
     for (y_off = 0; y_off < height; y_off++) {
@@ -1490,32 +1498,28 @@ int ui_window_fill_with(ui_window_t *win, ui_color_t *color, int x, int y, u_int
       ui_display_put_image(win->disp, x, y + y_off, src, size, 0);
     }
   }
-
-  return 1;
 }
 
-int ui_window_blank(ui_window_t *win) {
-  return ui_window_fill_with(win, &win->fg_color, 0, 0, win->width - RIGHT_MARGIN(win),
-                             win->height - BOTTOM_MARGIN(win));
+void ui_window_blank(ui_window_t *win) {
+  ui_window_fill_with(win, &win->fg_color, 0, 0, win->width - RIGHT_MARGIN(win),
+                      win->height - BOTTOM_MARGIN(win));
 }
 
-int ui_window_update(ui_window_t *win, int flag) {
+void ui_window_update(ui_window_t *win, int flag) {
   if (!win->is_mapped) {
-    return 0;
+    return;
   }
 
   if (win->update_window) {
     (*win->update_window)(win, flag);
   }
-
-  return 1;
 }
 
-int ui_window_update_all(ui_window_t *win) {
+void ui_window_update_all(ui_window_t *win) {
   u_int count;
 
   if (!win->is_mapped) {
-    return 0;
+    return;
   }
 
   if (!win->parent) {
@@ -1528,17 +1532,15 @@ int ui_window_update_all(ui_window_t *win) {
     (*win->window_exposed)(win, 0, 0, win->width, win->height);
   }
 
-  for (count = 0; count < win->num_of_children; count++) {
+  for (count = 0; count < win->num_children; count++) {
     ui_window_update_all(win->children[count]);
   }
-
-  return 1;
 }
 
 void ui_window_idling(ui_window_t *win) {
   u_int count;
 
-  for (count = 0; count < win->num_of_children; count++) {
+  for (count = 0; count < win->num_children; count++) {
     ui_window_idling(win->children[count]);
   }
 
@@ -1563,7 +1565,7 @@ int ui_window_receive_event(ui_window_t *win, XEvent *event) {
 #if 0
   u_int count;
 
-  for (count = 0; count < win->num_of_children; count++) {
+  for (count = 0; count < win->num_children; count++) {
     if (ui_window_receive_event(win->children[count], event)) {
       return 1;
     }
@@ -1879,68 +1881,63 @@ void ui_window_set_clip(ui_window_t *win, int x, int y, u_int width, u_int heigh
 
 void ui_window_unset_clip(ui_window_t *win) { win->clip_y = win->clip_height = 0; }
 
-int ui_window_draw_decsp_string(ui_window_t *win, ui_font_t *font, ui_color_t *fg_color, int x,
-                                int y, u_char *str, u_int len) {
+void ui_window_draw_decsp_string(ui_window_t *win, ui_font_t *font, ui_color_t *fg_color, int x,
+                                 int y, u_char *str, u_int len) {
   convert_to_decsp_font_index(str, len);
 
-  return ui_window_draw_string(win, font, fg_color, x, y, str, len);
+  ui_window_draw_string(win, font, fg_color, x, y, str, len);
 }
 
-int ui_window_draw_decsp_image_string(
-    ui_window_t *win, ui_font_t *font, ui_color_t *fg_color,
-    ui_color_t *bg_color, /* If NULL is specified, use wall_picture for bg */
-    int x, int y, u_char *str, u_int len) {
+void ui_window_draw_decsp_image_string(ui_window_t *win, ui_font_t *font, ui_color_t *fg_color,
+                                       ui_color_t *bg_color, /* NULL => use wall_picture for bg */
+                                       int x, int y, u_char *str, u_int len) {
   convert_to_decsp_font_index(str, len);
 
-  return ui_window_draw_image_string(win, font, fg_color, bg_color, x, y, str, len);
+  ui_window_draw_image_string(win, font, fg_color, bg_color, x, y, str, len);
 }
 
-int ui_window_draw_string(ui_window_t *win, ui_font_t *font, ui_color_t *fg_color, int x, int y,
-                          u_char *str, u_int len) {
-  return draw_string(win, font, fg_color, NULL, x, y, str, len, 1, 0);
+void ui_window_draw_string(ui_window_t *win, ui_font_t *font, ui_color_t *fg_color, int x, int y,
+                           u_char *str, u_int len) {
+  draw_string(win, font, fg_color, NULL, x, y, str, len, 1, 0);
 }
 
-int ui_window_draw_string16(ui_window_t *win, ui_font_t *font, ui_color_t *fg_color, int x, int y,
-                            XChar2b *str, u_int len) {
-  return draw_string(win, font, fg_color, NULL, x, y, str, len, 2, 0);
+void ui_window_draw_string16(ui_window_t *win, ui_font_t *font, ui_color_t *fg_color, int x, int y,
+                             XChar2b *str, u_int len) {
+  draw_string(win, font, fg_color, NULL, x, y, str, len, 2, 0);
 }
 
-int ui_window_draw_image_string(
-    ui_window_t *win, ui_font_t *font, ui_color_t *fg_color,
-    ui_color_t *bg_color, /* If NULL is specified, use wall_picture for bg */
-    int x, int y, u_char *str, u_int len) {
+void ui_window_draw_image_string(ui_window_t *win, ui_font_t *font, ui_color_t *fg_color,
+                                 ui_color_t *bg_color, /* NULL => use wall_picture for bg */
+                                 int x, int y, u_char *str, u_int len) {
 #ifdef USE_GRF
   if (bg_color == NULL && x68k_tvram_is_enabled()) {
     bg_color = &black;
   }
 #endif
 
-  return draw_string(win, font, fg_color, bg_color, x, y, str, len, 1, bg_color == NULL);
+  draw_string(win, font, fg_color, bg_color, x, y, str, len, 1, bg_color == NULL);
 }
 
-int ui_window_draw_image_string16(
-    ui_window_t *win, ui_font_t *font, ui_color_t *fg_color,
-    ui_color_t *bg_color, /* If NULL is specified, use wall_picture for bg */
-    int x, int y, XChar2b *str, u_int len) {
+void ui_window_draw_image_string16(ui_window_t *win, ui_font_t *font, ui_color_t *fg_color,
+                                   ui_color_t *bg_color, /* NULL => use wall_picture for bg */
+                                   int x, int y, XChar2b *str, u_int len) {
 #ifdef USE_GRF
   if (bg_color == NULL && x68k_tvram_is_enabled()) {
     bg_color = &black;
   }
 #endif
 
-  return draw_string(win, font, fg_color, bg_color, x, y, str, len, 2, bg_color == NULL);
+  draw_string(win, font, fg_color, bg_color, x, y, str, len, 2, bg_color == NULL);
 }
 
-int ui_window_draw_rect_frame(ui_window_t *win, int x1, int y1, int x2, int y2) {
+void ui_window_draw_rect_frame(ui_window_t *win, int x1, int y1, int x2, int y2) {
   ui_window_fill_with(win, &win->fg_color, x1, y1, x2 - x1 + 1, 1);
   ui_window_fill_with(win, &win->fg_color, x1, y1, 1, y2 - y1 + 1);
   ui_window_fill_with(win, &win->fg_color, x1, y2, x2 - x1 + 1, 1);
   ui_window_fill_with(win, &win->fg_color, x2, y1, 1, y2 - y1 + 1);
-
-  return 1;
 }
 
-int ui_set_use_clipboard_selection(int use_it) { return 0; }
+void ui_set_use_clipboard_selection(int use_it) {}
 
 int ui_is_using_clipboard_selection(void) { return 0; }
 
@@ -1992,12 +1989,10 @@ int ui_window_utf_selection_request(ui_window_t *win, Time time) {
   return 1;
 }
 
-int ui_window_send_picture_selection(ui_window_t *win, Pixmap pixmap, u_int width, u_int height) {
-  return 0;
-}
+void ui_window_send_picture_selection(ui_window_t *win, Pixmap pixmap, u_int width, u_int height) {}
 
-int ui_window_send_text_selection(ui_window_t *win, XSelectionRequestEvent *req_ev,
-                                  u_char *sel_data, size_t sel_len, Atom sel_type) {
+void ui_window_send_text_selection(ui_window_t *win, XSelectionRequestEvent *req_ev,
+                                   u_char *sel_data, size_t sel_len, Atom sel_type) {
 #if defined(__ANDROID__)
   ui_display_send_text_selection(sel_data, sel_len);
 #elif defined(USE_WAYLAND)
@@ -2015,11 +2010,9 @@ int ui_window_send_text_selection(ui_window_t *win, XSelectionRequestEvent *req_
     }
   }
 #endif
-
-  return 1;
 }
 
-int ui_set_window_name(ui_window_t *win, u_char *name) {
+void ui_set_window_name(ui_window_t *win, u_char *name) {
 #ifdef USE_WAYLAND
   if (name == NULL) {
     name = win->app_name;
@@ -2027,30 +2020,22 @@ int ui_set_window_name(ui_window_t *win, u_char *name) {
 
   ui_display_set_title(win->disp, name);
 #endif
-
-  return 1;
 }
 
-int ui_set_icon_name(ui_window_t *win, u_char *name) { return 1; }
+void ui_set_icon_name(ui_window_t *win, u_char *name) {}
 
-int ui_window_set_icon(ui_window_t *win, ui_icon_picture_ptr_t icon) { return 1; }
+void ui_window_set_icon(ui_window_t *win, ui_icon_picture_ptr_t icon) {}
 
-int ui_window_remove_icon(ui_window_t *win) { return 1; }
+void ui_window_remove_icon(ui_window_t *win) {}
 
-int ui_window_reset_group(ui_window_t *win) { return 1; }
+void ui_window_reset_group(ui_window_t *win) {}
 
-int ui_window_get_visible_geometry(ui_window_t *win, int *x, /* x relative to root window */
-                                   int *y,                   /* y relative to root window */
-                                   int *my_x,                /* x relative to my window */
-                                   int *my_y,                /* y relative to my window */
-                                   u_int *width, u_int *height) {
-  return 1;
-}
-
-int ui_set_click_interval(int interval) {
+void ui_set_click_interval(int interval) {
   click_interval = interval;
+}
 
-  return 1;
+int ui_get_click_interval(void) {
+  return click_interval;
 }
 
 u_int ui_window_get_mod_ignore_mask(ui_window_t *win, KeySym *keysyms) {
@@ -2059,26 +2044,21 @@ u_int ui_window_get_mod_ignore_mask(ui_window_t *win, KeySym *keysyms) {
 
 u_int ui_window_get_mod_meta_mask(ui_window_t *win, char *mod_key) { return ModMask; }
 
-int ui_window_bell(ui_window_t *win, ui_bel_mode_t mode) {
+void ui_window_bell(ui_window_t *win, ui_bel_mode_t mode) {
   if (mode & BEL_VISUAL) {
     ui_window_blank(win);
     bl_usleep(100000); /* 100 mili sec */
     (*win->window_exposed)(win, 0, 0, win->width, win->height);
   }
-
-  return 1;
 }
 
-int ui_window_translate_coordinates(ui_window_t *win, int x, int y, int *global_x, int *global_y,
-                                    Window *child) {
+void ui_window_translate_coordinates(ui_window_t *win, int x, int y, int *global_x, int *global_y) {
   *global_x = x + win->x;
   *global_y = y + win->y;
 
 #if defined(ROTATABLE_DISPLAY) && !defined(MANAGE_ROOT_WINDOWS_BY_MYSELF) /* == USE_WAYLAND */
   ui_display_logical_to_physical_coordinates(win->disp, global_x, global_y);
 #endif
-
-  return 1;
 }
 
 void ui_window_set_input_focus(ui_window_t *win) {
@@ -2095,4 +2075,4 @@ void ui_window_set_input_focus(ui_window_t *win) {
 
 /* for ui_display.c */
 
-int ui_window_clear_margin_area(ui_window_t *win) { return clear_margin_area(win); }
+void ui_window_clear_margin_area(ui_window_t *win) { clear_margin_area(win); }
