@@ -48,8 +48,7 @@ static u_int calculate_char_width(ui_font_t *font, u_int code, ef_charset_t cs,
 }
 
 #ifndef USE_CONSOLE
-static void draw_line(ui_window_t *window, ui_color_t *color, int is_vertical,
-                      int flag, /* 0 == underline 1 == double underline, 2 == crossed out */
+static void draw_line(ui_window_t *window, ui_color_t *color, int is_vertical, int line_style,
                       int x, int y, u_int width, u_int height, u_int ascent, int top_margin) {
   u_int w;
   u_int h;
@@ -60,24 +59,23 @@ static void draw_line(ui_window_t *window, ui_color_t *color, int is_vertical,
     w = 1;
     h = height;
 
-    if (flag == 1) /* double */
-    {
+    if (line_style == LS_UNDERLINE_DOUBLE) {
       x2 = x + 2;
       y2 = y;
     } else {
       w += ((ascent - top_margin) / 16);
 
-      if (flag == 2) /* crossed out */
-      {
+      if (line_style == LS_CROSSED_OUT) {
         x += ((width - 1) / 2);
+      } else if (line_style == LS_OVERLINE) {
+        x += (width - (width >= 2 ? 2 : 1));
       }
     }
   } else {
     w = width;
     h = 1;
 
-    if (flag == 1) /* double */
-    {
+    if (line_style == LS_UNDERLINE_DOUBLE) {
       x2 = x;
 
       if (ascent + 2 >= height) {
@@ -90,9 +88,10 @@ static void draw_line(ui_window_t *window, ui_color_t *color, int is_vertical,
     } else {
       h += ((ascent - top_margin) / 16);
 
-      if (flag == 2) /* crossed out */
-      {
+      if (line_style == LS_CROSSED_OUT) {
         y += ((height + 1) / 2);
+      } else if (line_style == LS_OVERLINE) {
+        /* do nothing */
       } else {
         y += ascent;
       }
@@ -101,19 +100,18 @@ static void draw_line(ui_window_t *window, ui_color_t *color, int is_vertical,
 
   ui_window_fill_with(window, color, x, y, w, h);
 
-  if (flag == 1) /* double */
-  {
+  if (line_style == LS_UNDERLINE_DOUBLE) {
     ui_window_fill_with(window, color, x2, y2, w, h);
   }
 }
 #endif
 
 #ifndef NO_IMAGE
-static int draw_picture(ui_window_t *window, u_int32_t *glyphs, u_int num_of_glyphs, int dst_x,
+static int draw_picture(ui_window_t *window, u_int32_t *glyphs, u_int num_glyphs, int dst_x,
                         int dst_y, u_int ch_width, u_int line_height) {
   u_int count;
   ui_inline_picture_t *cur_pic;
-  u_int num_of_rows;
+  u_int num_rows;
   int src_x;
   int src_y;
   u_int src_width;
@@ -125,7 +123,7 @@ static int draw_picture(ui_window_t *window, u_int32_t *glyphs, u_int num_of_gly
   cur_pic = NULL;
   is_end = 0;
 
-  for (count = 0; count < num_of_glyphs; count++) {
+  for (count = 0; count < num_glyphs; count++) {
     ui_inline_picture_t *pic;
     int pos;
     int x;
@@ -142,11 +140,11 @@ static int draw_picture(ui_window_t *window, u_int32_t *glyphs, u_int num_of_gly
      */
 
     if (pic != cur_pic) {
-      num_of_rows = (pic->height + pic->line_height - 1) / pic->line_height;
+      num_rows = (pic->height + pic->line_height - 1) / pic->line_height;
     }
 
     pos = INLINEPIC_POS(glyphs[count]);
-    x = (pos / num_of_rows) * ch_width;
+    x = (pos / num_rows) * ch_width;
 
     if (x + ch_width > pic->width) {
       w = pic->width > x ? pic->width - x : 0;
@@ -164,7 +162,7 @@ static int draw_picture(ui_window_t *window, u_int32_t *glyphs, u_int num_of_gly
       src_width += w;
       dst_width += ch_width;
 
-      if (count + 1 < num_of_glyphs) {
+      if (count + 1 < num_glyphs) {
         continue;
       }
 
@@ -196,7 +194,7 @@ static int draw_picture(ui_window_t *window, u_int32_t *glyphs, u_int num_of_gly
     dst_x += dst_width;
 
   new_picture:
-    src_y = (pos % num_of_rows) * line_height;
+    src_y = (pos % num_rows) * line_height;
     src_x = x;
     dst_width = ch_width;
     cur_pic = pic;
@@ -250,7 +248,7 @@ static int get_drcs_bitmap(char *glyph, u_int width, int x, int y) {
   return (glyph[(y / 6) * (width + 1) + x] - '?') & (1 << (y % 6));
 }
 
-static int draw_drcs(ui_window_t *window, char **glyphs, u_int num_of_glyphs, int x, int y,
+static int draw_drcs(ui_window_t *window, char **glyphs, u_int num_glyphs, int x, int y,
                      u_int ch_width, u_int line_height, ui_color_t *fg_xcolor, int size_attr) {
   int y_off = 0;
 
@@ -274,7 +272,7 @@ static int draw_drcs(ui_window_t *window, char **glyphs, u_int num_of_glyphs, in
 
     w = 0;
 
-    for (x_off_sum = 0; x_off_sum < ch_width * num_of_glyphs; x_off_sum++) {
+    for (x_off_sum = 0; x_off_sum < ch_width * num_glyphs; x_off_sum++) {
       int left_x;
       int top_y;
       int hit;
@@ -335,7 +333,7 @@ static int draw_drcs(ui_window_t *window, char **glyphs, u_int num_of_glyphs, in
       if (n_smpl <= hit * 2) {
         w++;
 
-        if (x_off_sum + 1 == ch_width * num_of_glyphs) {
+        if (x_off_sum + 1 == ch_width * num_glyphs) {
           /* for x_off - w */
           x_off_sum++;
         } else {
@@ -449,7 +447,7 @@ static void fc_draw_combining_chars(ui_window_t *window, ui_font_manager_t *font
 
 static int fc_draw_str(ui_window_t *window, ui_font_manager_t *font_man,
                        ui_color_manager_t *color_man, u_int *updated_width, vt_char_t *chars,
-                       u_int num_of_chars, int x, int y, u_int height, u_int ascent,
+                       u_int num_chars, int x, int y, u_int height, u_int ascent,
                        int top_margin, int hide_underline, int underline_offset) {
   int count;
   int start_draw;
@@ -468,8 +466,7 @@ static int fc_draw_str(ui_window_t *window, ui_font_manager_t *font_man,
   vt_font_t font;
   vt_color_t fg_color;
   vt_color_t bg_color;
-  int underline_style;
-  int is_crossed_out;
+  int line_style;
   vt_char_t *comb_chars;
   u_int comb_size;
   int draw_alone;
@@ -483,8 +480,7 @@ static int fc_draw_str(ui_window_t *window, ui_font_manager_t *font_man,
   vt_font_t next_font;
   vt_color_t next_fg_color;
   vt_color_t next_bg_color;
-  int next_underline_style;
-  int next_is_crossed_out;
+  int next_line_style;
   vt_char_t *next_comb_chars;
   u_int next_comb_size;
   u_int next_ch_width;
@@ -494,7 +490,7 @@ static int fc_draw_str(ui_window_t *window, ui_font_manager_t *font_man,
   int draw_count = 0;
 #endif
 
-  if (num_of_chars == 0) {
+  if (num_chars == 0) {
 #ifdef __DEBUG
     bl_debug_printf(BL_DEBUG_TAG " input chars length is 0(ui_window_draw_str).\n");
 #endif
@@ -507,7 +503,7 @@ static int fc_draw_str(ui_window_t *window, ui_font_manager_t *font_man,
 
   count = 0;
   while (vt_char_cols(&chars[count]) == 0) {
-    if (++count >= num_of_chars) {
+    if (++count >= num_chars) {
       return 1;
     }
   }
@@ -536,13 +532,12 @@ static int fc_draw_str(ui_window_t *window, ui_font_manager_t *font_man,
   fg_color = vt_char_fg_color(&chars[count]);
   bg_color = vt_char_bg_color(&chars[count]);
 
-  underline_style = vt_char_underline_style(&chars[count]);
-  is_crossed_out = vt_char_is_crossed_out(&chars[count]);
+  line_style = vt_char_line_style(&chars[count]);
 
   if (!(str8 = str32 = pic_glyphs = drcs_glyphs =
             alloca(K_MAX(sizeof(*str8),
                          K_MAX(sizeof(*str32), K_MAX(sizeof(*pic_glyphs), sizeof(*drcs_glyphs)))) *
-                   num_of_chars))) {
+                   num_chars))) {
     return 0;
   }
 
@@ -576,7 +571,7 @@ static int fc_draw_str(ui_window_t *window, ui_font_manager_t *font_man,
      */
 
     do {
-      if (++count >= num_of_chars) {
+      if (++count >= num_chars) {
         start_draw = 1;
         end_of_str = 1;
 
@@ -590,8 +585,7 @@ static int fc_draw_str(ui_window_t *window, ui_font_manager_t *font_man,
       ch_cs = FONT_CS(next_font);
       next_fg_color = vt_char_fg_color(&chars[count]);
       next_bg_color = vt_char_bg_color(&chars[count]);
-      next_underline_style = vt_char_underline_style(&chars[count]);
-      next_is_crossed_out = vt_char_is_crossed_out(&chars[count]);
+      next_line_style = vt_char_line_style(&chars[count]);
       next_comb_chars = vt_get_combining_chars(&chars[count], &next_comb_size);
       next_ch_width = calculate_char_width(next_xfont, ch_code, ch_cs, next_comb_chars,
                                            next_comb_size, &next_draw_alone);
@@ -615,17 +609,11 @@ static int fc_draw_str(ui_window_t *window, ui_font_manager_t *font_man,
        * 'font & FONT_BOLD' is necessary.
        */
       else if (next_xfont != xfont || next_fg_color != fg_color || next_bg_color != bg_color ||
-               next_underline_style != underline_style || next_is_crossed_out != is_crossed_out
-               /*
-                * Eevn if both is_underline and next_is_underline are 1
-                * underline is drawn one by one in vertical mode.
-                * (is_crossed_out is the same.)
-                */
-               ||
-               ((underline_style || is_crossed_out) && xfont->is_vertical) || state != next_state ||
-               draw_alone || next_draw_alone
+               next_line_style != line_style ||
+               /* If line_style > 0, line is drawn one by one in vertical mode. */
+               (line_style && xfont->is_vertical) || state != next_state ||
+               draw_alone || next_draw_alone ||
                /* FONT_BOLD flag is not the same. */
-               ||
                ((font ^ next_font) & FONT_BOLD)) {
         start_draw = 1;
       } else {
@@ -704,15 +692,22 @@ static int fc_draw_str(ui_window_t *window, ui_font_manager_t *font_man,
                                 y + ascent);
       }
 
-      if (!hide_underline && underline_style) {
-        draw_line(window, fg_xcolor, xfont->is_vertical,
-                  underline_style == UNDERLINE_DOUBLE ? 1 : 0, x, y, current_width - x, height,
-                  ascent + underline_offset, top_margin);
-      }
+      if (line_style) {
+        if ((line_style & LS_UNDERLINE) && !hide_underline) {
+          draw_line(window, fg_xcolor, xfont->is_vertical,
+                    line_style & LS_UNDERLINE,
+                    x, y, current_width - x, height, ascent + underline_offset, top_margin);
+        }
 
-      if (is_crossed_out) {
-        draw_line(window, fg_xcolor, xfont->is_vertical, 2, x, y, current_width - x, height, ascent,
-                  top_margin);
+        if (line_style & LS_CROSSED_OUT) {
+          draw_line(window, fg_xcolor, xfont->is_vertical,
+                    LS_CROSSED_OUT, x, y, current_width - x, height, ascent, top_margin);
+        }
+
+        if (line_style & LS_OVERLINE) {
+          draw_line(window, fg_xcolor, xfont->is_vertical,
+                    LS_OVERLINE, x, y, current_width - x, height, ascent, top_margin);
+        }
       }
 
     end_draw:
@@ -726,8 +721,7 @@ static int fc_draw_str(ui_window_t *window, ui_font_manager_t *font_man,
       break;
     }
 
-    underline_style = next_underline_style;
-    is_crossed_out = next_is_crossed_out;
+    line_style = next_line_style;
     xfont = next_xfont;
     font = next_font;
     fg_color = next_fg_color;
@@ -818,7 +812,7 @@ static int xcore_draw_combining_chars(ui_window_t *window, ui_font_manager_t *fo
 
 static int xcore_draw_str(ui_window_t *window, ui_font_manager_t *font_man,
                           ui_color_manager_t *color_man, u_int *updated_width, vt_char_t *chars,
-                          u_int num_of_chars, int x, int y, u_int height, u_int ascent,
+                          u_int num_chars, int x, int y, u_int height, u_int ascent,
                           int top_margin, int hide_underline, int underline_offset) {
   int count;
   int start_draw;
@@ -838,8 +832,7 @@ static int xcore_draw_str(ui_window_t *window, ui_font_manager_t *font_man,
   vt_font_t font;
   vt_color_t fg_color;
   vt_color_t bg_color;
-  int underline_style;
-  int is_crossed_out;
+  int line_style;
   int draw_alone;
   u_int32_t pic_glyph;
   u_int32_t *pic_glyphs;
@@ -854,14 +847,13 @@ static int xcore_draw_str(ui_window_t *window, ui_font_manager_t *font_man,
   vt_font_t next_font;
   vt_color_t next_fg_color;
   vt_color_t next_bg_color;
-  int next_underline_style;
-  int next_is_crossed_out;
+  int next_line_style;
   int next_draw_alone;
 #ifdef PERF_DEBUG
   int draw_count = 0;
 #endif
 
-  if (num_of_chars == 0) {
+  if (num_chars == 0) {
 #ifdef DEBUG
     bl_debug_printf(BL_DEBUG_TAG " input chars length is 0(ui_window_draw_str).\n");
 #endif
@@ -871,7 +863,7 @@ static int xcore_draw_str(ui_window_t *window, ui_font_manager_t *font_man,
 
   count = 0;
   while (vt_char_cols(&chars[count]) == 0) {
-    if (++count >= num_of_chars) {
+    if (++count >= num_chars) {
       return 1;
     }
   }
@@ -902,14 +894,13 @@ static int xcore_draw_str(ui_window_t *window, ui_font_manager_t *font_man,
 
   fg_color = vt_char_fg_color(&chars[count]);
   bg_color = vt_char_bg_color(&chars[count]);
-  underline_style = vt_char_underline_style(&chars[count]);
-  is_crossed_out = vt_char_is_crossed_out(&chars[count]);
+  line_style = vt_char_line_style(&chars[count]);
 
   if (!(str2b = str = pic_glyphs = drcs_glyphs =
             /* '* 2' is for UTF16 surrogate pair. */
         alloca(K_MAX(sizeof(*str2b) * 2,
                      K_MAX(sizeof(*str), K_MAX(sizeof(*pic_glyphs), sizeof(*drcs_glyphs)))) *
-               num_of_chars))) {
+               num_chars))) {
     return 0;
   }
 
@@ -940,7 +931,7 @@ static int xcore_draw_str(ui_window_t *window, ui_font_manager_t *font_man,
      */
 
     do {
-      if (++count >= num_of_chars) {
+      if (++count >= num_chars) {
         start_draw = 1;
         end_of_str = 1;
 
@@ -954,8 +945,7 @@ static int xcore_draw_str(ui_window_t *window, ui_font_manager_t *font_man,
       ch_cs = FONT_CS(next_font);
       next_fg_color = vt_char_fg_color(&chars[count]);
       next_bg_color = vt_char_bg_color(&chars[count]);
-      next_underline_style = vt_char_underline_style(&chars[count]);
-      next_is_crossed_out = vt_char_is_crossed_out(&chars[count]);
+      next_line_style = vt_char_line_style(&chars[count]);
       next_comb_chars = vt_get_combining_chars(&chars[count], &next_comb_size);
       next_ch_width = calculate_char_width(next_xfont, ch_code, ch_cs, next_comb_chars,
                                            next_comb_size, &next_draw_alone);
@@ -979,17 +969,11 @@ static int xcore_draw_str(ui_window_t *window, ui_font_manager_t *font_man,
        * 'font & FONT_BOLD' is necessary.
        */
       else if (next_xfont != xfont || next_fg_color != fg_color || next_bg_color != bg_color ||
-               next_underline_style != underline_style || next_is_crossed_out != is_crossed_out
-               /*
-                * Eevn if both is_underline and next_is_underline are 1,
-                * underline is drawn one by one in vertical mode.
-                * (is_crossed_out is the same.)
-                */
-               ||
-               ((underline_style || is_crossed_out) && xfont->is_vertical) || next_state != state ||
-               draw_alone || next_draw_alone
+               next_line_style != line_style ||
+               /* If line_style > 0, line is drawn one by one in vertical mode. */
+               (line_style && xfont->is_vertical) || next_state != state ||
+               draw_alone || next_draw_alone ||
                /* FONT_BOLD flag is not the same */
-               ||
                ((font ^ next_font) & FONT_BOLD)) {
         start_draw = 1;
       } else {
@@ -1054,14 +1038,14 @@ static int xcore_draw_str(ui_window_t *window, ui_font_manager_t *font_man,
 
         if (state == 2) {
           ui_window_console_draw_string16(window, xfont, fg_xcolor, bg_xcolor, x, y + ascent, str2b,
-                                          str_len, underline_style);
+                                          str_len, line_style);
         } else if (state == 1) {
           ui_window_console_draw_decsp_string(window, xfont, fg_xcolor, bg_xcolor, x, y + ascent,
-                                              str, str_len, underline_style);
+                                              str, str_len, line_style);
         } else /* if( state == 0) */
         {
           ui_window_console_draw_string(window, xfont, fg_xcolor, bg_xcolor, x, y + ascent, str,
-                                        str_len, underline_style);
+                                        str_len, line_style);
         }
       }
 #else /* USE_CONSOLE */
@@ -1145,15 +1129,22 @@ static int xcore_draw_str(ui_window_t *window, ui_font_manager_t *font_man,
                                    y + ascent);
       }
 
-      if (!hide_underline && underline_style) {
-        draw_line(window, fg_xcolor, xfont->is_vertical,
-                  underline_style == UNDERLINE_DOUBLE ? 1 : 0, x, y, current_width - x, height,
-                  ascent + underline_offset, top_margin);
-      }
+      if (line_style) {
+        if ((line_style & LS_UNDERLINE) && !hide_underline) {
+          draw_line(window, fg_xcolor, xfont->is_vertical,
+                    line_style & LS_UNDERLINE,
+                    x, y, current_width - x, height, ascent + underline_offset, top_margin);
+        }
 
-      if (is_crossed_out) {
-        draw_line(window, fg_xcolor, xfont->is_vertical, 2, x, y, current_width - x, height, ascent,
-                  top_margin);
+        if (line_style & LS_CROSSED_OUT) {
+          draw_line(window, fg_xcolor, xfont->is_vertical,
+                    LS_CROSSED_OUT, x, y, current_width - x, height, ascent, top_margin);
+        }
+
+        if (line_style & LS_OVERLINE) {
+          draw_line(window, fg_xcolor, xfont->is_vertical,
+                    LS_OVERLINE, x, y, current_width - x, height, ascent, top_margin);
+        }
       }
 #endif /* USE_CONSOLE */
 
@@ -1172,8 +1163,7 @@ static int xcore_draw_str(ui_window_t *window, ui_font_manager_t *font_man,
     font = next_font;
     fg_color = next_fg_color;
     bg_color = next_bg_color;
-    underline_style = next_underline_style;
-    is_crossed_out = next_is_crossed_out;
+    line_style = next_line_style;
     state = next_state;
     draw_alone = next_draw_alone;
     comb_chars = next_comb_chars;
@@ -1197,11 +1187,15 @@ static int xcore_draw_str(ui_window_t *window, ui_font_manager_t *font_man,
 /* --- global functions --- */
 
 int ui_draw_str(ui_window_t *window, ui_font_manager_t *font_man, ui_color_manager_t *color_man,
-                vt_char_t *chars, u_int num_of_chars, int x, int y, u_int height, u_int ascent,
+                vt_char_t *chars, u_int num_chars, int x, int y, u_int height, u_int ascent,
                 int top_margin, int hide_underline, int underline_offset) {
   u_int updated_width;
   int ret;
 
+#ifdef __DEBUG
+  bl_debug_printf("Draw %d characters.\n", num_chars);
+#endif
+
   if (font_man->size_attr >= DOUBLE_HEIGHT_TOP) {
     ui_window_set_clip(window, x, y, window->width - x, height);
     ascent = height - (height - ascent) * 2;
@@ -1219,7 +1213,7 @@ int ui_draw_str(ui_window_t *window, ui_font_manager_t *font_man, ui_color_manag
 #if !defined(NO_DYNAMIC_LOAD_TYPE) || defined(USE_TYPE_XFT) || defined(USE_TYPE_CAIRO)
     case TYPE_XFT:
     case TYPE_CAIRO:
-      ret = fc_draw_str(window, font_man, color_man, &updated_width, chars, num_of_chars, x, y,
+      ret = fc_draw_str(window, font_man, color_man, &updated_width, chars, num_chars, x, y,
                         height, ascent, top_margin, hide_underline, underline_offset);
 
       break;
@@ -1227,7 +1221,7 @@ int ui_draw_str(ui_window_t *window, ui_font_manager_t *font_man, ui_color_manag
 
 #if !defined(NO_DYNAMIC_LOAD_TYPE) || defined(USE_TYPE_XCORE)
     case TYPE_XCORE:
-      ret = xcore_draw_str(window, font_man, color_man, &updated_width, chars, num_of_chars, x, y,
+      ret = xcore_draw_str(window, font_man, color_man, &updated_width, chars, num_chars, x, y,
                            height, ascent, top_margin, hide_underline, underline_offset);
 
       break;
@@ -1242,12 +1236,16 @@ int ui_draw_str(ui_window_t *window, ui_font_manager_t *font_man, ui_color_manag
 }
 
 int ui_draw_str_to_eol(ui_window_t *window, ui_font_manager_t *font_man,
-                       ui_color_manager_t *color_man, vt_char_t *chars, u_int num_of_chars, int x,
+                       ui_color_manager_t *color_man, vt_char_t *chars, u_int num_chars, int x,
                        int y, u_int height, u_int ascent, int top_margin,
                        int hide_underline, int underline_offset) {
   u_int updated_width;
   int ret;
 
+#ifdef __DEBUG
+  bl_debug_printf("Draw %d characters to eol.\n", num_chars);
+#endif
+
   if (font_man->size_attr >= DOUBLE_HEIGHT_TOP) {
     ui_window_set_clip(window, x, y, window->width - x, height);
     ascent = height - (height - ascent) * 2;
@@ -1269,7 +1267,7 @@ int ui_draw_str_to_eol(ui_window_t *window, ui_font_manager_t *font_man,
 
       ret = fc_draw_str(
           window, font_man, color_man, NULL /* NULL disables ui_window_clear() in fc_draw_str() */,
-          chars, num_of_chars, x, y, height, ascent, top_margin, hide_underline,
+          chars, num_chars, x, y, height, ascent, top_margin, hide_underline,
           underline_offset);
 
       break;
@@ -1277,7 +1275,7 @@ int ui_draw_str_to_eol(ui_window_t *window, ui_font_manager_t *font_man,
 
 #if !defined(NO_DYNAMIC_LOAD_TYPE) || defined(USE_TYPE_XCORE)
     case TYPE_XCORE:
-      ret = xcore_draw_str(window, font_man, color_man, &updated_width, chars, num_of_chars, x, y,
+      ret = xcore_draw_str(window, font_man, color_man, &updated_width, chars, num_chars, x, y,
                            height, ascent, top_margin, hide_underline, underline_offset);
 
       if (updated_width < window->width) {
@@ -1295,7 +1293,7 @@ int ui_draw_str_to_eol(ui_window_t *window, ui_font_manager_t *font_man,
   return ret;
 }
 
-u_int ui_calculate_mlchar_width(ui_font_t *font, vt_char_t *ch, int *draw_alone) {
+u_int ui_calculate_vtchar_width(ui_font_t *font, vt_char_t *ch, int *draw_alone) {
   ef_charset_t cs;
   vt_char_t *comb;
   u_int comb_size;
