@@ -62,7 +62,7 @@
 /* --- static variables --- */
 
 static XFontStruct **xfonts;
-static u_int num_of_xfonts;
+static u_int num_xfonts;
 
 static XFontStruct *get_cached_xfont(const char *file, int32_t format);
 static int add_xfont_to_cache(XFontStruct *xfont);
@@ -80,10 +80,10 @@ static int load_bitmaps(XFontStruct *xfont, u_char *p, size_t size, int is_be, i
   /* 0 -> byte , 1 -> short , 2 -> int */
   xfont->glyph_width_bytes = (glyph_pad_type == 2 ? 4 : (glyph_pad_type == 1 ? 2 : 1));
 
-  xfont->num_of_glyphs = _TOINT32(p, is_be);
+  xfont->num_glyphs = _TOINT32(p, is_be);
   p += 4;
 
-  if (size < 8 + sizeof(*offsets) * xfont->num_of_glyphs) {
+  if (size < 8 + sizeof(*offsets) * xfont->num_glyphs) {
 #ifdef DEBUG
     bl_debug_printf(BL_DEBUG_TAG " size %d is too small.\n", size);
 #endif
@@ -91,7 +91,7 @@ static int load_bitmaps(XFontStruct *xfont, u_char *p, size_t size, int is_be, i
     return 0;
   }
 
-  if (!(xfont->glyph_offsets = malloc(sizeof(*offsets) * xfont->num_of_glyphs))) {
+  if (!(xfont->glyph_offsets = malloc(sizeof(*offsets) * xfont->num_glyphs))) {
     return 0;
   }
 
@@ -101,10 +101,10 @@ static int load_bitmaps(XFontStruct *xfont, u_char *p, size_t size, int is_be, i
   if (!is_be)
 #endif
   {
-    memcpy(xfont->glyph_offsets, p, sizeof(*offsets) * xfont->num_of_glyphs);
-    p += (sizeof(*offsets) * xfont->num_of_glyphs);
+    memcpy(xfont->glyph_offsets, p, sizeof(*offsets) * xfont->num_glyphs);
+    p += (sizeof(*offsets) * xfont->num_glyphs);
   } else {
-    for (count = 0; count < xfont->num_of_glyphs; count++) {
+    for (count = 0; count < xfont->num_glyphs; count++) {
       xfont->glyph_offsets[count] = _TOINT32(p, is_be);
       p += 4;
     }
@@ -115,7 +115,7 @@ static int load_bitmaps(XFontStruct *xfont, u_char *p, size_t size, int is_be, i
     p += 4;
   }
 
-  if (size < 8 + sizeof(*offsets) * xfont->num_of_glyphs + 16 + bitmap_sizes[glyph_pad_type]) {
+  if (size < 8 + sizeof(*offsets) * xfont->num_glyphs + 16 + bitmap_sizes[glyph_pad_type]) {
 #ifdef DEBUG
     bl_debug_printf(BL_DEBUG_TAG " size %d is too small.\n", size);
 #endif
@@ -141,7 +141,7 @@ static int load_bitmaps(XFontStruct *xfont, u_char *p, size_t size, int is_be, i
   }
 
 #ifdef __DEBUG
-  bl_debug_printf(BL_DEBUG_TAG "GLYPH COUNT %d x WIDTH BYTE %d = SIZE %d\n", xfont->num_of_glyphs,
+  bl_debug_printf(BL_DEBUG_TAG "GLYPH COUNT %d x WIDTH BYTE %d = SIZE %d\n", xfont->num_glyphs,
                   xfont->glyph_width_bytes, bitmap_sizes[glyph_pad_type]);
 
   {
@@ -151,7 +151,7 @@ static int load_bitmaps(XFontStruct *xfont, u_char *p, size_t size, int is_be, i
 
     fp = fopen("log.txt", "w");
 
-    for (count = 0; count < xfont->num_of_glyphs; count++) {
+    for (count = 0; count < xfont->num_glyphs; count++) {
       fprintf(fp, "NUM %x\n", count);
       fprintf(fp, "%x\n", _TOINT32(p, is_be));
       p += 4;
@@ -262,32 +262,32 @@ static int load_encodings(XFontStruct *xfont, u_char *p, size_t size, int is_be)
 
 static int get_metrics(u_int8_t *width, u_int8_t *width_full, u_int8_t *height, u_int8_t *ascent,
                        u_char *p, size_t size, int is_be, int is_compressed) {
-  int16_t num_of_metrics;
+  int16_t num_metrics;
 
   /* XXX Proportional font is not considered. */
 
   if (is_compressed) {
-    num_of_metrics = _TOINT16(p, is_be);
+    num_metrics = _TOINT16(p, is_be);
     p += 2;
 
     *width = p[2] - 0x80;
     *ascent = p[3] - 0x80;
     *height = *ascent + (p[4] - 0x80);
 
-    if (num_of_metrics > 0x3000) {
+    if (num_metrics > 0x3000) {
       /* U+3000: Unicode ideographic space (Full width) */
       p += (5 * 0x3000);
       *width_full = p[2] - 0x80;
     } else {
-      *width_full = 0;
+      *width_full = *width;
     }
 
 #ifdef __DEBUG
-    bl_debug_printf(BL_DEBUG_TAG " COMPRESSED METRICS %d %d %d %d %d\n", num_of_metrics, *width,
+    bl_debug_printf(BL_DEBUG_TAG " COMPRESSED METRICS %d %d %d %d %d\n", num_metrics, *width,
                     *width_full, *height, *ascent);
 #endif
   } else {
-    num_of_metrics = _TOINT32(p, is_be);
+    num_metrics = _TOINT32(p, is_be);
     p += 4;
 
     /* skip {left|right}_sided_bearing */
@@ -301,7 +301,7 @@ static int get_metrics(u_int8_t *width, u_int8_t *width_full, u_int8_t *height,
 
     *height = *ascent + _TOINT16(p, is_be);
 
-    if (num_of_metrics > 0x3000) {
+    if (num_metrics > 0x3000) {
       /* skip character_descent and character attributes */
       p += 4;
 
@@ -313,11 +313,11 @@ static int get_metrics(u_int8_t *width, u_int8_t *width_full, u_int8_t *height,
 
       *width_full = _TOINT16(p, is_be);
     } else {
-      *width_full = 0;
+      *width_full = *width;
     }
 
 #ifdef __DEBUG
-    bl_debug_printf(BL_DEBUG_TAG " NOT COMPRESSED METRICS %d %d %d %d %d\n", num_of_metrics, *width,
+    bl_debug_printf(BL_DEBUG_TAG " NOT COMPRESSED METRICS %d %d %d %d %d\n", num_metrics, *width,
                     *width_full, *height, *ascent);
 #endif
   }
@@ -416,7 +416,7 @@ static int load_pcf(XFontStruct *xfont, const char *file_path) {
   struct stat st;
   u_char *pcf = NULL;
   u_char *p;
-  int32_t num_of_tables;
+  int32_t num_tables;
   int table_load_count;
   int32_t count;
 
@@ -451,14 +451,14 @@ static int load_pcf(XFontStruct *xfont, const char *file_path) {
 
   p += 4;
 
-  num_of_tables = _TOINT32(p, 0);
+  num_tables = _TOINT32(p, 0);
   p += 4;
 
-  if (st.st_size <= 8 + 16 * num_of_tables) {
+  if (st.st_size <= 8 + 16 * num_tables) {
     goto end;
   }
 
-  for (count = 0; count < num_of_tables; count++) {
+  for (count = 0; count < num_tables; count++) {
     int32_t type;
     int32_t format;
     int32_t size;
@@ -516,7 +516,7 @@ static int load_pcf(XFontStruct *xfont, const char *file_path) {
     int i;
     int j;
 
-    if ((bitmap = ui_get_bitmap(xfont, ch, sizeof(ch) - 1, NULL))) {
+    if ((bitmap = ui_get_bitmap(xfont, ch, sizeof(ch) - 1, 0, NULL))) {
       for (j = 0; j < xfont->height; j++) {
         u_char *line;
 
@@ -570,6 +570,7 @@ static int is_pcf(const char *file_path) {
 #ifdef FT_LCD_FILTER_H
 #include FT_LCD_FILTER_H
 #endif
+#include FT_OUTLINE_H
 
 /* 0 - 511 */
 #define SEG(idx) (((idx) >> 7) & 0x1ff)
@@ -578,6 +579,7 @@ static int is_pcf(const char *file_path) {
 /* +3 is for storing glyph position info. */
 #define IS_PROPORTIONAL(xfont) \
   ((xfont)->glyph_size == (xfont)->glyph_width_bytes * (xfont)->height + 3)
+#define FONT_ROTATED (FONT_ITALIC << 1)
 
 /* --- static variables --- */
 
@@ -616,6 +618,7 @@ static int get_glyph_index(FT_Face face, u_int32_t code) {
 }
 
 static int load_glyph(FT_Face face, int32_t format, u_int32_t code, int is_aa) {
+  FT_Glyph_Format orig_glyph_format;
   if (is_aa) {
     FT_Load_Glyph(face, code, FT_LOAD_NO_BITMAP);
 
@@ -626,12 +629,25 @@ static int load_glyph(FT_Face face, int32_t format, u_int32_t code, int is_aa) {
     FT_Load_Glyph(face, code, 0);
   }
 
-  if (format & FONT_ITALIC) {
+  orig_glyph_format = face->glyph->format;
+
+  if (format & FONT_ROTATED) {
     FT_Matrix matrix;
+
+    matrix.xx = 0;
+    matrix.xy = 0x10000L;  /* (FT_Fixed)(-sin((-90.0 / 360.0) * 3.141592 * 2) * 0x10000L */
+    matrix.yx = -0x10000L; /* (FT_Fixed)(sin((-90.0 / 360.0) * 3.141592 * 2) * 0x10000L */
+    matrix.yy = 0;
+
+    FT_Outline_Transform(&face->glyph->outline, &matrix);
+  } else if (format & FONT_ITALIC) {
+    FT_Matrix matrix;
+
     matrix.xx = 1 << 16;
     matrix.xy = 0x3000;
     matrix.yx = 0;
     matrix.yy = 1 << 16;
+
     FT_Outline_Transform(&face->glyph->outline, &matrix);
   }
 
@@ -645,6 +661,16 @@ static int load_glyph(FT_Face face, int32_t format, u_int32_t code, int is_aa) {
     FT_Render_Glyph(face->glyph, FT_RENDER_MODE_MONO);
   }
 
+  /*
+   * get_ft_bitmap_intern() uses face->glyph->format to check if glyph is actually rotated.
+   * (face->glyph->format == FT_GLYPH_FORMAT_BITMAP just after FT_Load_Glyph() means that
+   * glyphs is not rotated.)
+   *
+   * Note that FT_Render_Glyph() turns face->glyph->format from FT_GLYPH_FORMAT_OUTLINE
+   * to FT_GLYPH_FORMAT_BITMAP.
+   */
+  face->glyph->format = orig_glyph_format;
+
   return 1;
 }
 
@@ -668,11 +694,12 @@ static int load_ft(XFontStruct *xfont, const char *file_path, int32_t format, in
 #endif
   }
 
-  fontsize = (format & ~(FONT_BOLD | FONT_ITALIC));
+  fontsize = (format & ~(FONT_BOLD | FONT_ITALIC | FONT_ROTATED));
 
-  for (count = 0; count < num_of_xfonts; count++) {
+  for (count = 0; count < num_xfonts; count++) {
     if (strcmp(xfonts[count]->file, file_path) == 0 &&
-        (xfonts[count]->format & ~(FONT_BOLD | FONT_ITALIC)) == fontsize) {
+        /* The same face is used for normal, italic and bold. */
+        (xfonts[count]->format & ~(FONT_BOLD | FONT_ITALIC | FONT_ROTATED)) == fontsize) {
       face = xfonts[count]->face;
 
       goto face_found;
@@ -700,61 +727,63 @@ face_found:
     goto error;
   }
 
-  xfont->num_of_indeces = INITIAL_GLYPH_INDEX_TABLE_SIZE;
+  xfont->num_indeces = INITIAL_GLYPH_INDEX_TABLE_SIZE;
 
   if (!(xfont->file = strdup(file_path)) ||
-      !(xfont->glyph_indeces = calloc(xfont->num_of_indeces, sizeof(u_int16_t))) ||
+      !(xfont->glyph_indeces = calloc(xfont->num_indeces, sizeof(u_int16_t))) ||
       !(xfont->glyphs = calloc(MAX_GLYPH_TABLES, sizeof(u_char*)))) {
     goto error;
   }
 
   face->generic.data = ((int)face->generic.data) + 1; /* ref_count */
 
-  xfont->width_full =
-      (face->max_advance_width * face->size->metrics.x_ppem + face->units_per_EM - 1) /
-      face->units_per_EM;
-#ifdef __DEBUG
-  bl_debug_printf("maxw %d ppem %d units %d => w %d\n",
-                  face->max_advance_width, face->size->metrics.x_ppem,
-                  face->units_per_EM, xfont->width_full);
-#endif
-  if (is_aa) {
-    xfont->glyph_width_bytes = xfont->width_full * 3;
-    xfont->width = face->glyph->bitmap.width / 3;
-  } else {
-    xfont->glyph_width_bytes = (xfont->width_full + 7) / 8;
-    xfont->width = face->glyph->bitmap.width;
-  }
-
   if (force_height) {
     xfont->height = force_height;
   } else {
     xfont->height = (face->max_advance_height * face->size->metrics.y_ppem +
                      face->units_per_EM - 1) / face->units_per_EM;
-  }
 #ifdef __DEBUG
-  bl_debug_printf("maxh %d ppem %d units %d => h %d\n",
-                  face->max_advance_height, face->size->metrics.y_ppem,
-                  face->units_per_EM, xfont->height);
+    bl_debug_printf("maxh %d ppem %d units %d => h %d\n",
+                    face->max_advance_height, face->size->metrics.y_ppem,
+                    face->units_per_EM, xfont->height);
 #endif
-  xfont->ascent =
+  }
+
+  if (format & FONT_ROTATED) {
+    xfont->width = xfont->width_full = xfont->height;
+    xfont->ascent = 0;
+  } else {
+    xfont->width_full = (face->max_advance_width * face->size->metrics.x_ppem +
+                         face->units_per_EM - 1) / face->units_per_EM;
+#ifdef __DEBUG
+    bl_debug_printf("maxw %d ppem %d units %d => w %d\n",
+                    face->max_advance_width, face->size->metrics.x_ppem,
+                    face->units_per_EM, xfont->width_full);
+#endif
+
+    if (is_aa) {
+      xfont->width = face->glyph->bitmap.width / 3;
+    } else {
+      xfont->width = face->glyph->bitmap.width;
+    }
+
+    xfont->ascent =
       (face->ascender * face->size->metrics.y_ppem + face->units_per_EM - 1) / face->units_per_EM;
 
-  if (load_glyph(face, format, get_glyph_index(face, 'j'), is_aa)) {
-    int descent;
-
-    descent = face->glyph->bitmap.rows - face->glyph->bitmap_top;
-    if (descent > xfont->height - xfont->ascent) {
-      xfont->height = xfont->ascent + descent;
+    if (load_glyph(face, format, get_glyph_index(face, 'j'), is_aa)) {
+      int descent = face->glyph->bitmap.rows - face->glyph->bitmap_top;
+      if (descent > xfont->height - xfont->ascent) {
+        xfont->height = xfont->ascent + descent;
+      }
     }
   }
 
   if (is_aa) {
-    xfont->glyph_size = xfont->glyph_width_bytes * xfont->height;
+    xfont->glyph_width_bytes = xfont->width_full * 3;
   } else {
-    /* +1 is for the last 'dst[count] = ...' in get_ft_bitmap_intern(). */
-    xfont->glyph_size = xfont->glyph_width_bytes * xfont->height + 1;
+    xfont->glyph_width_bytes = (xfont->width_full + 7) / 8;
   }
+  xfont->glyph_size = xfont->glyph_width_bytes * xfont->height;
 
 #if 0
   bl_debug_printf("w %d %d h %d a %d\n", xfont->width, xfont->width_full, xfont->height,
@@ -799,8 +828,8 @@ static void clear_glyph_cache_ft(XFontStruct *xfont) {
   }
 
   memset(xfont->glyphs, 0, MAX_GLYPH_TABLES * sizeof(u_char*));
-  xfont->num_of_glyphs = 0;
-  memset(xfont->glyph_indeces, 0, xfont->num_of_indeces * sizeof(u_int16_t));
+  xfont->num_glyphs = 0;
+  memset(xfont->glyph_indeces, 0, xfont->num_indeces * sizeof(u_int16_t));
 }
 
 static void unload_ft(XFontStruct *xfont) {
@@ -822,25 +851,59 @@ static void unload_ft(XFontStruct *xfont) {
   free(xfont->glyphs);
   free(xfont->glyph_indeces);
 
-  if (num_of_xfonts == 0 && library) {
+  if (num_xfonts == 0 && library) {
     FT_Done_FreeType(library);
     library = NULL;
   }
 }
 
-static u_char *get_ft_bitmap_intern(XFontStruct *xfont, u_int32_t code /* glyph index */) {
+static int is_rotated_char(u_int32_t ch) {
+  if (ch < 0x80) {
+    return 1;
+  } else if ((ch & 0xffffff00) == 0x3000) {
+    if ((0x3008 <= ch && ch <= 0x3011) || (0x3013 <= ch && ch <= 0x301c) || ch == 0x30fc) {
+      return 1;
+    }
+  } else if ((ch & 0xffffff00) == 0xff00) {
+    if ((0xff08 <= ch && ch <= 0xff09) || ch == 0xff0d || (0xff1a <= ch && ch <= 0xff1e) ||
+        ch == 0xff3b || ch == 0xff3d || (0xff5b <= ch && ch <= 0xff5e) ||
+        (0xff62 <= ch && ch <= 0xff63)) {
+      return 1;
+    }
+  }
+  return 0;
+}
+
+static int is_right_aligned_char(u_int32_t ch) {
+  if ((ch & 0xffffff00) == 0x3000) {
+    if ((0x3001 <= ch && ch <= 0x3002) || ch == 0x3063 || ch == 0x30c3 ||
+        (((0x3041 <= ch && ch <= 0x3049) || (0x3083 <= ch && ch <= 0x3087) ||
+          (0x30a1 <= ch && ch <= 0x30a9) || (0x30e3 <= ch && ch <= 0x30e7)) &&
+         ch % 2 == 1)) {
+      return 1;
+    }
+  } else if ((ch & 0xffffff00) == 0xff00) {
+    if (ch == 0xff0c || ch == 0xff61 || ch == 0xff64) {
+      return 1;
+    }
+  }
+  return 0;
+}
+
+static u_char *get_ft_bitmap_intern(XFontStruct *xfont, u_int32_t code /* glyph index */,
+                                    u_int32_t ch) {
   u_int16_t *indeces;
   int idx;
   u_char **glyphs;
   u_char *glyph;
 
-  if (code >= xfont->num_of_indeces) {
+  if (code >= xfont->num_indeces) {
     if (!(indeces = realloc(xfont->glyph_indeces, sizeof(u_int16_t) * (code + 1)))) {
       return NULL;
     }
-    memset(indeces + xfont->num_of_indeces, 0,
-           sizeof(u_int16_t) * (code + 1 - xfont->num_of_indeces));
-    xfont->num_of_indeces = code + 1;
+    memset(indeces + xfont->num_indeces, 0,
+           sizeof(u_int16_t) * (code + 1 - xfont->num_indeces));
+    xfont->num_indeces = code + 1;
     xfont->glyph_indeces = indeces;
   } else {
     indeces = xfont->glyph_indeces;
@@ -856,26 +919,50 @@ static u_char *get_ft_bitmap_intern(XFontStruct *xfont, u_int32_t code /* glyph
     int left_pitch;
     int pitch;
     int rows;
+    int32_t format;
 
-    if (xfont->num_of_glyphs >= GLYPH_TABLE_SIZE * MAX_GLYPH_TABLES - 1) {
+    if (xfont->num_glyphs >= GLYPH_TABLE_SIZE * MAX_GLYPH_TABLES - 1) {
       bl_msg_printf("Unable to show U+%x because glyph cache is full.\n", code);
 
       return NULL;
     }
 
     face = xfont->face;
+    format = xfont->format;
+    left_pitch = 0;
 
-    if (!load_glyph(face, xfont->format, code, xfont->is_aa)) {
+    /* CJK characters etc aren't rotated. */
+    if (format & FONT_ROTATED) {
+      if (is_rotated_char(ch)) {
+        if (!load_glyph(face, xfont->format & ~FONT_ROTATED, code, xfont->is_aa)) {
+          return NULL;
+        }
+
+        left_pitch = (face->max_advance_height - face->ascender) * face->size->metrics.y_ppem /
+                     face->units_per_EM;
+        if (face->glyph->bitmap.rows > face->glyph->bitmap_top) {
+          if ((left_pitch -= (face->glyph->bitmap.rows - face->glyph->bitmap_top)) < 0) {
+            left_pitch = 0;
+          }
+        }
+
+        /* XXX 'if (xfont->is_aa) { left_pitch *= 3 }' is in the following block. */
+      } else {
+        format &= ~FONT_ROTATED;
+      }
+    }
+
+    if (!load_glyph(face, format, code, xfont->is_aa)) {
       return NULL;
     }
 
-    if (OFF(xfont->num_of_glyphs) == 0) {
-      if (!(glyphs[SEG(xfont->num_of_glyphs)] = calloc(GLYPH_TABLE_SIZE, xfont->glyph_size))) {
+    if (OFF(xfont->num_glyphs) == 0) {
+      if (!(glyphs[SEG(xfont->num_glyphs)] = calloc(GLYPH_TABLE_SIZE, xfont->glyph_size))) {
         return NULL;
       }
     }
 
-    idx = ++xfont->num_of_glyphs;
+    idx = ++xfont->num_glyphs;
 
 #if 0
     bl_debug_printf("%x %c w %d %d(%d) h %d(%d) at %d %d\n", code, code, face->glyph->bitmap.width,
@@ -885,11 +972,51 @@ static u_char *get_ft_bitmap_intern(XFontStruct *xfont, u_int32_t code /* glyph
 
     indeces[code] = idx;
 
-    if (xfont->is_aa) {
-      if ((left_pitch = face->glyph->bitmap_left * 3) < 0) {
-        left_pitch = 0;
+    if (xfont->format & FONT_ROTATED) {
+      if (!(format & FONT_ROTATED) || face->glyph->format == FT_GLYPH_FORMAT_BITMAP) {
+        /* Glyph isn't rotated. */
+
+        if (is_right_aligned_char(ch)) {
+          /* XXX Hack for vertical kutouten and sokuon */
+          left_pitch += (xfont->width / 2);
+        } else if (face->glyph->bitmap_left + face->glyph->bitmap.width <= xfont->width / 2) {
+          left_pitch += (xfont->width / 4);
+        }
       }
 
+      if (face->glyph->bitmap.rows < xfont->height) {
+        rows = face->glyph->bitmap.rows;
+        y = (xfont->height - face->glyph->bitmap.rows) / 2;
+      } else {
+        rows = xfont->height;
+        y = 0;
+      }
+    } else {
+      if (xfont->ascent > face->glyph->bitmap_top) {
+        y = xfont->ascent - face->glyph->bitmap_top;
+      } else {
+        y = 0;
+      }
+
+      if (face->glyph->bitmap.rows < xfont->height) {
+        rows = face->glyph->bitmap.rows;
+
+        if (rows + y > xfont->height) {
+          y = xfont->height - rows;
+        }
+      } else {
+        rows = xfont->height;
+        y = 0;
+      }
+    }
+
+    if (face->glyph->bitmap_left > 0) {
+      left_pitch += face->glyph->bitmap_left;
+    }
+
+    if (xfont->is_aa) {
+      left_pitch *= 3;
+
       if (face->glyph->bitmap.pitch < xfont->glyph_width_bytes) {
         pitch = face->glyph->bitmap.pitch;
 
@@ -904,11 +1031,8 @@ static u_char *get_ft_bitmap_intern(XFontStruct *xfont, u_int32_t code /* glyph
       if (face->glyph->bitmap.pitch <= xfont->glyph_width_bytes) {
         pitch = face->glyph->bitmap.pitch;
 
-        /* XXX left_pitch is 7 at most. */
-        if ((left_pitch = face->glyph->bitmap_left) > 7) {
+        if (left_pitch >= (xfont->glyph_width_bytes - pitch + 1) * 8) {
           left_pitch = 7;
-        } else if (left_pitch < 0) {
-          left_pitch = 0;
         }
       } else {
         pitch = xfont->glyph_width_bytes;
@@ -916,23 +1040,6 @@ static u_char *get_ft_bitmap_intern(XFontStruct *xfont, u_int32_t code /* glyph
       }
     }
 
-    if (xfont->ascent > face->glyph->bitmap_top) {
-      y = xfont->ascent - face->glyph->bitmap_top;
-    } else {
-      y = 0;
-    }
-
-    if (face->glyph->bitmap.rows < xfont->height) {
-      rows = face->glyph->bitmap.rows;
-
-      if (rows + y > xfont->height) {
-        y = xfont->height - rows;
-      }
-    } else {
-      rows = xfont->height;
-      y = 0;
-    }
-
     glyph = glyphs[SEG(idx - 1)] + xfont->glyph_size * OFF(idx - 1);
 
     src = face->glyph->bitmap.buffer;
@@ -974,22 +1081,32 @@ static u_char *get_ft_bitmap_intern(XFontStruct *xfont, u_int32_t code /* glyph
 #endif
       }
     } else {
-      for (y = 0; y < rows; y++) {
-        int count;
+      int shift;
+      if ((shift = left_pitch / 8) > 0) {
+        left_pitch -= (shift * 8);
+        dst += shift;
+      }
 
-        if (left_pitch == 0) {
+      if (left_pitch == 0) {
+        for (y = 0; y < rows; y++) {
           memcpy(dst, src, pitch);
-        } else {
-          dst += (left_pitch / 8);
+          src += face->glyph->bitmap.pitch;
+          dst += xfont->glyph_width_bytes;
+        }
+      } else {
+        int count;
+        for (y = 0; y < rows; y++) {
           dst[0] = (src[0] >> left_pitch);
           for (count = 1; count < pitch; count++) {
             dst[count] = (src[count - 1] << (8 - left_pitch)) | (src[count] >> left_pitch);
           }
-          dst[count] = (src[count - 1] << (8 - left_pitch));
-        }
+          if (shift + pitch < xfont->glyph_width_bytes) {
+            dst[count] = (src[count - 1] << (8 - left_pitch));
+          }
 
-        src += face->glyph->bitmap.pitch;
-        dst += xfont->glyph_width_bytes;
+          src += face->glyph->bitmap.pitch;
+          dst += xfont->glyph_width_bytes;
+        }
       }
     }
   } else {
@@ -1024,7 +1141,7 @@ static int use_fontconfig;
 static double dpi_for_fc;
 static FcPattern *compl_pattern;
 static char **fc_files;
-static u_int num_of_fc_files;
+static u_int num_fc_files;
 static FcCharSet **fc_charsets;
 
 static void compl_final(void) {
@@ -1035,7 +1152,7 @@ static void compl_final(void) {
     compl_pattern = NULL;
 
     if (fc_files) {
-      for (count = 0; count < num_of_fc_files; count++) {
+      for (count = 0; count < num_fc_files; count++) {
         free(fc_files[count]);
         FcCharSetDestroy(fc_charsets[count]);
       }
@@ -1051,7 +1168,7 @@ static void compl_xfonts_delete(XFontStruct **xfonts) {
   if (xfonts) {
     u_int count;
 
-    for (count = 0; count < num_of_fc_files; count++) {
+    for (count = 0; count < num_fc_files; count++) {
       if (xfonts[count]) {
         xfont_unref(xfonts[count]);
       }
@@ -1295,7 +1412,7 @@ static FcPattern *parse_font_name(const char *fontname, int *is_bold, int *is_it
     }
 
     if (compl_pattern == NULL) {
-      num_of_fc_files = strip_pattern((compl_pattern = pattern), match);
+      num_fc_files = strip_pattern((compl_pattern = pattern), match);
     } else {
       FcPatternDestroy(pattern);
     }
@@ -1329,9 +1446,10 @@ static u_char *get_ft_bitmap(XFontStruct *xfont, u_int32_t ch, int use_ot_layout
     }
   } else {
     code = ch;
+    ch = 0xffffffff; /* check_rotate() always returns 0. */
   }
 
-  return get_ft_bitmap_intern(xfont, code);
+  return get_ft_bitmap_intern(xfont, code, ch);
 
  compl_font:
   /*
@@ -1343,19 +1461,19 @@ static u_char *get_ft_bitmap(XFontStruct *xfont, u_int32_t ch, int use_ot_layout
   }
 
   if (!fc_files) {
-    if (!(fc_files = calloc(num_of_fc_files, sizeof(*fc_charsets) + sizeof(*fc_files)))) {
+    if (!(fc_files = calloc(num_fc_files, sizeof(*fc_charsets) + sizeof(*fc_files)))) {
       return NULL;
     }
 
-    fc_charsets = fc_files + num_of_fc_files;
+    fc_charsets = fc_files + num_fc_files;
   }
 
   if (!xfont->compl_xfonts &&
-      !(xfont->compl_xfonts = calloc(num_of_fc_files, sizeof(*xfont->compl_xfonts)))) {
+      !(xfont->compl_xfonts = calloc(num_fc_files, sizeof(*xfont->compl_xfonts)))) {
     return NULL;
   }
 
-  for (count = 0; count < num_of_fc_files;) {
+  for (count = 0; count < num_fc_files;) {
     if (!fc_files[count]) {
       FcResult result;
       FcPattern *match;
@@ -1364,7 +1482,7 @@ static u_char *get_ft_bitmap(XFontStruct *xfont, u_int32_t ch, int use_ot_layout
       FcPatternRemove(compl_pattern, FC_FAMILY, 0);
 
       if (match) {
-        num_of_fc_files = count + 1 + strip_pattern(compl_pattern, match);
+        num_fc_files = count + 1 + strip_pattern(compl_pattern, match);
 
         if (FcPatternGetCharSet(match, FC_CHARSET, 0, &fc_charsets[count]) == FcResultMatch) {
           FcValue val;
@@ -1379,7 +1497,7 @@ static u_char *get_ft_bitmap(XFontStruct *xfont, u_int32_t ch, int use_ot_layout
       }
 
       if (!fc_files[count]) {
-        num_of_fc_files --;
+        num_fc_files --;
         if (fc_charsets[count]) {
           FcCharSetDestroy(fc_charsets[count]);
         }
@@ -1416,7 +1534,7 @@ static u_char *get_ft_bitmap(XFontStruct *xfont, u_int32_t ch, int use_ot_layout
       }
 
       if ((code = get_glyph_index(xfont->compl_xfonts[count]->face, ch)) > 0) {
-        if ((bitmap = get_ft_bitmap_intern(xfont->compl_xfonts[count], code))) {
+        if ((bitmap = get_ft_bitmap_intern(xfont->compl_xfonts[count], code, ch))) {
           if (compl_xfont) {
             *compl_xfont = xfont->compl_xfonts[count];
           }
@@ -1445,7 +1563,7 @@ static u_char *get_ft_bitmap(XFontStruct *xfont, u_int32_t ch, int use_ot_layout
 static XFontStruct *get_cached_xfont(const char *file, int32_t format) {
   u_int count;
 
-  for (count = 0; count < num_of_xfonts; count++) {
+  for (count = 0; count < num_xfonts; count++) {
     if (strcmp(xfonts[count]->file, file) == 0
 #ifdef USE_FREETYPE
         && (xfonts[count]->face == NULL || xfonts[count]->format == format)
@@ -1466,7 +1584,7 @@ static XFontStruct *get_cached_xfont(const char *file, int32_t format) {
 static int add_xfont_to_cache(XFontStruct *xfont) {
   void *p;
 
-  if (!(p = realloc(xfonts, sizeof(XFontStruct*) * (num_of_xfonts + 1)))) {
+  if (!(p = realloc(xfonts, sizeof(XFontStruct*) * (num_xfonts + 1)))) {
     unload_xfont(xfont);
     free(xfont);
 
@@ -1474,7 +1592,7 @@ static int add_xfont_to_cache(XFontStruct *xfont) {
   }
 
   xfonts = p;
-  xfonts[num_of_xfonts++] = xfont;
+  xfonts[num_xfonts++] = xfont;
   xfont->ref_count = 1;
 
   return 1;
@@ -1488,10 +1606,10 @@ static void xfont_unref(XFontStruct *xfont) {
     compl_xfonts_delete(xfont->compl_xfonts);
 #endif
 
-    for (count = 0; count < num_of_xfonts; count++) {
+    for (count = 0; count < num_xfonts; count++) {
       if (xfonts[count] == xfont) {
-        if (--num_of_xfonts > 0) {
-          xfonts[count] = xfonts[num_of_xfonts];
+        if (--num_xfonts > 0) {
+          xfonts[count] = xfonts[num_xfonts];
         } else {
           free(xfonts);
           xfonts = NULL;
@@ -1506,7 +1624,7 @@ static void xfont_unref(XFontStruct *xfont) {
 
 #ifdef DEBUG
     bl_debug_printf(BL_DEBUG_TAG " %s font is unloaded. => CURRENT NUM OF XFONTS %d\n",
-                    xfont->file, num_of_xfonts);
+                    xfont->file, num_xfonts);
 #endif
 
     unload_xfont(xfont);
@@ -1520,10 +1638,8 @@ static int compose_dec_special_font;
 
 /* --- global functions --- */
 
-int ui_compose_dec_special_font(void) {
+void ui_compose_dec_special_font(void) {
   compose_dec_special_font = 1;
-
-  return 1;
 }
 
 #if defined(USE_FREETYPE) && defined(USE_FONTCONFIG)
@@ -1544,6 +1660,7 @@ ui_font_t *ui_font_new(Display *display, vt_font_t id, int size_attr, ui_type_en
 #ifdef USE_FREETYPE
   u_int format;
 #endif
+  u_int cols;
 
   cs = FONT_CS(id);
 
@@ -1709,6 +1826,11 @@ ui_font_t *ui_font_new(Display *display, vt_font_t id, int size_attr, ui_type_en
   }
 #endif
   format = fontsize | (id & (FONT_BOLD | FONT_ITALIC));
+  if (font_present & FONT_VERT_RTL) {
+    format |= FONT_ROTATED;
+    /* XXX Not support ROTATED and ITALIC at the same time. (see load_glyph()). */
+    format &= ~FONT_ITALIC;
+  }
 #endif
 
   if (decsp_id) {
@@ -1782,9 +1904,9 @@ xfont_loaded:
   font->id = orig_id;
 
   if (font->id & FONT_FULLWIDTH) {
-    font->cols = 2;
+    cols = 2;
   } else {
-    font->cols = 1;
+    cols = 1;
   }
 
 /*
@@ -1836,7 +1958,7 @@ xfont_loaded:
     font->double_draw_gap = 1;
   }
 
-  if ((id & FONT_FULLWIDTH) && font->xfont->width_full > 0) {
+  if (id & FONT_FULLWIDTH) {
     font->width = font->xfont->width_full;
   } else {
     font->width = font->xfont->width;
@@ -1884,13 +2006,17 @@ xfont_loaded:
         }
       }
     } else if (font->is_vertical) {
-      /*
-       * !! Notice !!
-       * The width of full and half character font is the same.
-       */
-
-      font->x_off = font->width / 2;
-      font->width *= 2;
+#ifdef USE_FREETYPE
+      if (!font->xfont->face || !(font->xfont->format & FONT_ROTATED))
+#endif
+      {
+        /*
+         * !! Notice !!
+         * The width of full and half character font is the same.
+         */
+        font->x_off = font->width / 2;
+        font->width *= 2;
+      }
     }
 
     if (letter_space > 0) {
@@ -1930,18 +2056,18 @@ xfont_loaded:
         }
       }
     } else {
-      if (font->width != col_width * font->cols) {
+      if (font->width != col_width * cols) {
         bl_msg_printf(
             "Font(id %x) width(%d) is not matched with "
             "standard width(%d).\n",
-            font->id, font->width, col_width * font->cols);
+            font->id, font->width, col_width * cols);
 
         if (!font->is_var_col_width) {
-          if (font->width < col_width * font->cols) {
-            font->x_off = (col_width * font->cols - font->width) / 2;
+          if (font->width < col_width * cols) {
+            font->x_off = (col_width * cols - font->width) / 2;
           }
 
-          font->width = col_width * font->cols;
+          font->width = col_width * cols;
         }
       }
     }
@@ -1964,7 +2090,7 @@ xfont_loaded:
 #endif
 
     /* XXX this may be inaccurate. */
-    font->width = DIVIDE_ROUNDINGUP(fontsize * font->cols, 2);
+    font->width = DIVIDE_ROUNDINGUP(fontsize * cols, 2);
   }
 
   if (font->height == 0) {
@@ -1979,7 +2105,7 @@ xfont_loaded:
 
 #ifdef DEBUG
   bl_debug_printf(BL_DEBUG_TAG " %s font is loaded. => CURRENT NUM OF XFONTS %d\n",
-                  font->xfont->file, num_of_xfonts);
+                  font->xfont->file, num_xfonts);
 #endif
 
 #ifdef DEBUG
@@ -1989,7 +2115,7 @@ xfont_loaded:
   return font;
 }
 
-int ui_font_delete(ui_font_t *font) {
+void ui_font_delete(ui_font_t *font) {
   xfont_unref(font->xfont);
 
 #ifdef USE_OT_LAYOUT
@@ -1999,23 +2125,6 @@ int ui_font_delete(ui_font_t *font) {
 #endif
 
   free(font);
-
-  return 1;
-}
-
-int ui_change_font_cols(ui_font_t *font, u_int cols /* 0 means default value */
-                        ) {
-  if (cols == 0) {
-    if (font->id & FONT_FULLWIDTH) {
-      font->cols = 2;
-    } else {
-      font->cols = 1;
-    }
-  } else {
-    font->cols = cols;
-  }
-
-  return 1;
 }
 
 #ifdef USE_OT_LAYOUT
@@ -2106,7 +2215,7 @@ size_t ui_convert_ucs4_to_utf16(u_char *dst, /* 4 bytes. Big endian. */
 
 #ifdef DEBUG
 
-int ui_font_dump(ui_font_t *font) {
+void ui_font_dump(ui_font_t *font) {
   bl_msg_printf("Font id %x: XFont %p (width %d, height %d, ascent %d, x_off %d)", font->id,
                 font->xfont, font->width, font->height, font->ascent, font->x_off);
 
@@ -2127,8 +2236,6 @@ int ui_font_dump(ui_font_t *font) {
   }
 
   bl_msg_printf("\n");
-
-  return 1;
 }
 
 #endif
