@@ -41,7 +41,7 @@ static LRESULT CALLBACK window_proc(HWND hwnd, UINT msg, WPARAM wparam, LPARAM l
   event.wparam = wparam;
   event.lparam = lparam;
 
-  for (count = 0; count < _disp.num_of_roots; count++) {
+  for (count = 0; count < _disp.num_roots; count++) {
     int val;
 
     val = ui_window_receive_event(_disp.roots[count], &event);
@@ -59,9 +59,13 @@ static int dialog_cb(bl_dialog_style_t style, const char *msg) {
   if (style == BL_DIALOG_OKCANCEL) {
     if (MessageBoxA(NULL, msg, "", MB_OKCANCEL) == IDOK) {
       return 1;
+    } else {
+      return 0;
     }
   } else if (style == BL_DIALOG_ALERT) {
     MessageBoxA(NULL, msg, "", MB_ICONSTOP);
+
+    return 1;
   } else {
     return -1;
   }
@@ -138,26 +142,24 @@ ui_display_t *ui_display_open(char *disp_name, /* Ignored */
   return &_disp;
 }
 
-int ui_display_close(ui_display_t *disp) {
+void ui_display_close(ui_display_t *disp) {
   if (disp == &_disp) {
-    return ui_display_close_all();
-  } else {
-    return 0;
+    ui_display_close_all();
   }
 }
 
-int ui_display_close_all(void) {
+void ui_display_close_all(void) {
   u_int count;
 
   if (!DISP_IS_INITED) {
-    return 0;
+    return;
   }
 
   ui_picture_display_closed(_disp.display);
 
   ui_gc_delete(_disp.gc);
 
-  for (count = 0; count < _disp.num_of_roots; count++) {
+  for (count = 0; count < _disp.num_roots; count++) {
     ui_window_unmap(_disp.roots[count]);
     ui_window_final(_disp.roots[count]);
   }
@@ -179,8 +181,6 @@ int ui_display_close_all(void) {
   _disp.display = NULL;
 
   ui_gdiobj_pool_final();
-
-  return 1;
 }
 
 ui_display_t **ui_get_opened_displays(u_int *num) {
@@ -204,7 +204,7 @@ int ui_display_show_root(ui_display_t *disp, ui_window_t *root, int x, int y, in
                          ) {
   void *p;
 
-  if ((p = realloc(disp->roots, sizeof(ui_window_t*) * (disp->num_of_roots + 1))) == NULL) {
+  if ((p = realloc(disp->roots, sizeof(ui_window_t*) * (disp->num_roots + 1))) == NULL) {
 #ifdef DEBUG
     bl_warn_printf(BL_DEBUG_TAG " realloc failed.\n");
 #endif
@@ -225,7 +225,7 @@ int ui_display_show_root(ui_display_t *disp, ui_window_t *root, int x, int y, in
     root->app_name = app_name;
   }
 
-  disp->roots[disp->num_of_roots++] = root;
+  disp->roots[disp->num_roots++] = root;
 
   return ui_window_show(root, hint);
 }
@@ -233,17 +233,17 @@ int ui_display_show_root(ui_display_t *disp, ui_window_t *root, int x, int y, in
 int ui_display_remove_root(ui_display_t *disp, ui_window_t *root) {
   u_int count;
 
-  for (count = 0; count < disp->num_of_roots; count++) {
+  for (count = 0; count < disp->num_roots; count++) {
     if (disp->roots[count] == root) {
       ui_window_unmap(root);
       ui_window_final(root);
 
-      disp->num_of_roots--;
+      disp->num_roots--;
 
-      if (count == disp->num_of_roots) {
+      if (count == disp->num_roots) {
         disp->roots[count] = NULL;
       } else {
-        disp->roots[count] = disp->roots[disp->num_of_roots];
+        disp->roots[count] = disp->roots[disp->num_roots];
       }
 
       return 1;
@@ -256,7 +256,7 @@ int ui_display_remove_root(ui_display_t *disp, ui_window_t *root) {
 void ui_display_idling(ui_display_t *disp) {
   u_int count;
 
-  for (count = 0; count < disp->num_of_roots; count++) {
+  for (count = 0; count < disp->num_roots; count++) {
     ui_window_idling(disp->roots[count]);
   }
 }
