@@ -27,8 +27,6 @@ static char *color_name_table[] = {
     "hl_black", "hl_red", "hl_green", "hl_yellow", "hl_blue", "hl_magenta", "hl_cyan", "hl_white",
 };
 
-static char color_name_256[4];
-
 static u_int8_t vtsys_color_rgb_table[][3] = {
     {0x00, 0x00, 0x00},
     {0xcd, 0x00, 0x00},
@@ -299,7 +297,7 @@ static u_int8_t color256_rgb_table[][3] = {
 
 static char *color_file = "mlterm/color";
 static BL_MAP(color_rgb) color_config;
-static u_int num_of_changed_256_colors;
+static u_int num_changed_256_colors;
 
 static struct {
   u_int is_changed : 1;
@@ -385,7 +383,7 @@ static int color_config_set_rgb(vt_color_t color, /* is 255 or less */
 
     if (r == red && g == green && b == blue && alpha == 0xff) {
       if (IS_256_COLOR(color)) {
-        num_of_changed_256_colors--;
+        num_changed_256_colors--;
       }
 
       bl_map_erase_simple(result, color_config, color);
@@ -429,7 +427,7 @@ static int color_config_set_rgb(vt_color_t color, /* is 255 or less */
       }
 #endif
 
-      num_of_changed_256_colors++;
+      num_changed_256_colors++;
     }
 
     bl_map_set(result, color_config, color, rgb);
@@ -482,7 +480,7 @@ static int parse_conf(char *color_name, char *rgb) {
       int result;
 
       if (IS_256_COLOR(color)) {
-        num_of_changed_256_colors--;
+        num_changed_256_colors--;
       }
 
       bl_map_erase_simple(result, color_config, color);
@@ -504,7 +502,7 @@ static int parse_conf(char *color_name, char *rgb) {
   return color_config_set_rgb(color, red, green, blue, alpha);
 }
 
-static int read_conf(const char *filename) {
+static void read_conf(const char *filename) {
   bl_file_t *from;
   char *color_name;
   char *rgb;
@@ -514,7 +512,7 @@ static int read_conf(const char *filename) {
     bl_warn_printf(BL_DEBUG_TAG " %s couldn't be opened.\n", filename);
 #endif
 
-    return 0;
+    return;
   }
 
   while (bl_conf_io_read(from, &color_name, &rgb)) {
@@ -522,8 +520,6 @@ static int read_conf(const char *filename) {
   }
 
   bl_file_close(from);
-
-  return 1;
 }
 
 /* --- global functions --- */
@@ -553,7 +549,7 @@ char *vt_get_color_mode(void) {
   }
 }
 
-int vt_color_config_init(void) {
+void vt_color_config_init(void) {
   char *rcpath;
 
   bl_map_new_with_size(vt_color_t, rgb_t, color_config, bl_map_hash_int, bl_map_compare_int, 16);
@@ -567,15 +563,11 @@ int vt_color_config_init(void) {
     read_conf(rcpath);
     free(rcpath);
   }
-
-  return 1;
 }
 
-int vt_color_config_final(void) {
+void vt_color_config_final(void) {
   bl_map_delete(color_config);
   color_config = NULL;
-
-  return 1;
 }
 
 /*
@@ -618,6 +610,7 @@ char *vt_get_color_name(vt_color_t color) {
     }
   } else if (IS_256_COLOR(color)) {
     /* XXX Not reentrant */
+    static char color_name_256[4];
 
     snprintf(color_name_256, sizeof(color_name_256), "%d", color);
 
@@ -772,6 +765,14 @@ end:
   return 1;
 }
 
+void vt_color_force_linear_search(int flag) {
+  if (flag) {
+    num_changed_256_colors++;
+  } else {
+    num_changed_256_colors--;
+  }
+}
+
 /*
  * Return the number of colors which should be searched after this function.
  */
@@ -786,7 +787,7 @@ u_int vt_get_closest_256_color(vt_color_t *closest, u_int *min_diff, u_int8_t re
   int count;
   int num;
 
-  if (num_of_changed_256_colors > 0) {
+  if (num_changed_256_colors > 0) {
     return 256;
   }
 
