@@ -24,16 +24,16 @@ typedef struct vt_config_menu {
 
 #ifdef NO_TOOLS
 
-#define vt_config_menu_init(config_menu) (1)
+#define vt_config_menu_init(config_menu) (0)
 #define vt_config_menu_final(config_menu) (0)
 #define vt_config_menu_start(config_menu, cmd_path, x, y, display, pty) (0)
 #define vt_config_menu_write(config_menu, buf, len) (0)
 
 #else /* NO_TOOLS */
 
-int vt_config_menu_init(vt_config_menu_t *config_menu);
+void vt_config_menu_init(vt_config_menu_t *config_menu);
 
-int vt_config_menu_final(vt_config_menu_t *config_menu);
+void vt_config_menu_final(vt_config_menu_t *config_menu);
 
 int vt_config_menu_start(vt_config_menu_t *config_menu, char *cmd_path, int x, int y, char *display,
                          vt_pty_ptr_t pty);
