@@ -11,7 +11,7 @@ typedef struct vt_iscii_state *vt_iscii_state_t;
 
 vt_isciikey_state_t vt_isciikey_state_new(int is_inscript);
 
-int vt_isciikey_state_delete(vt_isciikey_state_t state);
+void vt_isciikey_state_delete(vt_isciikey_state_t state);
 
 size_t vt_convert_ascii_to_iscii(vt_isciikey_state_t state, u_char *iscii, size_t iscii_len,
                                  u_char *ascii, size_t ascii_len);
