@@ -13,23 +13,23 @@
 
 /* --- global functions --- */
 
-int vt_log_init(vt_logs_t *logs, u_int num_of_rows) {
+int vt_log_init(vt_logs_t *logs, u_int num_rows) {
   logs->lines = NULL;
   logs->index = NULL;
-  logs->num_of_rows = 0;
+  logs->num_rows = 0;
 
-  if (num_of_rows == 0) {
+  if (num_rows == 0) {
     return 1;
   }
 
-  if ((logs->lines = calloc(sizeof(vt_line_t), num_of_rows)) == NULL) {
+  if ((logs->lines = calloc(sizeof(vt_line_t), num_rows)) == NULL) {
 #ifdef DEBUG
     bl_warn_printf(BL_DEBUG_TAG " calloc() failed.\n");
 #endif
     return 0;
   }
 
-  if ((logs->index = bl_cycle_index_new(num_of_rows)) == NULL) {
+  if ((logs->index = bl_cycle_index_new(num_rows)) == NULL) {
 #ifdef DEBUG
     bl_warn_printf(BL_DEBUG_TAG " bl_cycle_index_new() failed.\n");
 #endif
@@ -40,57 +40,55 @@ int vt_log_init(vt_logs_t *logs, u_int num_of_rows) {
     return 0;
   }
 
-  logs->num_of_rows = num_of_rows;
+  logs->num_rows = num_rows;
 
   return 1;
 }
 
-int vt_log_final(vt_logs_t *logs) {
-  int count;
+void vt_log_final(vt_logs_t *logs) {
+  u_int count;
 
-  if (logs->num_of_rows == 0) {
-    return 1;
+  if (logs->num_rows == 0) {
+    return;
   }
 
-  for (count = 0; count < logs->num_of_rows; count++) {
+  for (count = 0; count < logs->num_rows; count++) {
     vt_line_final(&logs->lines[count]);
   }
 
   bl_cycle_index_delete(logs->index);
 
   free(logs->lines);
-
-  return 1;
 }
 
-int vt_change_log_size(vt_logs_t *logs, u_int new_num_of_rows) {
-  u_int num_of_filled_rows;
+int vt_change_log_size(vt_logs_t *logs, u_int new_num_rows) {
+  u_int num_filled_rows;
 
   logs->unlimited = 0;
 
-  num_of_filled_rows = vt_get_num_of_logged_lines(logs);
+  num_filled_rows = vt_get_num_logged_lines(logs);
 
-  if (new_num_of_rows == logs->num_of_rows) {
+  if (new_num_rows == logs->num_rows) {
     return 1;
-  } else if (new_num_of_rows == 0) {
+  } else if (new_num_rows == 0) {
     free(logs->lines);
     logs->lines = NULL;
 
     bl_cycle_index_delete(logs->index);
     logs->index = NULL;
 
-    logs->num_of_rows = 0;
+    logs->num_rows = 0;
 
     return 1;
-  } else if (new_num_of_rows > logs->num_of_rows) {
+  } else if (new_num_rows > logs->num_rows) {
     vt_line_t *new_lines;
 
-    if (sizeof(vt_line_t) * new_num_of_rows < sizeof(vt_line_t) * logs->num_of_rows) {
+    if (sizeof(vt_line_t) * new_num_rows < sizeof(vt_line_t) * logs->num_rows) {
       /* integer overflow */
       return 0;
     }
 
-    if ((new_lines = realloc(logs->lines, sizeof(vt_line_t) * new_num_of_rows)) == NULL) {
+    if ((new_lines = realloc(logs->lines, sizeof(vt_line_t) * new_num_rows)) == NULL) {
 #ifdef DEBUG
       bl_warn_printf(BL_DEBUG_TAG " realloc() failed.\n");
 #endif
@@ -98,17 +96,17 @@ int vt_change_log_size(vt_logs_t *logs, u_int new_num_of_rows) {
       return 0;
     }
 
-    memset(&new_lines[logs->num_of_rows], 0,
-           sizeof(vt_line_t) * (new_num_of_rows - logs->num_of_rows));
+    memset(&new_lines[logs->num_rows], 0,
+           sizeof(vt_line_t) * (new_num_rows - logs->num_rows));
 
     logs->lines = new_lines;
-  } else if (new_num_of_rows < logs->num_of_rows) {
+  } else if (new_num_rows < logs->num_rows) {
     vt_line_t *new_lines;
     vt_line_t *line;
     int count;
     int start;
 
-    if ((new_lines = calloc(sizeof(vt_line_t), new_num_of_rows)) == NULL) {
+    if ((new_lines = calloc(sizeof(vt_line_t), new_num_rows)) == NULL) {
 #ifdef DEBUG
       bl_warn_printf(BL_DEBUG_TAG " calloc() failed.\n");
 #endif
@@ -116,12 +114,12 @@ int vt_change_log_size(vt_logs_t *logs, u_int new_num_of_rows) {
       return 0;
     }
 
-    num_of_filled_rows = vt_get_num_of_logged_lines(logs);
+    num_filled_rows = vt_get_num_logged_lines(logs);
 
-    if (new_num_of_rows >= num_of_filled_rows) {
+    if (new_num_rows >= num_filled_rows) {
       start = 0;
     } else {
-      start = num_of_filled_rows - new_num_of_rows;
+      start = num_filled_rows - new_num_rows;
     }
 
     /*
@@ -142,12 +140,12 @@ int vt_change_log_size(vt_logs_t *logs, u_int new_num_of_rows) {
     /*
      * copying to new lines.
      */
-    for (count = 0; count < new_num_of_rows; count++) {
+    for (count = 0; count < new_num_rows; count++) {
       if ((line = vt_log_get(logs, count + start)) == NULL) {
         break;
       }
 
-      vt_line_init(&new_lines[count], line->num_of_filled_chars);
+      vt_line_init(&new_lines[count], line->num_filled_chars);
       vt_line_share(&new_lines[count], line);
     }
 
@@ -156,16 +154,16 @@ int vt_change_log_size(vt_logs_t *logs, u_int new_num_of_rows) {
   }
 
   if (logs->index) {
-    if (!bl_cycle_index_change_size(logs->index, new_num_of_rows)) {
+    if (!bl_cycle_index_change_size(logs->index, new_num_rows)) {
       return 0;
     }
   } else {
-    if ((logs->index = bl_cycle_index_new(new_num_of_rows)) == NULL) {
+    if ((logs->index = bl_cycle_index_new(new_num_rows)) == NULL) {
       return 0;
     }
   }
 
-  logs->num_of_rows = new_num_of_rows;
+  logs->num_rows = new_num_rows;
 
   return 1;
 }
@@ -173,14 +171,14 @@ int vt_change_log_size(vt_logs_t *logs, u_int new_num_of_rows) {
 int vt_log_add(vt_logs_t *logs, vt_line_t *line) {
   int at;
 
-  if (logs->num_of_rows == 0) {
+  if (logs->num_rows == 0) {
     return 1;
   }
 
   if (logs->unlimited &&
       bl_get_filled_cycle_index(logs->index) == bl_get_cycle_index_size(logs->index)) {
-    if (logs->num_of_rows + 128 > logs->num_of_rows) {
-      vt_change_log_size(logs, logs->num_of_rows + 128);
+    if (logs->num_rows + 128 > logs->num_rows) {
+      vt_change_log_size(logs, logs->num_rows + 128);
       logs->unlimited = 1;
     }
   }
@@ -188,13 +186,13 @@ int vt_log_add(vt_logs_t *logs, vt_line_t *line) {
   at = bl_next_cycle_index(logs->index);
 
 #ifdef __DEBUG
-  bl_debug_printf(BL_DEBUG_TAG " %d len line logged to index %d.\n", line->num_of_filled_chars, at);
+  bl_debug_printf(BL_DEBUG_TAG " %d len line logged to index %d.\n", line->num_filled_chars, at);
 #endif
 
   vt_line_final(&logs->lines[at]);
 
   /* logs->lines[at] becomes completely the same one as line */
-  vt_line_clone(&logs->lines[at], line, line->num_of_filled_chars);
+  vt_line_clone(&logs->lines[at], line, line->num_filled_chars);
 
   vt_line_set_updated(&logs->lines[at]);
 
@@ -204,7 +202,7 @@ int vt_log_add(vt_logs_t *logs, vt_line_t *line) {
 vt_line_t *vt_log_get(vt_logs_t *logs, int at) {
   int _at;
 
-  if (at < 0 || vt_get_num_of_logged_lines(logs) <= at) {
+  if (at < 0 || vt_get_num_logged_lines(logs) <= at) {
 #ifdef DEBUG
     bl_warn_printf(BL_DEBUG_TAG " row %d is overflowed in logs.\n", at);
 #endif
@@ -219,8 +217,8 @@ vt_line_t *vt_log_get(vt_logs_t *logs, int at) {
   return &logs->lines[_at];
 }
 
-u_int vt_get_num_of_logged_lines(vt_logs_t *logs) {
-  if (logs->num_of_rows == 0) {
+u_int vt_get_num_logged_lines(vt_logs_t *logs) {
+  if (logs->num_rows == 0) {
     return 0;
   } else {
     return bl_get_filled_cycle_index(logs->index);
