@@ -13,23 +13,23 @@ typedef struct vt_model {
   vt_line_t *lines;
 
   /* public(readonly) */
-  u_int16_t num_of_cols; /* 0 - 65536 */
-  u_int16_t num_of_rows; /* 0 - 65536 */
+  u_int16_t num_cols; /* 0 - 65536 */
+  u_int16_t num_rows; /* 0 - 65536 */
 
   /* private */
   int beg_row; /* used for scrolling */
 
 } vt_model_t;
 
-int vt_model_init(vt_model_t *model, u_int num_of_cols, u_int num_of_rows);
+int vt_model_init(vt_model_t *model, u_int num_cols, u_int num_rows);
 
-int vt_model_final(vt_model_t *model);
+void vt_model_final(vt_model_t *model);
 
-int vt_model_reset(vt_model_t *model);
+void vt_model_reset(vt_model_t *model);
 
-int vt_model_resize(vt_model_t *model, u_int *slide, u_int num_of_cols, u_int num_of_rows);
+int vt_model_resize(vt_model_t *model, u_int *slide, u_int num_cols, u_int num_rows);
 
-u_int vt_model_get_num_of_filled_rows(vt_model_t *model);
+u_int vt_model_get_num_filled_rows(vt_model_t *model);
 
 int vt_model_end_row(vt_model_t *model);
 
