@@ -17,15 +17,19 @@ typedef enum vt_ot_layout_attr {
 
 typedef struct vt_ot_layout_state {
   void *term;
-  u_int8_t *num_of_chars_array;
+  u_int8_t *num_chars_array;
   u_int16_t size;
 
-  int8_t substituted;
+  int substituted : 2;
+  int complex_shape : 2;
+  int has_var_width_char : 2;
 
 } * vt_ot_layout_state_t;
 
 void vt_set_ot_layout_attr(char *value, vt_ot_layout_attr_t attr);
 
+char *vt_get_ot_layout_attr(vt_ot_layout_attr_t attr);
+
 void vt_ot_layout_set_shape_func(u_int (*func1)(void *, u_int32_t *, u_int, int8_t *, u_int8_t *,
                                                 u_int32_t *, u_int32_t *, u_int, const char *,
                                                 const char *),
@@ -42,7 +46,7 @@ int vt_ot_layout_delete(vt_ot_layout_state_t state);
 
 int vt_ot_layout(vt_ot_layout_state_t state, vt_char_t *src, u_int src_len);
 
-int vt_ot_layout_reset(vt_ot_layout_state_t state);
+void vt_ot_layout_reset(vt_ot_layout_state_t state);
 
 int vt_ot_layout_copy(vt_ot_layout_state_t dst, vt_ot_layout_state_t src, int optimize);
 
