@@ -13,7 +13,7 @@
 #include "vt_char_encoding.h"
 #include "vt_str_parser.h"
 
-#define ROW_IN_LOGS(screen, row) (vt_get_num_of_logged_lines(&(screen)->logs) + row)
+#define ROW_IN_LOGS(screen, row) (vt_get_num_logged_lines(&(screen)->logs) + row)
 
 /* Not contains the first page. */
 #define MAX_PAGE_ID 8
@@ -82,6 +82,10 @@ static void receive_scrolled_out_line(void *p, vt_line_t *line) {
 
   screen = p;
 
+  if (vt_status_line_is_focused(screen)) {
+    return;
+  }
+
   if (screen->screen_listener && screen->screen_listener->line_scrolled_out) {
     (*screen->screen_listener->line_scrolled_out)(screen->screen_listener->self);
   }
@@ -89,25 +93,25 @@ static void receive_scrolled_out_line(void *p, vt_line_t *line) {
   if (screen->logvis) {
     (*screen->logvis->visual_line)(screen->logvis, line);
   } else {
-    line->num_of_filled_chars =
-        vt_line_get_num_of_filled_chars_except_spaces_with_func(line, vt_char_equal);
+    line->num_filled_chars =
+        vt_line_get_num_filled_chars_except_sp_with_func(line, vt_char_equal);
   }
 
   vt_log_add(&screen->logs, line);
 
 /* XXX see vt_line_iscii_visual() */
 #if 1
-  if (line->num_of_chars > vt_screen_get_logical_cols(screen)) {
+  if (line->num_chars > vt_screen_get_logical_cols(screen)) {
     /*
-     * line->num_of_filled_chars can be more than line->num_of_chars
+     * line->num_filled_chars can be more than line->num_chars
      * without vt_line_reset() here because line is visualized.
      */
     vt_line_reset(line);
     vt_line_set_updated(line);
 
     vt_str_final(line->chars + vt_screen_get_logical_cols(screen),
-                 line->num_of_chars - vt_screen_get_logical_cols(screen));
-    line->num_of_chars = vt_screen_get_logical_cols(screen);
+                 line->num_chars - vt_screen_get_logical_cols(screen));
+    line->num_chars = vt_screen_get_logical_cols(screen);
   } else
 #endif
   {
@@ -185,7 +189,7 @@ static int modify_region(vt_screen_t *screen, /* visual */
   row = *end_row;
 
   while ((line = vt_screen_get_line(screen, row)) == NULL || vt_line_is_empty(line)) {
-    if (--row < 0 && abs(row) > vt_get_num_of_logged_lines(&screen->logs)) {
+    if (--row < 0 && abs(row) > vt_get_num_logged_lines(&screen->logs)) {
       return 0;
     }
   }
@@ -194,7 +198,7 @@ static int modify_region(vt_screen_t *screen, /* visual */
     if (vt_line_is_rtl(line)) {
       *end_char_index = vt_line_beg_char_index_regarding_rtl(line);
     } else {
-      if ((*end_char_index = vt_line_get_num_of_filled_chars_except_spaces(line)) > 0) {
+      if ((*end_char_index = vt_line_get_num_filled_chars_except_sp(line)) > 0) {
         (*end_char_index)--;
       }
     }
@@ -215,14 +219,14 @@ static void convert_col_to_char_index(vt_screen_t *screen, /* visual */
   u_int rest;
 
   if (vt_line_is_rtl(line) &&
-      (padding = vt_screen_get_cols(screen) - vt_line_get_num_of_filled_cols(line)) > 0) {
+      (padding = vt_screen_get_cols(screen) - vt_line_get_num_filled_cols(line)) > 0) {
     beg_col -= padding;
     end_col -= padding;
   }
 
   *beg_char_index = vt_convert_col_to_char_index(line, &rest, beg_col, 0);
 
-  if ((end = vt_line_get_num_of_filled_chars_except_spaces(line)) <= *beg_char_index ||
+  if ((end = vt_line_get_num_filled_chars_except_sp(line)) <= *beg_char_index ||
       (end == *beg_char_index + 1 && rest > 0)) {
     *beg_char_index = end;
   } else if ((beg = vt_line_beg_char_index_regarding_rtl(line)) > *beg_char_index) {
@@ -281,7 +285,7 @@ static int reverse_or_restore_color(vt_screen_t *screen, /* visual */
   int char_index;
   int row;
   vt_line_t *line;
-  u_int size_except_spaces;
+  u_int size_except_sp;
   int beg_regarding_rtl;
 
   if (!modify_region(screen, &end_char_index, &end_row)) {
@@ -297,19 +301,19 @@ static int reverse_or_restore_color(vt_screen_t *screen, /* visual */
       goto next_line;
     }
 
-    size_except_spaces = vt_line_get_num_of_filled_chars_except_spaces(line);
+    size_except_sp = vt_line_get_num_filled_chars_except_sp(line);
     beg_regarding_rtl = vt_line_beg_char_index_regarding_rtl(line);
 
     if (vt_line_is_rtl(line)) {
-      if (row > beg_row || beg_char_index >= size_except_spaces) {
-        beg_char_index = K_MAX(size_except_spaces, 1) - 1;
+      if (row > beg_row || beg_char_index >= size_except_sp) {
+        beg_char_index = K_MAX(size_except_sp, 1) - 1;
       } else if (beg_char_index < beg_regarding_rtl) {
         goto next_line;
       }
     } else {
       if (row > beg_row || beg_char_index < beg_regarding_rtl) {
         beg_char_index = beg_regarding_rtl;
-      } else if (beg_char_index >= size_except_spaces) {
+      } else if (beg_char_index >= size_except_sp) {
         goto next_line;
       }
     }
@@ -328,7 +332,7 @@ static int reverse_or_restore_color(vt_screen_t *screen, /* visual */
         (*func)(line, char_index);
       }
     } else {
-      for (char_index = beg_char_index; char_index < size_except_spaces; char_index++) {
+      for (char_index = beg_char_index; char_index < size_except_sp; char_index++) {
         (*func)(line, char_index);
       }
     }
@@ -338,9 +342,9 @@ static int reverse_or_restore_color(vt_screen_t *screen, /* visual */
         continue;
       }
 
-      size_except_spaces = vt_line_get_num_of_filled_chars_except_spaces(line);
+      size_except_sp = vt_line_get_num_filled_chars_except_sp(line);
 
-      for (char_index = vt_line_beg_char_index_regarding_rtl(line); char_index < size_except_spaces;
+      for (char_index = vt_line_beg_char_index_regarding_rtl(line); char_index < size_except_sp;
            char_index++) {
         (*func)(line, char_index);
       }
@@ -350,11 +354,11 @@ static int reverse_or_restore_color(vt_screen_t *screen, /* visual */
       return 1;
     }
 
-    size_except_spaces = vt_line_get_num_of_filled_chars_except_spaces(line);
+    size_except_sp = vt_line_get_num_filled_chars_except_sp(line);
     beg_regarding_rtl = vt_line_beg_char_index_regarding_rtl(line);
 
     if (vt_line_is_rtl(line)) {
-      beg_char_index = K_MAX(size_except_spaces, 1) - 1;
+      beg_char_index = K_MAX(size_except_sp, 1) - 1;
     } else {
       beg_char_index = beg_regarding_rtl;
     }
@@ -363,7 +367,7 @@ static int reverse_or_restore_color(vt_screen_t *screen, /* visual */
   /* row == end_row */
 
   if (vt_line_is_rtl(line)) {
-    if (end_char_index < size_except_spaces) {
+    if (end_char_index < size_except_sp) {
       for (char_index = K_MAX(end_char_index, beg_regarding_rtl); char_index <= beg_char_index;
            char_index++) {
         (*func)(line, char_index);
@@ -371,7 +375,7 @@ static int reverse_or_restore_color(vt_screen_t *screen, /* visual */
     }
   } else {
     if (end_char_index >= beg_regarding_rtl) {
-      for (char_index = beg_char_index; char_index < K_MIN(end_char_index + 1, size_except_spaces);
+      for (char_index = beg_char_index; char_index < K_MIN(end_char_index + 1, size_except_sp);
            char_index++) {
         (*func)(line, char_index);
       }
@@ -384,7 +388,7 @@ static int reverse_or_restore_color(vt_screen_t *screen, /* visual */
 static u_int check_or_copy_region_rect(
     vt_screen_t *screen, /* visual */
     vt_char_t *chars,    /* Behavior is undefined if chars is insufficient. */
-    u_int num_of_chars, int beg_col, int beg_row, int end_col, int end_row) {
+    u_int num_chars, int beg_col, int beg_row, int end_col, int end_row) {
   int row;
   vt_line_t *line;
   u_int region_size;
@@ -409,14 +413,14 @@ static u_int check_or_copy_region_rect(
 
       size = end_char_index - beg_char_index;
 
-      if (chars && num_of_chars >= region_size + size) {
+      if (chars && num_chars >= region_size + size) {
         vt_line_copy_logical_str(line, chars + region_size, beg_char_index, size);
       }
 
       region_size += size;
 
       if (row < end_row) {
-        if (chars && num_of_chars >= region_size + 1) {
+        if (chars && num_chars >= region_size + 1) {
           vt_char_copy(chars + region_size, vt_nl_ch());
         }
 
@@ -431,8 +435,8 @@ static u_int check_or_copy_region_rect(
 static u_int check_or_copy_region(
     vt_screen_t *screen,                    /* visual */
     vt_char_t *chars,                       /* Behavior is undefined if chars is insufficient. */
-    u_int num_of_chars, int beg_char_index, /* can be over size_except_spaces */
-    int beg_row, int end_char_index,        /* can be over size_except_spaces */
+    u_int num_chars, int beg_char_index, /* can be over size_except_sp */
+    int beg_row, int end_char_index,        /* can be over size_except_sp */
     int end_row) {
   /*
    * LTR line:    a<aa bbb ccc>
@@ -446,7 +450,7 @@ static u_int check_or_copy_region(
   vt_line_t *line;
   u_int size;
   u_int region_size;
-  u_int size_except_spaces;
+  u_int size_except_sp;
   int beg_regarding_rtl;
   int row;
 
@@ -467,19 +471,19 @@ static u_int check_or_copy_region(
       goto next_line;
     }
 
-    size_except_spaces = vt_line_get_num_of_filled_chars_except_spaces(line);
+    size_except_sp = vt_line_get_num_filled_chars_except_sp(line);
     beg_regarding_rtl = vt_line_beg_char_index_regarding_rtl(line);
 
     if (vt_line_is_rtl(line)) {
-      if (row > beg_row || beg_char_index >= size_except_spaces) {
-        beg_char_index = K_MAX(size_except_spaces, 1) - 1;
+      if (row > beg_row || beg_char_index >= size_except_sp) {
+        beg_char_index = K_MAX(size_except_sp, 1) - 1;
       } else if (beg_char_index < beg_regarding_rtl) {
         goto next_line;
       }
     } else {
       if (row > beg_row || beg_char_index < beg_regarding_rtl) {
         beg_char_index = beg_regarding_rtl;
-      } else if (beg_char_index >= size_except_spaces) {
+      } else if (beg_char_index >= size_except_sp) {
         goto next_line;
       }
     }
@@ -498,13 +502,13 @@ static u_int check_or_copy_region(
     if (vt_line_is_rtl(line)) {
       size = beg_char_index - beg_regarding_rtl + 1;
 
-      if (chars && num_of_chars >= region_size + size) {
+      if (chars && num_chars >= region_size + size) {
         vt_line_copy_logical_str(line, chars + region_size, beg_regarding_rtl, size);
       }
     } else {
-      size = size_except_spaces - beg_char_index;
+      size = size_except_sp - beg_char_index;
 
-      if (chars && num_of_chars >= region_size + size) {
+      if (chars && num_chars >= region_size + size) {
         vt_line_copy_logical_str(line, chars + region_size, beg_char_index, size);
       }
     }
@@ -512,7 +516,7 @@ static u_int check_or_copy_region(
     region_size += size;
 
     if (!vt_line_is_continued_to_next(line)) {
-      if (chars && num_of_chars > region_size) {
+      if (chars && num_chars > region_size) {
         vt_char_copy(chars + region_size, vt_nl_ch());
       }
       region_size++;
@@ -522,16 +526,16 @@ static u_int check_or_copy_region(
       line = vt_screen_get_line(screen, row);
 
       beg_regarding_rtl = vt_line_beg_char_index_regarding_rtl(line);
-      size = vt_line_get_num_of_filled_chars_except_spaces(line) - beg_regarding_rtl;
+      size = vt_line_get_num_filled_chars_except_sp(line) - beg_regarding_rtl;
 
-      if (chars && num_of_chars >= region_size + size) {
+      if (chars && num_chars >= region_size + size) {
         vt_line_copy_logical_str(line, chars + region_size, beg_regarding_rtl, size);
       }
 
       region_size += size;
 
       if (!vt_line_is_continued_to_next(line)) {
-        if (chars && num_of_chars > region_size) {
+        if (chars && num_chars > region_size) {
           vt_char_copy(chars + region_size, vt_nl_ch());
         }
         region_size++;
@@ -542,11 +546,11 @@ static u_int check_or_copy_region(
       return region_size;
     }
 
-    size_except_spaces = vt_line_get_num_of_filled_chars_except_spaces(line);
+    size_except_sp = vt_line_get_num_filled_chars_except_sp(line);
     beg_regarding_rtl = vt_line_beg_char_index_regarding_rtl(line);
 
     if (vt_line_is_rtl(line)) {
-      beg_char_index = K_MAX(size_except_spaces, 1) - 1;
+      beg_char_index = K_MAX(size_except_sp, 1) - 1;
     } else {
       beg_char_index = beg_regarding_rtl;
     }
@@ -554,17 +558,17 @@ static u_int check_or_copy_region(
 
   /* row == end_row */
 
-  if (size_except_spaces == 0) {
+  if (size_except_sp == 0) {
     /* do nothing */
   } else if (vt_line_is_rtl(line)) {
-    if (end_char_index < size_except_spaces) {
+    if (end_char_index < size_except_sp) {
       if (end_char_index < beg_regarding_rtl) {
         end_char_index = beg_regarding_rtl;
       }
 
       size = beg_char_index - end_char_index + 1;
 
-      if (chars && num_of_chars >= region_size + size) {
+      if (chars && num_chars >= region_size + size) {
         vt_line_copy_logical_str(line, chars + region_size, end_char_index, size);
       }
 
@@ -572,13 +576,13 @@ static u_int check_or_copy_region(
     }
   } else {
     if (end_char_index >= beg_regarding_rtl) {
-      if (end_char_index >= size_except_spaces) {
-        end_char_index = size_except_spaces - 1;
+      if (end_char_index >= size_except_sp) {
+        end_char_index = size_except_sp - 1;
       }
 
       size = end_char_index - beg_char_index + 1;
 
-      if (chars && num_of_chars >= region_size + size) {
+      if (chars && num_chars >= region_size + size) {
         vt_line_copy_logical_str(line, chars + region_size, beg_char_index, size);
       }
 
@@ -605,13 +609,23 @@ static u_int32_t get_msec_time(void) {
 static void change_edit(vt_screen_t *screen, vt_edit_t *edit) {
   vt_screen_disable_local_echo(screen);
 
-  edit->bce_ch = screen->edit->bce_ch;
+  if (edit != screen->status_edit) {
+    if (screen->logvis) {
+      (*screen->logvis->init)(screen->logvis, &edit->model, &edit->cursor);
+    }
 
-  if (screen->logvis) {
-    (*screen->logvis->init)(screen->logvis, &edit->model, &edit->cursor);
+    if (screen->main_edit) {
+      screen->main_edit = edit;
+    }
+
+    if (screen->edit != screen->status_edit) {
+      vt_edit_set_modified_all(edit);
+    }
+  } else {
+    screen->main_edit = screen->edit;
   }
 
-  vt_edit_set_modified_all(edit);
+  edit->bce_ch = screen->edit->bce_ch;
 
   screen->edit = edit;
 }
@@ -646,9 +660,21 @@ static vt_edit_t *get_edit(vt_screen_t *screen, u_int page_id) {
   return NULL;
 }
 
+static vt_edit_t *status_edit_new(vt_edit_t *main_edit) {
+  vt_edit_t *status_edit;
+
+  if ((status_edit = malloc(sizeof(vt_edit_t)))) {
+    vt_edit_init(status_edit, main_edit->scroll_listener,
+                 vt_edit_get_cols(main_edit), 1, vt_edit_get_tab_size(main_edit), 1,
+                 main_edit->use_bce);
+  }
+
+  return status_edit;
+}
+
 /* --- global functions --- */
 
-int vt_set_word_separators(const char *seps) {
+void vt_set_word_separators(const char *seps) {
   static char *default_word_separators;
 
   if (default_word_separators) {
@@ -660,19 +686,17 @@ int vt_set_word_separators(const char *seps) {
       /* Fall back to default. */
       word_separators = default_word_separators;
 
-      return 1;
+      return;
     }
   } else if (seps == NULL || *seps == '\0') {
     /* Not changed */
-    return 1;
+    return;
   } else {
     /* Store the default value. */
     default_word_separators = word_separators;
   }
 
   word_separators = bl_str_unescape(seps);
-
-  return 1;
 }
 
 char *vt_get_word_separators(void) { return word_separators; }
@@ -681,7 +705,7 @@ void vt_set_regard_uri_as_word(int flag) { regard_uri_as_word = flag; }
 
 int vt_get_regard_uri_as_word(void) { return regard_uri_as_word; }
 
-vt_screen_t *vt_screen_new(u_int cols, u_int rows, u_int tab_size, u_int num_of_log_lines,
+vt_screen_t *vt_screen_new(u_int cols, u_int rows, u_int tab_size, u_int num_log_lines,
                            int use_bce, vt_bs_mode_t bs_mode) {
   vt_screen_t *screen;
 
@@ -719,7 +743,7 @@ vt_screen_t *vt_screen_new(u_int cols, u_int rows, u_int tab_size, u_int num_of_
 
   screen->edit = &screen->normal_edit;
 
-  if (!vt_log_init(&screen->logs, num_of_log_lines)) {
+  if (!vt_log_init(&screen->logs, num_log_lines)) {
 #ifdef DEBUG
     bl_warn_printf(BL_DEBUG_TAG " vt_log_init failed.\n");
 #endif
@@ -764,6 +788,11 @@ int vt_screen_delete(vt_screen_t *screen) {
     free(screen->page_edits);
   }
 
+  if (screen->status_edit) {
+    vt_edit_final(screen->status_edit);
+    free(screen->status_edit);
+  }
+
   vt_log_final(&screen->logs);
 
   vt_screen_search_final(screen);
@@ -773,13 +802,20 @@ int vt_screen_delete(vt_screen_t *screen) {
   return 1;
 }
 
-int vt_screen_set_listener(vt_screen_t *screen, vt_screen_event_listener_t *screen_listener) {
+void vt_screen_set_listener(vt_screen_t *screen, vt_screen_event_listener_t *screen_listener) {
   screen->screen_listener = screen_listener;
-
-  return 1;
 }
 
+/* This considers status line ('row' contains status line) */
 int vt_screen_resize(vt_screen_t *screen, u_int cols, u_int rows) {
+  if (screen->status_edit) {
+    vt_edit_resize(screen->status_edit, cols, 1);
+
+    if (vt_screen_has_status_line(screen) && rows >= 2) {
+      rows--;
+    }
+  }
+
   vt_edit_resize(&screen->normal_edit, cols, rows);
   vt_edit_resize(&screen->alt_edit, cols, rows);
 
@@ -798,13 +834,23 @@ int vt_screen_resize(vt_screen_t *screen, u_int cols, u_int rows) {
   return 1;
 }
 
-int vt_screen_cursor_row_in_screen(vt_screen_t *screen) {
-  int row;
+/* This considers status line */
+int vt_screen_cursor_row(vt_screen_t *screen) {
+  int row = vt_cursor_row(screen->edit);
 
-  row = vt_cursor_row(screen->edit);
+  if (vt_status_line_is_focused(screen)) {
+    row += vt_edit_get_rows(screen->main_edit);
+  }
+
+  return row;
+}
+
+/* This considers status line */
+int vt_screen_cursor_row_in_screen(vt_screen_t *screen) {
+  int row = vt_screen_cursor_row(screen);
 
   if (screen->backscroll_rows > 0) {
-    if ((row += screen->backscroll_rows) >= vt_edit_get_rows(screen->edit)) {
+    if ((row += screen->backscroll_rows) >= vt_screen_get_rows(screen)) {
       return -1;
     }
   }
@@ -813,15 +859,33 @@ int vt_screen_cursor_row_in_screen(vt_screen_t *screen) {
 }
 
 u_int vt_screen_get_logical_cols(vt_screen_t *screen) {
-  if (screen->logvis) {
+  if (screen->logvis && screen->logvis->is_visual) {
     return (*screen->logvis->logical_cols)(screen->logvis);
   } else {
     return vt_edit_get_cols(screen->edit);
   }
 }
 
+/* This considers status line */
+u_int vt_screen_get_rows(vt_screen_t *screen) {
+  u_int rows;
+
+  rows = vt_edit_get_rows(screen->edit);
+
+  if (vt_screen_has_status_line(screen)) {
+    if (vt_status_line_is_focused(screen)) {
+      rows += vt_edit_get_rows(screen->main_edit);
+    } else {
+      rows ++;
+    }
+  }
+
+  return rows;
+}
+
+/* This ignores status line */
 u_int vt_screen_get_logical_rows(vt_screen_t *screen) {
-  if (screen->logvis) {
+  if (screen->logvis && screen->logvis->is_visual) {
     return (*screen->logvis->logical_rows)(screen->logvis);
   } else {
     return vt_edit_get_rows(screen->edit);
@@ -832,69 +896,52 @@ int vt_screen_convert_scr_row_to_abs(vt_screen_t *screen, int row) {
   return row - screen->backscroll_rows;
 }
 
+/* This considers status line */
 vt_line_t *vt_screen_get_line(vt_screen_t *screen, int row) {
-  if (row < -(int)vt_get_num_of_logged_lines(&screen->logs)) {
-#ifdef __DEBUG
-    bl_debug_printf(BL_DEBUG_TAG " row %d is over the beg of screen.\n", row);
-#endif
-
-    return NULL;
-  } else if (row >= (int)vt_edit_get_rows(screen->edit)) {
-#ifdef __DEBUG
-    bl_debug_printf(BL_DEBUG_TAG " row %d is over the end of screen.\n", row);
-#endif
-
-    return NULL;
-  }
-
   if (row < 0) {
     return vt_log_get(&screen->logs, ROW_IN_LOGS(screen, row));
+  } else if (vt_screen_has_status_line(screen)) {
+    if (row == vt_edit_get_rows(screen->main_edit)) {
+      return vt_edit_get_line(screen->status_edit, 0);
+    } else {
+      return vt_edit_get_line(screen->main_edit, row);
+    }
   } else {
     return vt_edit_get_line(screen->edit, row);
   }
 }
 
+/* This considers status line */
 vt_line_t *vt_screen_get_line_in_screen(vt_screen_t *screen, int row) {
   if (screen->is_backscrolling && screen->backscroll_rows > 0) {
-    int abs_row;
+    row -= screen->backscroll_rows;
 
-    if (row < 0 - (int)vt_get_num_of_logged_lines(&screen->logs)) {
-#ifdef __DEBUG
-      bl_debug_printf(BL_DEBUG_TAG " row %d is over the beg of screen.\n", row);
-#endif
-
-      return NULL;
-    } else if (row >= (int)vt_edit_get_rows(screen->edit)) {
-#ifdef __DEBUG
-      bl_debug_printf(BL_DEBUG_TAG " row %d is over the end of screen.\n", row);
-#endif
-
-      return NULL;
+    if (row < 0) {
+      return vt_log_get(&screen->logs, ROW_IN_LOGS(screen, row));
     }
+  }
 
-    abs_row = row - screen->backscroll_rows;
-
-    if (abs_row < 0) {
-      return vt_log_get(&screen->logs, ROW_IN_LOGS(screen, abs_row));
+  if (vt_screen_has_status_line(screen)) {
+    if (row == vt_edit_get_rows(screen->main_edit)) {
+      return vt_edit_get_line(screen->status_edit, 0);
     } else {
-      return vt_edit_get_line(screen->edit, abs_row);
+      return vt_edit_get_line(screen->main_edit, row);
     }
   } else {
     return vt_edit_get_line(screen->edit, row);
   }
 }
 
-int vt_screen_set_modified_all(vt_screen_t *screen) {
+void vt_screen_set_modified_all(vt_screen_t *screen) {
   int row;
   vt_line_t *line;
+  u_int num_rows = vt_screen_get_rows(screen);
 
-  for (row = 0; row < vt_edit_get_rows(screen->edit); row++) {
+  for (row = 0; row < num_rows; row++) {
     if ((line = vt_screen_get_line_in_screen(screen, row))) {
       vt_line_set_modified_all(line);
     }
   }
-
-  return 1;
 }
 
 int vt_screen_add_logical_visual(vt_screen_t *screen, vt_logical_visual_t *logvis) {
@@ -966,35 +1013,26 @@ vt_bs_mode_t vt_screen_is_backscrolling(vt_screen_t *screen) {
   }
 }
 
-int vt_set_backscroll_mode(vt_screen_t *screen, vt_bs_mode_t mode) {
+void vt_set_backscroll_mode(vt_screen_t *screen, vt_bs_mode_t mode) {
   screen->backscroll_mode = mode;
 
   if (screen->is_backscrolling) {
     screen->is_backscrolling = mode;
   }
-
-  return 1;
 }
 
-int vt_enter_backscroll_mode(vt_screen_t *screen) {
+void vt_enter_backscroll_mode(vt_screen_t *screen) {
   screen->is_backscrolling = screen->backscroll_mode;
-
-  return 1;
 }
 
-int vt_exit_backscroll_mode(vt_screen_t *screen) {
+void vt_exit_backscroll_mode(vt_screen_t *screen) {
   screen->is_backscrolling = 0;
   screen->backscroll_rows = 0;
 
   vt_screen_set_modified_all(screen);
-
-  return 1;
 }
 
 int vt_screen_backscroll_to(vt_screen_t *screen, int row) {
-  vt_line_t *line;
-  u_int count;
-
   if (!screen->is_backscrolling) {
     return 0;
   }
@@ -1005,13 +1043,7 @@ int vt_screen_backscroll_to(vt_screen_t *screen, int row) {
     screen->backscroll_rows = abs(row);
   }
 
-  for (count = 0; count < vt_edit_get_rows(screen->edit); count++) {
-    if ((line = vt_screen_get_line_in_screen(screen, count)) == NULL) {
-      break;
-    }
-
-    vt_line_set_modified_all(line);
-  }
+  vt_screen_set_modified_all(screen);
 
 #ifdef EXIT_BS_AT_BOTTOM
   if (screen->backscroll_rows == 0) {
@@ -1024,7 +1056,8 @@ int vt_screen_backscroll_to(vt_screen_t *screen, int row) {
 
 int vt_screen_backscroll_upward(vt_screen_t *screen, u_int size) {
   vt_line_t *line;
-  int count;
+  u_int count;
+  u_int num_rows;
 
   if (!screen->is_backscrolling) {
     return 0;
@@ -1040,10 +1073,12 @@ int vt_screen_backscroll_upward(vt_screen_t *screen, u_int size) {
 
   screen->backscroll_rows -= size;
 
+  num_rows = vt_screen_get_rows(screen);
+
   if (!screen->screen_listener || !screen->screen_listener->window_scroll_upward_region ||
       !(*screen->screen_listener->window_scroll_upward_region)(
-          screen->screen_listener->self, 0, vt_edit_get_rows(screen->edit) - 1, size)) {
-    for (count = 0; count < vt_edit_get_rows(screen->edit) - size; count++) {
+          screen->screen_listener->self, 0, num_rows - 1, size)) {
+    for (count = 0; count < num_rows - size; count++) {
       if ((line = vt_screen_get_line_in_screen(screen, count)) == NULL) {
         break;
       }
@@ -1052,8 +1087,7 @@ int vt_screen_backscroll_upward(vt_screen_t *screen, u_int size) {
     }
   }
 
-  for (count = vt_edit_get_rows(screen->edit) - size; count < vt_edit_get_rows(screen->edit);
-       count++) {
+  for (count = num_rows - size; count < num_rows; count++) {
     if ((line = vt_screen_get_line_in_screen(screen, count)) == NULL) {
       break;
     }
@@ -1073,13 +1107,14 @@ int vt_screen_backscroll_upward(vt_screen_t *screen, u_int size) {
 int vt_screen_backscroll_downward(vt_screen_t *screen, u_int size) {
   vt_line_t *line;
   u_int count;
+  int num_rows;
 
   if (!screen->is_backscrolling) {
     return 0;
   }
 
-  if (vt_get_num_of_logged_lines(&screen->logs) < screen->backscroll_rows + size) {
-    size = vt_get_num_of_logged_lines(&screen->logs) - screen->backscroll_rows;
+  if (vt_get_num_logged_lines(&screen->logs) < screen->backscroll_rows + size) {
+    size = vt_get_num_logged_lines(&screen->logs) - screen->backscroll_rows;
   }
 
   if (size == 0) {
@@ -1088,10 +1123,12 @@ int vt_screen_backscroll_downward(vt_screen_t *screen, u_int size) {
 
   screen->backscroll_rows += size;
 
+  num_rows = vt_screen_get_rows(screen);
+
   if (!screen->screen_listener || !screen->screen_listener->window_scroll_downward_region ||
       !(*screen->screen_listener->window_scroll_downward_region)(
-          screen->screen_listener->self, 0, vt_edit_get_rows(screen->edit) - 1, size)) {
-    for (count = size; count < vt_edit_get_rows(screen->edit); count++) {
+          screen->screen_listener->self, 0, num_rows - 1, size)) {
+    for (count = size; count < num_rows; count++) {
       if ((line = vt_screen_get_line_in_screen(screen, count)) == NULL) {
         break;
       }
@@ -1133,14 +1170,14 @@ int vt_screen_restore_color(vt_screen_t *screen, int beg_char_index, int beg_row
   }
 }
 
-u_int vt_screen_copy_region(vt_screen_t *screen, vt_char_t *chars, u_int num_of_chars,
+u_int vt_screen_copy_region(vt_screen_t *screen, vt_char_t *chars, u_int num_chars,
                             int beg_char_index, int beg_row, int end_char_index, int end_row,
                             int is_rect) {
   if (is_rect) {
-    return check_or_copy_region_rect(screen, chars, num_of_chars, beg_char_index, beg_row,
+    return check_or_copy_region_rect(screen, chars, num_chars, beg_char_index, beg_row,
                                      end_char_index, end_row);
   } else {
-    return check_or_copy_region(screen, chars, num_of_chars, beg_char_index, beg_row,
+    return check_or_copy_region(screen, chars, num_chars, beg_char_index, beg_row,
                                 end_char_index, end_row);
   }
 }
@@ -1183,7 +1220,7 @@ int vt_screen_get_line_region(vt_screen_t *screen, int *beg_row, int *end_char_i
     row++;
   }
 
-  *end_char_index = line->num_of_filled_chars - 1;
+  *end_char_index = line->num_filled_chars - 1;
   *end_row = row;
 
   /*
@@ -1293,7 +1330,7 @@ int vt_screen_get_word_region(vt_screen_t *screen, int *beg_char_index, int *beg
       }
 
       row--;
-      char_index = line->num_of_filled_chars - 1;
+      char_index = line->num_filled_chars - 1;
     } else {
       char_index--;
     }
@@ -1317,7 +1354,7 @@ int vt_screen_get_word_region(vt_screen_t *screen, int *beg_char_index, int *beg
   line = base_line;
 
   while (1) {
-    if (char_index == line->num_of_filled_chars - 1) {
+    if (char_index == line->num_filled_chars - 1) {
       if (!vt_line_is_continued_to_next(line) ||
           (line = vt_screen_get_line(screen, row + 1)) == NULL || vt_line_is_empty(line)) {
         *end_char_index = char_index;
@@ -1367,11 +1404,9 @@ int vt_screen_search_init(vt_screen_t *screen,
   return 1;
 }
 
-int vt_screen_search_final(vt_screen_t *screen) {
+void vt_screen_search_final(vt_screen_t *screen) {
   free(screen->search);
   screen->search = NULL;
-
-  return 1;
 }
 
 int vt_screen_search_reset_position(vt_screen_t *screen) {
@@ -1451,7 +1486,7 @@ int vt_screen_search_find(vt_screen_t *screen,
     size_t match_beg;
     size_t match_len;
 
-    if ((line_len = vt_line_get_num_of_filled_chars_except_spaces(line)) == 0) {
+    if ((line_len = vt_line_get_num_filled_chars_except_sp(line)) == 0) {
       continue;
     }
 
@@ -1588,13 +1623,14 @@ int vt_screen_blink(vt_screen_t *screen) {
     int char_index;
     int row;
     vt_line_t *line;
+    u_int num_rows = vt_screen_get_rows(screen);
 
-    for (row = 0; row + screen->backscroll_rows < vt_edit_get_rows(screen->edit); row++) {
+    for (row = 0; row + screen->backscroll_rows < num_rows; row++) {
       if ((line = vt_screen_get_line(screen, row)) == NULL) {
         continue;
       }
 
-      for (char_index = 0; char_index < line->num_of_filled_chars; char_index++) {
+      for (char_index = 0; char_index < line->num_filled_chars; char_index++) {
         if (vt_char_is_blinking(line->chars + char_index)) {
           vt_line_set_modified(line, char_index, char_index);
           has_blinking_char = 1;
@@ -1636,8 +1672,7 @@ vt_char_t *vt_screen_get_n_prev_char(vt_screen_t *screen, int n) {
 int vt_screen_combine_with_prev_char(vt_screen_t *screen, u_int32_t code, ef_charset_t cs,
                                      int is_fullwidth, int is_comb, vt_color_t fg_color,
                                      vt_color_t bg_color, int is_bold, int is_italic,
-                                     int is_underlined, int is_crossed_out, int is_blinking,
-                                     int is_protected) {
+                                     int line_style, int is_blinking, int is_protected) {
   int char_index;
   int row;
   vt_char_t *ch;
@@ -1656,7 +1691,7 @@ int vt_screen_combine_with_prev_char(vt_screen_t *screen, u_int32_t code, ef_cha
   }
 
   if (!vt_char_combine(ch, code, cs, is_fullwidth, is_comb, fg_color, bg_color, is_bold, is_italic,
-                       is_underlined, is_crossed_out, is_blinking, is_protected)) {
+                       line_style, is_blinking, is_protected)) {
     return 0;
   }
 
@@ -1874,7 +1909,7 @@ int vt_screen_local_echo_wait(vt_screen_t *screen, int msec /* 0: stored_edit->t
  */
 int vt_screen_disable_local_echo(vt_screen_t *screen) {
   u_int row;
-  u_int num_of_rows;
+  u_int num_rows;
   vt_line_t *old_line;
   vt_line_t *new_line;
 
@@ -1882,20 +1917,20 @@ int vt_screen_disable_local_echo(vt_screen_t *screen) {
     return 0;
   }
 
-  num_of_rows = vt_edit_get_rows(screen->edit);
+  num_rows = vt_edit_get_rows(screen->edit);
 
   /*
    * Set modified flag to the difference between the current edit and the stored
    * one
    * to restore the screen before starting local echo.
    */
-  for (row = 0; row < num_of_rows; row++) {
+  for (row = 0; row < num_rows; row++) {
     if ((new_line = vt_edit_get_line(&screen->stored_edit->edit, row)) &&
         (old_line = vt_edit_get_line(screen->edit, row)) &&
         (vt_line_is_modified(old_line) ||
-         old_line->num_of_filled_chars != new_line->num_of_filled_chars
+         old_line->num_filled_chars != new_line->num_filled_chars
 #if 1
-         || !vt_str_bytes_equal(old_line->chars, new_line->chars, new_line->num_of_filled_chars)
+         || !vt_str_bytes_equal(old_line->chars, new_line->chars, new_line->num_filled_chars)
 #endif
              )) {
       vt_line_set_modified_all(new_line);
@@ -1911,26 +1946,9 @@ int vt_screen_disable_local_echo(vt_screen_t *screen) {
   return 1;
 }
 
-int vt_screen_fill_area(vt_screen_t *screen, int code /* Unicode */, int is_protected,
-                        int col, int row, u_int num_of_cols, u_int num_of_rows) {
-  vt_char_t ch;
-
-  vt_char_init(&ch);
-
-  vt_char_set(&ch, code,
-              code <= 0x7f ? US_ASCII : ISO10646_UCS4_1, /* XXX biwidth is not supported. */
-              0, 0, VT_FG_COLOR, VT_BG_COLOR, 0, 0, 0, 0, 0, is_protected);
-
-  vt_edit_fill_area(screen->edit, &ch, col, row, num_of_cols, num_of_rows);
-
-  vt_char_final(&ch);
-
-  return 1;
-}
-
-int vt_screen_copy_area(vt_screen_t *screen, int src_col, int src_row, u_int num_of_copy_cols,
-                        u_int num_of_copy_rows, u_int src_page,
-                        int dst_col, int dst_row, u_int dst_page) {
+void vt_screen_copy_area(vt_screen_t *screen, int src_col, int src_row, u_int num_copy_cols,
+                         u_int num_copy_rows, u_int src_page,
+                         int dst_col, int dst_row, u_int dst_page) {
   vt_edit_t *src_edit;
   vt_edit_t *dst_edit;
 
@@ -1942,11 +1960,9 @@ int vt_screen_copy_area(vt_screen_t *screen, int src_col, int src_row, u_int num
   }
 
   if ((src_edit = get_edit(screen, src_page)) && (dst_edit = get_edit(screen, dst_page))) {
-    return vt_edit_copy_area(src_edit, src_col, src_row, num_of_copy_cols, num_of_copy_rows,
-                             dst_edit, dst_col, dst_row);
+    vt_edit_copy_area(src_edit, src_col, src_row, num_copy_cols, num_copy_rows,
+                      dst_edit, dst_col, dst_row);
   }
-
-  return 0;
 }
 
 void vt_screen_enable_blinking(vt_screen_t *screen) { screen->has_blinking_char = 1; }
@@ -1971,7 +1987,7 @@ int vt_screen_write_content(vt_screen_t *screen, int fd, ef_conv_t *conv, int cl
   } else {
     end = vt_screen_get_rows(screen);
     if (area == WCA_ALL) {
-      beg = -vt_screen_get_num_of_logged_lines(screen);
+      beg = -vt_screen_get_num_logged_lines(screen);
     } else /* if (area == WCA_SCREEN) */ {
       beg = 0;
     }
@@ -2075,3 +2091,46 @@ int vt_screen_goto_prev_page(vt_screen_t *screen, u_int offset) {
 
   return 0;
 }
+
+void vt_screen_set_use_status_line(vt_screen_t *screen, int use) {
+  if (use) {
+    if (!vt_screen_has_status_line(screen)) {
+      if ((!screen->status_edit && !(screen->status_edit = status_edit_new(screen->edit))) ||
+          /* XXX status line is *not* supported on vertical mode */
+          (screen->logvis && !screen->logvis->is_reversible)) {
+        return;
+      }
+
+      screen->main_edit = screen->edit;
+      screen->has_status_line = 1;
+      vt_edit_set_modified_all(screen->status_edit);
+
+      vt_screen_resize(screen, vt_edit_get_cols(screen->main_edit),
+                       vt_edit_get_rows(screen->main_edit));
+    }
+  } else {
+    if (vt_screen_has_status_line(screen)) {
+      screen->has_status_line = 0;
+
+      vt_screen_resize(screen, vt_edit_get_cols(screen->main_edit),
+                       vt_edit_get_rows(screen->main_edit) + 1);
+      screen->main_edit = NULL;
+    }
+  }
+}
+
+void vt_focus_status_line(vt_screen_t *screen) {
+  if (!screen->status_edit && !(screen->status_edit = status_edit_new(screen->edit))) {
+    return;
+  }
+
+  if (!vt_status_line_is_focused(screen)) {
+    change_edit(screen, screen->status_edit);
+  }
+}
+
+void vt_focus_main_screen(vt_screen_t *screen) {
+  if (screen->main_edit && vt_status_line_is_focused(screen)) {
+    change_edit(screen, screen->main_edit);
+  }
+}
