@@ -54,6 +54,8 @@ typedef struct vt_screen {
   vt_edit_t alt_edit;
   vt_edit_t *page_edits;         /* stores 8 pages */
   vt_stored_edit_t *stored_edit; /* Store logical edits. */
+  vt_edit_t *main_edit;
+  vt_edit_t *status_edit;
 
   vt_edit_scroll_event_listener_t edit_scroll_listener;
 
@@ -79,9 +81,11 @@ typedef struct vt_screen {
 
   int8_t has_blinking_char;
 
+  int8_t has_status_line;
+
 } vt_screen_t;
 
-int vt_set_word_separators(const char *seps);
+void vt_set_word_separators(const char *seps);
 
 char *vt_get_word_separators(void);
 
@@ -91,13 +95,14 @@ int vt_get_regard_uri_as_word(void);
 
 #define vt_free_word_separators() vt_set_word_separators(NULL)
 
-vt_screen_t *vt_screen_new(u_int cols, u_int rows, u_int tab_size, u_int num_of_log_lines,
+vt_screen_t *vt_screen_new(u_int cols, u_int rows, u_int tab_size, u_int num_log_lines,
                            int use_bce, vt_bs_mode_t bs_mode);
 
 int vt_screen_delete(vt_screen_t *screen);
 
-int vt_screen_set_listener(vt_screen_t *screen, vt_screen_event_listener_t *screen_listener);
+void vt_screen_set_listener(vt_screen_t *screen, vt_screen_event_listener_t *screen_listener);
 
+/* This considers status line */
 int vt_screen_resize(vt_screen_t *screen, u_int cols, u_int rows);
 
 #define vt_screen_set_use_bce(screen, use) \
@@ -115,17 +120,22 @@ int vt_screen_resize(vt_screen_t *screen, u_int cols, u_int rows);
 
 #define vt_screen_cursor_col(screen) vt_cursor_col((screen)->edit)
 
-#define vt_screen_cursor_row(screen) vt_cursor_row((screen)->edit)
+/* XXX Don't call this in visual context for now. */
+#define vt_screen_cursor_logical_col(screen) vt_edit_cursor_logical_col((screen)->edit)
 
-#define vt_screen_cursor_relative_col(screen) vt_cursor_relative_col((screen)->edit)
-
-#define vt_screen_cursor_relative_row(screen) vt_cursor_relative_row((screen)->edit)
+/* This considers status line */
+int vt_screen_cursor_row(vt_screen_t *screen);
 
+/* This considers status line */
 int vt_screen_cursor_row_in_screen(vt_screen_t *screen);
 
+/* XXX Don't call this in visual context for now. */
+#define vt_screen_cursor_logical_row(screen) vt_edit_cursor_logical_row((screen)->edit)
+
 #define vt_screen_get_cols(screen) vt_edit_get_cols((screen)->edit)
 
-#define vt_screen_get_rows(screen) vt_edit_get_rows((screen)->edit)
+/* This considers status line */
+u_int vt_screen_get_rows(vt_screen_t *screen);
 
 u_int vt_screen_get_logical_cols(vt_screen_t *screen);
 
@@ -139,18 +149,20 @@ u_int vt_screen_get_logical_rows(vt_screen_t *screen);
 
 #define vt_screen_log_size_is_unlimited(screen) vt_log_size_is_unlimited(&(screen)->logs)
 
-#define vt_screen_get_num_of_logged_lines(screen) vt_get_num_of_logged_lines(&(screen)->logs)
+#define vt_screen_get_num_logged_lines(screen) vt_get_num_logged_lines(&(screen)->logs)
 
 int vt_screen_convert_scr_row_to_abs(vt_screen_t *screen, int row);
 
+/* This considers status line */
 vt_line_t *vt_screen_get_line(vt_screen_t *screen, int row);
 
+/* This considers status line */
 vt_line_t *vt_screen_get_line_in_screen(vt_screen_t *screen, int row);
 
 #define vt_screen_get_cursor_line(screen) \
   vt_edit_get_line((screen)->edit, vt_cursor_row((screen)->edit))
 
-int vt_screen_set_modified_all(vt_screen_t *screen);
+void vt_screen_set_modified_all(vt_screen_t *screen);
 
 int vt_screen_add_logical_visual(vt_screen_t *screen, vt_logical_visual_t *logvis);
 
@@ -167,13 +179,13 @@ int vt_screen_logical(vt_screen_t *screen);
 
 vt_bs_mode_t vt_screen_is_backscrolling(vt_screen_t *screen);
 
-int vt_set_backscroll_mode(vt_screen_t *screen, vt_bs_mode_t mode);
+void vt_set_backscroll_mode(vt_screen_t *screen, vt_bs_mode_t mode);
 
 #define vt_get_backscroll_mode(screen) ((screen)->backscroll_mode)
 
-int vt_enter_backscroll_mode(vt_screen_t *screen);
+void vt_enter_backscroll_mode(vt_screen_t *screen);
 
-int vt_exit_backscroll_mode(vt_screen_t *screen);
+void vt_exit_backscroll_mode(vt_screen_t *screen);
 
 int vt_screen_backscroll_to(vt_screen_t *screen, int row);
 
@@ -185,13 +197,15 @@ int vt_screen_backscroll_downward(vt_screen_t *screen, u_int size);
 
 #define vt_screen_set_tab_size(screen, tab_size) vt_edit_set_tab_size((screen)->edit, tab_size)
 
+#define vt_screen_is_tab_stop(screen, col) vt_edit_is_tab_stop((screen)->edit, col)
+
 int vt_screen_restore_color(vt_screen_t *screen, int beg_char_index, int beg_row,
                             int end_char_index, int end_row, int is_rect);
 
 int vt_screen_reverse_color(vt_screen_t *screen, int beg_char_index, int beg_row,
                             int end_char_index, int end_row, int is_rect);
 
-u_int vt_screen_copy_region(vt_screen_t *screen, vt_char_t *chars, u_int num_of_chars,
+u_int vt_screen_copy_region(vt_screen_t *screen, vt_char_t *chars, u_int num_chars,
                             int beg_char_index, int beg_row, int end_char_index, int end_row,
                             int is_rect);
 
@@ -207,7 +221,7 @@ int vt_screen_get_word_region(vt_screen_t *screen, int *beg_char_index, int *beg
 int vt_screen_search_init(vt_screen_t *screen,
                           int (*match)(size_t *, size_t *, void *, u_char *, int));
 
-int vt_screen_search_final(vt_screen_t *screen);
+void vt_screen_search_final(vt_screen_t *screen);
 
 int vt_screen_search_reset_position(vt_screen_t *screen);
 
@@ -225,8 +239,7 @@ vt_char_t *vt_screen_get_n_prev_char(vt_screen_t *screen, int n);
 int vt_screen_combine_with_prev_char(vt_screen_t *screen, u_int32_t code, ef_charset_t cs,
                                      int is_fullwidth, int is_comb, vt_color_t fg_color,
                                      vt_color_t bg_color, int is_bold, int is_italic,
-                                     int is_underlined, int is_crossed_out, int is_blinking,
-                                     int is_protected);
+                                     int line_style, int is_blinking, int is_protected);
 
 int vt_screen_insert_chars(vt_screen_t *screen, vt_char_t *chars, u_int len);
 
@@ -303,18 +316,19 @@ int vt_screen_go_downward(vt_screen_t *screen, u_int size);
 #define vt_screen_goto_beg_of_line(screen) vt_edit_goto_beg_of_line((screen)->edit)
 
 #define vt_screen_go_horizontally(screen, col) \
-  vt_screen_goto(screen, col, vt_cursor_row((screen)->edit))
+  vt_edit_goto((screen)->edit, col, vt_edit_cursor_logical_row((screen)->edit))
 
 #define vt_screen_go_vertically(screen, row) \
-  vt_screen_goto(screen, vt_cursor_col((screen)->edit), row)
+  vt_edit_goto((screen)->edit, vt_edit_cursor_logical_col((screen)->edit), row)
 
 #define vt_screen_goto_home(screen) vt_edit_goto_home((screen)->edit)
 
 #define vt_screen_goto(screen, col, row) vt_edit_goto((screen)->edit, col, row)
 
-#define vt_screen_set_relative_origin(screen) vt_edit_set_relative_origin((screen)->edit)
+#define vt_screen_set_relative_origin(screen, flag) \
+  vt_edit_set_relative_origin((screen)->edit, flag)
 
-#define vt_screen_set_absolute_origin(screen) vt_edit_set_absolute_origin((screen)->edit)
+#define vt_screen_is_relative_origin(screen) vt_edit_is_relative_origin((screen)->edit)
 
 #define vt_screen_set_auto_wrap(screen, flag) vt_edit_set_auto_wrap((screen)->edit, flag)
 
@@ -350,22 +364,22 @@ int vt_screen_local_echo_wait(vt_screen_t *screen, int msec);
 
 int vt_screen_disable_local_echo(vt_screen_t *screen);
 
-int vt_screen_fill_area(vt_screen_t *screen, int code, int is_protected, int col, int beg,
-                        u_int num_of_cols, u_int num_of_rows);
+#define vt_screen_fill_area(screen, code, is_protected, col, beg, num_cols, num_rows) \
+  vt_edit_fill_area((screen)->edit, code, is_protected, col, beg, num_cols, num_rows)
 
-int vt_screen_copy_area(vt_screen_t *screen, int src_col, int src_row, u_int num_of_copy_cols,
-                        u_int num_of_copy_rows, u_int src_page,
-                        int dst_col, int dst_row, u_int dst_page);
+void vt_screen_copy_area(vt_screen_t *screen, int src_col, int src_row, u_int num_copy_cols,
+                         u_int num_copy_rows, u_int src_page,
+                         int dst_col, int dst_row, u_int dst_page);
 
-#define vt_screen_erase_area(screen, col, row, num_of_cols, num_of_rows) \
-  vt_edit_erase_area((screen)->edit, col, row, num_of_cols, num_of_rows)
+#define vt_screen_erase_area(screen, col, row, num_cols, num_rows) \
+  vt_edit_erase_area((screen)->edit, col, row, num_cols, num_rows)
 
-#define vt_screen_change_attr_area(screen, col, row, num_of_cols, num_of_rows, attr) \
-  vt_edit_change_attr_area((screen)->edit, col, row, num_of_cols, num_of_rows,       \
+#define vt_screen_change_attr_area(screen, col, row, num_cols, num_rows, attr) \
+  vt_edit_change_attr_area((screen)->edit, col, row, num_cols, num_rows,       \
                            vt_char_change_attr, attr)
 
-#define vt_screen_reverse_attr_area(screen, col, row, num_of_cols, num_of_rows, attr) \
-  vt_edit_change_attr_area((screen)->edit, col, row, num_of_cols, num_of_rows,        \
+#define vt_screen_reverse_attr_area(screen, col, row, num_cols, num_rows, attr) \
+  vt_edit_change_attr_area((screen)->edit, col, row, num_cols, num_rows,        \
                            vt_char_reverse_attr, attr)
 
 #define vt_screen_set_use_rect_attr_select(screen, use) \
@@ -392,4 +406,19 @@ int vt_screen_goto_prev_page(vt_screen_t *prev, u_int offset);
 #define vt_screen_cursor_is_rtl(screen) \
   ((screen)->logvis ? vt_logical_visual_cursor_is_rtl((screen)->logvis) : 0)
 
+/* This considers status line */
+#define vt_screen_has_status_line(screen) ((screen)->has_status_line)
+
+/* This considers status line */
+void vt_screen_set_use_status_line(vt_screen_t *screen, int use);
+
+/* This considers status line */
+#define vt_status_line_is_focused(screen) ((screen)->edit == (screen)->status_edit)
+
+/* This considers status line */
+void vt_focus_status_line(vt_screen_t *screen);
+
+/* This considers status line */
+void vt_focus_main_screen(vt_screen_t *screen);
+
 #endif
