@@ -231,7 +231,7 @@ vt_term_t *vt_term_new(const char *term_type, u_int cols, u_int rows, u_int tab_
                        int use_ctl, vt_bidi_mode_t bidi_mode, const char *bidi_separators,
                        int use_dynamic_comb, vt_bs_mode_t bs_mode, vt_vertical_mode_t vertical_mode,
                        int use_local_echo, const char *win_name, const char *icon_name,
-                       vt_alt_color_mode_t alt_color_mode, int use_ot_layout,
+                       int use_ansi_colors, vt_alt_color_mode_t alt_color_mode, int use_ot_layout,
                        vt_cursor_style_t cursor_style, int ignore_broadcasted_chars) {
   vt_termcap_ptr_t termcap;
   vt_term_t *term;
@@ -271,7 +271,8 @@ vt_term_t *vt_term_new(const char *term_type, u_int cols, u_int rows, u_int tab_
   if (!(term->parser = vt_parser_new(term->screen, termcap, encoding, is_auto_encoding,
                                      use_auto_detect, logging_vt_seq, policy, col_size_a,
                                      use_char_combining, use_multi_col_char, win_name, icon_name,
-                                     alt_color_mode, cursor_style, ignore_broadcasted_chars))) {
+                                     use_ansi_colors, alt_color_mode, cursor_style,
+                                     ignore_broadcasted_chars))) {
 #ifdef DEBUG
     bl_warn_printf(BL_DEBUG_TAG " vt_parser_new failed.\n");
 #endif
@@ -305,7 +306,7 @@ error:
   return NULL;
 }
 
-int vt_term_delete(vt_term_t *term) {
+void vt_term_delete(vt_term_t *term) {
 #ifndef NO_IMAGE
   if (vt_term_pty_closed_event) {
     (*vt_term_pty_closed_event)(term);
@@ -328,11 +329,9 @@ int vt_term_delete(vt_term_t *term) {
   vt_parser_delete(term->parser);
 
   free(term);
-
-  return 1;
 }
 
-int vt_term_zombie(vt_term_t *term) {
+void vt_term_zombie(vt_term_t *term) {
   if (term->pty) {
     vt_pty_ptr_t pty;
 
@@ -348,8 +347,6 @@ int vt_term_zombie(vt_term_t *term) {
     bl_debug_printf(BL_DEBUG_TAG " term is already zombie.\n");
   }
 #endif
-
-  return 1;
 }
 
 /* The caller should swap width_pix and height_pix in vertical mode. */
@@ -554,15 +551,17 @@ size_t vt_term_write(vt_term_t *term, u_char *buf, size_t len) {
 
 /* The caller should swap width_pix and height_pix in vertical mode. */
 int vt_term_resize(vt_term_t *term, u_int cols, u_int rows, u_int width_pix, u_int height_pix) {
-  if (term->pty) {
-    vt_set_pty_winsize(term->pty, cols, rows, width_pix, height_pix);
-  }
-
   vt_screen_logical(term->screen);
   vt_screen_resize(term->screen, cols, rows);
   vt_screen_render(term->screen);
   vt_screen_visual(term->screen);
 
+  if (term->pty) {
+    /* Don't use cols and rows because status line might change rows in vt_screen_resize(). */
+    vt_set_pty_winsize(term->pty, vt_screen_get_logical_cols(term->screen),
+                       vt_screen_get_logical_rows(term->screen), width_pix, height_pix);
+  }
+
   return 1;
 }
 
@@ -601,9 +600,9 @@ int vt_term_unhighlight_cursor(vt_term_t *term, int revert_visual) {
  * Not implemented yet.
  */
 #if 0
-int vt_term_set_modified_region(vt_term_t *term, int beg_char_index, int beg_row, u_int nchars,
-                                u_int nrows) {
-  return 0;
+void vt_term_set_modified_region(vt_term_t *term, int beg_char_index, int beg_row, u_int nchars,
+                                 u_int nrows) {
+  return;
 }
 #endif
 
@@ -611,8 +610,8 @@ int vt_term_set_modified_region(vt_term_t *term, int beg_char_index, int beg_row
  * Not used.
  */
 #if 0
-int vt_term_set_modified_region_in_screen(vt_term_t *term, int beg_char_index, int beg_row,
-                                          u_int nchars, u_int nrows) {
+void vt_term_set_modified_region_in_screen(vt_term_t *term, int beg_char_index, int beg_row,
+                                           u_int nchars, u_int nrows) {
   int row;
   vt_line_t *line;
   int revert_to_visual;
@@ -637,12 +636,10 @@ int vt_term_set_modified_region_in_screen(vt_term_t *term, int beg_char_index, i
     /* vt_screen_render(term->screen); */
     vt_screen_visual(term->screen);
   }
-
-  return 1;
 }
 #endif
 
-int vt_term_set_modified_lines(vt_term_t *term, int beg, int end) {
+void vt_term_set_modified_lines(vt_term_t *term, int beg, int end) {
   int row;
   vt_line_t *line;
   int revert_to_visual;
@@ -667,11 +664,9 @@ int vt_term_set_modified_lines(vt_term_t *term, int beg, int end) {
     /* vt_screen_render(term->screen); */
     vt_screen_visual(term->screen);
   }
-
-  return 1;
 }
 
-int vt_term_set_modified_lines_in_screen(vt_term_t *term, int beg, int end) {
+void vt_term_set_modified_lines_in_screen(vt_term_t *term, int beg, int end) {
   int row;
   vt_line_t *line;
   int revert_to_visual;
@@ -696,11 +691,9 @@ int vt_term_set_modified_lines_in_screen(vt_term_t *term, int beg, int end) {
     /* vt_screen_render(term->screen); */
     vt_screen_visual(term->screen);
   }
-
-  return 1;
 }
 
-int vt_term_set_modified_all_lines_in_screen(vt_term_t *term) {
+void vt_term_set_modified_all_lines_in_screen(vt_term_t *term) {
   int revert_to_visual;
 
   /*
@@ -719,11 +712,9 @@ int vt_term_set_modified_all_lines_in_screen(vt_term_t *term) {
     /* vt_screen_render(term->screen); */
     vt_screen_visual(term->screen);
   }
-
-  return 1;
 }
 
-int vt_term_updated_all(vt_term_t *term) {
+void vt_term_updated_all(vt_term_t *term) {
   int row;
   vt_line_t *line;
 
@@ -749,8 +740,6 @@ int vt_term_updated_all(vt_term_t *term) {
     /* vt_screen_render(term->screen); */
     vt_screen_visual(term->screen);
   }
-
-  return 1;
 }
 
 /*
@@ -842,18 +831,18 @@ int vt_term_update_special_visual(vt_term_t *term) {
   }
 }
 
-int vt_term_enter_backscroll_mode(vt_term_t *term) {
+void vt_term_enter_backscroll_mode(vt_term_t *term) {
   /* XXX */
   if (term->vertical_mode) {
     bl_msg_printf("Not supported backscrolling in vertical mode.\n");
 
-    return 0;
+    return;
   }
 
   return vt_enter_backscroll_mode(term->screen);
 }
 
-int vt_term_set_icon_path(vt_term_t *term, const char *path) {
+void vt_term_set_icon_path(vt_term_t *term, const char *path) {
   free(term->icon_path);
 
   if (path && *path) {
@@ -861,8 +850,6 @@ int vt_term_set_icon_path(vt_term_t *term, const char *path) {
   } else {
     term->icon_path = NULL;
   }
-
-  return 1;
 }
 
 void vt_term_set_bidi_separators(vt_term_t *term, const char *bidi_separators) {
@@ -911,6 +898,10 @@ int vt_term_get_config(vt_term_t *term, vt_term_t *output, /* if term == output,
     } else {
       value = "false";
     }
+  } else if (strcmp(key, "ot_features") == 0) {
+    value = vt_get_ot_layout_attr(OT_FEATURES);
+  } else if (strcmp(key, "ot_script") == 0) {
+    value = vt_get_ot_layout_attr(OT_SCRIPT);
   }
 #endif
   else if (strcmp(key, "pty_name") == 0) {
