@@ -57,7 +57,7 @@ extern void (*vt_term_pty_closed_event)(vt_term_t *);
 extern int start_with_local_pty;
 #endif
 
-#define vt_term_init() vt_parser_init()
+#define vt_term_init vt_parser_init
 
 void vt_term_final(void);
 
@@ -68,12 +68,12 @@ vt_term_t *vt_term_new(const char *term_type, u_int cols, u_int rows, u_int tab_
                        int use_ctl, vt_bidi_mode_t bidi_mode, const char *bidi_separators,
                        int use_dynamic_comb, vt_bs_mode_t bs_mode, vt_vertical_mode_t vertical_mode,
                        int use_local_echo, const char *win_name, const char *icon_name,
-                       vt_alt_color_mode_t alt_color_mode, int use_ot_layout,
+                       int use_ansi_colors, vt_alt_color_mode_t alt_color_mode, int use_ot_layout,
                        vt_cursor_style_t cursor_style, int ignore_broadcasted_chars);
 
-int vt_term_delete(vt_term_t *term);
+void vt_term_delete(vt_term_t *term);
 
-int vt_term_zombie(vt_term_t *term);
+void vt_term_zombie(vt_term_t *term);
 
 int vt_term_open_pty(vt_term_t *term, const char *cmd_path, char **argv, char **env,
                      const char *host, const char *work_dir, const char *pass, const char *pubkey,
@@ -194,7 +194,7 @@ int vt_term_unhighlight_cursor(vt_term_t *term, int revert_visual);
 
 #define vt_term_log_size_is_unlimited(term) vt_screen_log_size_is_unlimited((term)->screen)
 
-#define vt_term_get_num_of_logged_lines(term) vt_screen_get_num_of_logged_lines((term)->screen)
+#define vt_term_get_num_logged_lines(term) vt_screen_get_num_logged_lines((term)->screen)
 
 #define vt_term_convert_scr_row_to_abs(term, row) \
   vt_screen_convert_scr_row_to_abs((term)->screen, row)
@@ -206,20 +206,20 @@ int vt_term_unhighlight_cursor(vt_term_t *term, int revert_visual);
 #define vt_term_get_cursor_line(term) vt_screen_get_cursor_line((term)->screen)
 
 #if 0
-int vt_term_set_modified_region(vt_term_t *term, int beg_char_index, int beg_row, u_int nchars,
-                                u_int nrows);
+void vt_term_set_modified_region(vt_term_t *term, int beg_char_index, int beg_row, u_int nchars,
+                                 u_int nrows);
 
-int vt_term_set_modified_region_in_screen(vt_term_t *term, int beg_char_index, int beg_row,
-                                          u_int nchars, u_int nrows);
+void vt_term_set_modified_region_in_screen(vt_term_t *term, int beg_char_index, int beg_row,
+                                           u_int nchars, u_int nrows);
 #endif
 
-int vt_term_set_modified_lines(vt_term_t *term, int beg, int end);
+void vt_term_set_modified_lines(vt_term_t *term, int beg, int end);
 
-int vt_term_set_modified_lines_in_screen(vt_term_t *term, int beg, int end);
+void vt_term_set_modified_lines_in_screen(vt_term_t *term, int beg, int end);
 
-int vt_term_set_modified_all_lines_in_screen(vt_term_t *term);
+void vt_term_set_modified_all_lines_in_screen(vt_term_t *term);
 
-int vt_term_updated_all(vt_term_t *term);
+void vt_term_updated_all(vt_term_t *term);
 
 int vt_term_update_special_visual(vt_term_t *term);
 
@@ -228,7 +228,7 @@ int vt_term_update_special_visual(vt_term_t *term);
 
 #define vt_term_is_backscrolling(term) vt_screen_is_backscrolling((term)->screen)
 
-int vt_term_enter_backscroll_mode(vt_term_t *term);
+void vt_term_enter_backscroll_mode(vt_term_t *term);
 
 #define vt_term_exit_backscroll_mode(term) vt_exit_backscroll_mode((term)->screen)
 
@@ -244,9 +244,9 @@ int vt_term_enter_backscroll_mode(vt_term_t *term);
 #define vt_term_restore_color(term, beg_char_index, beg_row, end_char_index, end_row, is_rect) \
   vt_screen_restore_color((term)->screen, beg_char_index, beg_row, end_char_index, end_row, is_rect)
 
-#define vt_term_copy_region(term, chars, num_of_chars, beg_char_index, beg_row, end_char_index, \
+#define vt_term_copy_region(term, chars, num_chars, beg_char_index, beg_row, end_char_index, \
                             end_row, is_rect)                                                   \
-  vt_screen_copy_region((term)->screen, chars, num_of_chars, beg_char_index, beg_row,           \
+  vt_screen_copy_region((term)->screen, chars, num_chars, beg_char_index, beg_row,           \
                         end_char_index, end_row, is_rect)
 
 #define vt_term_get_region_size(term, beg_char_index, beg_row, end_char_index, end_row, is_rect) \
@@ -283,7 +283,7 @@ int vt_term_enter_backscroll_mode(vt_term_t *term);
 
 #define vt_term_is_broadcasting(term) vt_parser_is_broadcasting((term)->parser)
 
-int vt_term_set_icon_path(vt_term_t *term, const char *path);
+void vt_term_set_icon_path(vt_term_t *term, const char *path);
 
 #define vt_term_window_name(term) vt_get_window_name((term)->parser)
 
@@ -333,6 +333,8 @@ int vt_term_set_config(vt_term_t *term, char *key, char *value);
 
 #define vt_term_blink(term) vt_screen_blink((term)->screen)
 
+#define vt_term_has_status_line(term) vt_screen_has_status_line((term)->screen)
+
 #define vt_term_get_user_data(term, key) ((term)->user_data)
 
 #define vt_term_set_user_data(term, key, val) ((term)->user_data = (val))
