@@ -39,7 +39,7 @@ static u_int32_t *dead_mask;
  * So 'terms' array must be allocated only once.
  */
 static vt_term_t **terms;
-static u_int num_of_terms;
+static u_int num_terms;
 
 static char *pty_list;
 
@@ -57,7 +57,7 @@ static void sig_error(int sig) {
 
   env[0] = '\0';
   len = 0;
-  for (count = 0; count < num_of_terms; count++) {
+  for (count = 0; count < num_terms; count++) {
     int master;
 
     if ((master = vt_term_get_master_fd(terms[count])) >= 0) {
@@ -91,7 +91,7 @@ static void sig_error(int sig) {
 
     if (pid == 0) {
       /* child process */
-      for (count = 0; count < num_of_terms; count++) {
+      for (count = 0; count < num_terms; count++) {
         vt_term_write_content(terms[count], vt_term_get_slave_fd(terms[count]),
                               terms[count]->parser->cc_conv, 1, WCA_ALL);
       }
@@ -134,7 +134,7 @@ static void sig_child(void *p, pid_t pid) {
     return;
   }
 
-  for (count = 0; count < num_of_terms; count++) {
+  for (count = 0; count < num_terms; count++) {
     if (pid == vt_term_get_child_pid(terms[count])) {
       u_int idx;
 
@@ -162,19 +162,29 @@ int vt_term_manager_init(u_int multiple) {
   }
 
   if ((dead_mask = calloc(sizeof(*dead_mask), max_terms_multiple)) == NULL) {
-    free(terms);
-    terms = NULL;
+    goto error1;
+  }
 
-    return 0;
+  if (!vt_term_init()) {
+    goto error2;
   }
 
   bl_add_sig_child_listener(NULL, sig_child);
-  vt_term_init();
 
   return 1;
+
+error2:
+  free(dead_mask);
+  dead_mask = NULL;
+
+error1:
+  free(terms);
+  terms = NULL;
+
+  return 0;
 }
 
-int vt_term_manager_final(void) {
+void vt_term_manager_final(void) {
   int count;
 
 #ifdef USE_OT_LAYOUT
@@ -185,7 +195,7 @@ int vt_term_manager_final(void) {
   bl_remove_sig_child_listener(NULL, sig_child);
   vt_term_final();
 
-  for (count = num_of_terms - 1; count >= 0; count--) {
+  for (count = num_terms - 1; count >= 0; count--) {
 #if 0
     /*
      * All windows may be invalid before vt_term_manager_final() is called.
@@ -204,11 +214,9 @@ int vt_term_manager_final(void) {
   free(dead_mask);
   free(pty_list);
   free(auto_restart_cmd);
-
-  return 1;
 }
 
-int vt_set_auto_restart_cmd(char *cmd) {
+void vt_set_auto_restart_cmd(char *cmd) {
 #if !defined(USE_WIN32API) && !defined(DEBUG)
   char *env;
 
@@ -249,8 +257,6 @@ int vt_set_auto_restart_cmd(char *cmd) {
     auto_restart_cmd = NULL;
   }
 #endif
-
-  return 1;
 }
 
 vt_term_t *vt_create_term(const char *term_type, u_int cols, u_int rows, u_int tab_size,
@@ -261,13 +267,14 @@ vt_term_t *vt_create_term(const char *term_type, u_int cols, u_int rows, u_int t
                           int use_dynamic_comb, vt_bs_mode_t bs_mode,
                           vt_vertical_mode_t vertical_mode, int use_local_echo,
                           const char *win_name, const char *icon_name,
-                          vt_alt_color_mode_t alt_color_mode, int use_ot_layout,
-                          vt_cursor_style_t cursor_style, int ignore_broadcasted_chars) {
+                          int use_ansi_colors, vt_alt_color_mode_t alt_color_mode,
+                          int use_ot_layout, vt_cursor_style_t cursor_style,
+                          int ignore_broadcasted_chars) {
 #if !defined(USE_WIN32API) && !defined(DEBUG)
   char *list;
 #endif
 
-  if (num_of_terms == MAX_TERMS) {
+  if (num_terms == MAX_TERMS) {
     return NULL;
   }
 
@@ -286,13 +293,13 @@ vt_term_t *vt_create_term(const char *term_type, u_int cols, u_int rows, u_int t
          * cols + 1 is for redrawing screen by vt_set_pty_winsize() below.
          */
         if ((pty = vt_pty_new_with(master, slave, child_pid, cols + 1, rows, 0, 0))) {
-          if ((terms[num_of_terms] = vt_term_new(
+          if ((terms[num_terms] = vt_term_new(
                    term_type, cols, rows, tab_size, log_size, encoding, is_auto_encoding,
                    use_auto_detect, logging_vt_seq, policy, col_size_a, use_char_combining,
                    use_multi_col_char, use_ctl, bidi_mode, bidi_separators, use_dynamic_comb,
-                   bs_mode, vertical_mode, use_local_echo, win_name, icon_name, alt_color_mode,
-                   use_ot_layout, cursor_style, ignore_broadcasted_chars))) {
-            vt_term_plug_pty(terms[num_of_terms++], pty);
+                   bs_mode, vertical_mode, use_local_echo, win_name, icon_name, use_ansi_colors,
+                   alt_color_mode, use_ot_layout, cursor_style, ignore_broadcasted_chars))) {
+            vt_term_plug_pty(terms[num_terms++], pty);
             vt_set_pty_winsize(pty, cols, rows, 0, 0);
 
             continue;
@@ -310,14 +317,14 @@ vt_term_t *vt_create_term(const char *term_type, u_int cols, u_int rows, u_int t
     bl_unsetenv("INHERIT_PTY_LIST");
 #endif
 
-    if (num_of_terms > 0) {
-      return terms[num_of_terms - 1];
+    if (num_terms > 0) {
+      return terms[num_terms - 1];
     }
   }
 #endif
 
   /*
-   * Before modifying terms and num_of_terms, do vt_close_dead_terms().
+   * Before modifying terms and num_terms, do vt_close_dead_terms().
    */
   vt_close_dead_terms();
 
@@ -326,23 +333,24 @@ vt_term_t *vt_create_term(const char *term_type, u_int cols, u_int rows, u_int t
    * If sig_child here...
    */
 
-  if (!(terms[num_of_terms] = vt_term_new(
-            term_type, cols, rows, tab_size, log_size, encoding, is_auto_encoding, use_auto_detect,
-            logging_vt_seq, policy, col_size_a, use_char_combining, use_multi_col_char, use_ctl,
-            bidi_mode, bidi_separators, use_dynamic_comb, bs_mode, vertical_mode, use_local_echo,
-            win_name, icon_name, alt_color_mode, use_ot_layout, cursor_style,
-            ignore_broadcasted_chars))) {
+  if (!(terms[num_terms] = vt_term_new(term_type, cols, rows, tab_size, log_size, encoding,
+                                          is_auto_encoding, use_auto_detect, logging_vt_seq,
+                                          policy, col_size_a, use_char_combining,
+                                          use_multi_col_char, use_ctl, bidi_mode, bidi_separators,
+                                          use_dynamic_comb, bs_mode, vertical_mode, use_local_echo,
+                                          win_name, icon_name, use_ansi_colors, alt_color_mode,
+                                          use_ot_layout, cursor_style, ignore_broadcasted_chars))) {
     return NULL;
   }
 
-  return terms[num_of_terms++];
+  return terms[num_terms++];
 }
 
-int vt_destroy_term(vt_term_t *term) {
-  int count;
+void vt_destroy_term(vt_term_t *term) {
+  u_int count;
 
   /*
-   * Before modifying terms and num_of_terms, do vt_close_dead_terms().
+   * Before modifying terms and num_terms, do vt_close_dead_terms().
    */
   vt_close_dead_terms();
 
@@ -351,23 +359,21 @@ int vt_destroy_term(vt_term_t *term) {
    * If sig_child here...
    */
 
-  for (count = 0; count < num_of_terms; count++) {
+  for (count = 0; count < num_terms; count++) {
     if (terms[count] == term) {
-      terms[count] = terms[--num_of_terms];
+      terms[count] = terms[--num_terms];
 
       break;
     }
   }
 
   vt_term_delete(term);
-
-  return 1;
 }
 
 vt_term_t *vt_get_term(const char *dev) {
   int count;
 
-  for (count = 0; count < num_of_terms; count++) {
+  for (count = 0; count < num_terms; count++) {
     if (dev == NULL || strcmp(dev, vt_term_get_slave_name(terms[count])) == 0) {
       return terms[count];
     }
@@ -379,7 +385,7 @@ vt_term_t *vt_get_term(const char *dev) {
 vt_term_t *vt_get_detached_term(const char *dev) {
   int count;
 
-  for (count = 0; count < num_of_terms; count++) {
+  for (count = 0; count < num_terms; count++) {
     if (!vt_term_is_attached(terms[count]) &&
         (dev == NULL || strcmp(dev, vt_term_get_slave_name(terms[count])) == 0)) {
       return terms[count];
@@ -393,13 +399,13 @@ vt_term_t *vt_next_term(vt_term_t *term /* is detached */
                         ) {
   int count;
 
-  for (count = 0; count < num_of_terms; count++) {
+  for (count = 0; count < num_terms; count++) {
     if (terms[count] == term) {
       int old;
 
       old = count;
 
-      for (count++; count < num_of_terms; count++) {
+      for (count++; count < num_terms; count++) {
         if (!vt_term_is_attached(terms[count])) {
           return terms[count];
         }
@@ -422,7 +428,7 @@ vt_term_t *vt_prev_term(vt_term_t *term /* is detached */
                         ) {
   int count;
 
-  for (count = 0; count < num_of_terms; count++) {
+  for (count = 0; count < num_terms; count++) {
     if (terms[count] == term) {
       int old;
 
@@ -434,7 +440,7 @@ vt_term_t *vt_prev_term(vt_term_t *term /* is detached */
         }
       }
 
-      for (count = num_of_terms - 1; count > old; count--) {
+      for (count = num_terms - 1; count > old; count--) {
         if (!vt_term_is_attached(terms[count])) {
           return terms[count];
         }
@@ -456,14 +462,14 @@ u_int vt_get_all_terms(vt_term_t*** _terms) {
     *_terms = terms;
   }
 
-  return num_of_terms;
+  return num_terms;
 }
 
-int vt_close_dead_terms(void) {
-  if (num_of_terms > 0) {
+void vt_close_dead_terms(void) {
+  if (num_terms > 0) {
     int idx;
 
-    for (idx = (num_of_terms - 1) / MTU; idx >= 0; idx--) {
+    for (idx = (num_terms - 1) / MTU; idx >= 0; idx--) {
       if (dead_mask[idx]) {
         int count;
 
@@ -477,12 +483,12 @@ int vt_close_dead_terms(void) {
 
             term = terms[idx * MTU + count];
             /*
-             * Update terms and num_of_terms before
+             * Update terms and num_terms before
              * vt_term_delete, which calls
              * vt_pty_event_listener::pty_close in which
              * vt_term_manager can be used.
              */
-            terms[idx * MTU + count] = terms[--num_of_terms];
+            terms[idx * MTU + count] = terms[--num_terms];
             if (zombie_pty) {
               vt_term_zombie(term);
             } else {
@@ -495,8 +501,6 @@ int vt_close_dead_terms(void) {
       }
     }
   }
-
-  return 1;
 }
 
 char *vt_get_pty_list(void) {
@@ -507,7 +511,7 @@ char *vt_get_pty_list(void) {
   free(pty_list);
 
   /* The length of pty name is under 50. */
-  len = (50 + 2) * num_of_terms;
+  len = (50 + 2) * num_terms;
 
   if ((pty_list = malloc(len + 1)) == NULL) {
     return "";
@@ -517,7 +521,7 @@ char *vt_get_pty_list(void) {
 
   *p = '\0';
 
-  for (count = 0; count < num_of_terms; count++) {
+  for (count = 0; count < num_terms; count++) {
     bl_snprintf(p, len, "%s:%d;", vt_term_get_slave_name(terms[count]),
                 vt_term_is_attached(terms[count]));
 
